#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 6.2831853071795862*p[7]*(y[4] - y[24]) - p[10]*(x[0] - u[7]);
out[1] = -x[1]*p[11] + u[4];
out[2] = -x[2]*p[12] + u[9];
out[3] = (-x[3] + ((u[10] < 0) ? (
   p[14]*pow(x[7], 3) + u[10]
)
: (
   p[14]*pow(x[7], 3)
)))*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[46];
out[4] = -1.0e-8*x[4] + ((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
));
out[5] = 1.0*(p[18]*x[4] + p[17]*((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
)) - x[5] + u[11])/p[16];
out[6] = -x[8] + x[7] - u[18];
out[7] = 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0.0
)
: (
   p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[8] = 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/p[20];
out[9] = 6.2831853071795862*x[10] - 6.2831853071795862*y[24] + 6.2831853071795862;
out[10] = p[28]*x[11] + p[27]*y[0]*sin(y[1])*sin(x[9]);
out[11] = y[0]*sin(y[1])*sin(x[9]);
out[12] = (0.5*(y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7) - 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/(x[12] + 9.9999999999999995e-7))/p[31];
out[13] = -p[49]*x[13] - y[24] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[13]*y[22]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[13]*y[23]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[6]*y[7]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[6]*y[8]/p[0];
out[4] = x[1] - y[4] + u[6];
out[5] = -p[9]*y[5] - y[2]*sin(x[0] + u[8] - y[3]) + p[8]*y[6];
out[6] = x[2] - p[9]*y[6] - y[2]*cos(x[0] + u[8] - y[3]) - p[8]*y[5] + u[5];
out[7] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]) - y[7];
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]) - y[8];
out[9] = p[25]*y[9]*x[8] - u[13] - x[3];
out[10] = -p[24]*y[9]*x[8] - p[23]*u[12] - y[10];
out[11] = p[24]*u[12]*x[8] + p[25]*x[8] - p[23]*y[9] - y[11];
out[12] = -p[24]*y[13]*x[8] - p[23]*y[12] - y[10];
out[13] = p[24]*y[12]*x[8] + p[25]*x[8] - p[23]*y[13] - y[11];
out[14] = p[25]*y[13] - y[14];
out[15] = -p[26]*(-x[12] + u[14]) + y[12]*y[10] + y[13]*y[11] - y[15];
out[16] = y[17]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[15];
out[17] = -y[16]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[15];
out[18] = -p[29]*y[16] - p[30]*y[17] + y[18];
out[19] = -p[29]*y[17] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[30]*y[16] + y[19];
out[20] = -p[29]*y[20] - y[0]*sin(y[1]) - p[30]*y[21] + y[18]*cos(y[1]) + y[19]*sin(y[1]);
out[21] = -p[29]*y[21] - y[0]*cos(y[1]) + p[30]*y[20] - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[22] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]) - y[22];
out[23] = -y[0]*y[20]*cos(y[1]) + y[0]*y[21]*sin(y[1]) - y[23];
out[24] = 1.0*y[4] - y[24];
out[25] = p[48]*x[13] + p[47]*(1 - y[24]) - y[25];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 6.2831853071795862*p[7]*(y[4] - y[24]) - p[10]*(x[0] - u[7]);
out[1] = -x[1]*p[11] + u[4];
out[2] = -x[2]*p[12] + u[9];
out[3] = (-x[3] + ((u[10] < 0) ? (
   p[14]*pow(x[7], 3) + u[10]
)
: (
   p[14]*pow(x[7], 3)
)))*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[46];
out[4] = -1.0e-8*x[4] + ((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
));
out[5] = 1.0*(p[18]*x[4] + p[17]*((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
)) - x[5] + u[11])/p[16];
out[6] = -x[8] + x[7] - u[18];
out[7] = 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0.0
)
: (
   p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[8] = 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/p[20];
out[9] = 6.2831853071795862*x[10] - 6.2831853071795862*y[24] + 6.2831853071795862;
out[10] = p[28]*x[11] + p[27]*y[0]*sin(y[1])*sin(x[9]);
out[11] = y[0]*sin(y[1])*sin(x[9]);
out[12] = (0.5*(y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7) - 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/(x[12] + 9.9999999999999995e-7))/p[31];
out[13] = -p[49]*x[13] - y[24] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[13]*y[22]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[13]*y[23]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[6]*y[7]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[6]*y[8]/p[0];
out[4] = x[1] - y[4] + u[6];
out[5] = -p[9]*y[5] - y[2]*sin(x[0] + u[8] - y[3]) + p[8]*y[6];
out[6] = x[2] - p[9]*y[6] - y[2]*cos(x[0] + u[8] - y[3]) - p[8]*y[5] + u[5];
out[7] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]) - y[7];
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]) - y[8];
out[9] = p[25]*y[9]*x[8] - u[13] - x[3];
out[10] = -p[24]*y[9]*x[8] - p[23]*u[12] - y[10];
out[11] = p[24]*u[12]*x[8] + p[25]*x[8] - p[23]*y[9] - y[11];
out[12] = -p[24]*y[13]*x[8] - p[23]*y[12] - y[10];
out[13] = p[24]*y[12]*x[8] + p[25]*x[8] - p[23]*y[13] - y[11];
out[14] = p[25]*y[13] - y[14];
out[15] = -p[26]*(-x[12] + u[14]) + y[12]*y[10] + y[13]*y[11] - y[15];
out[16] = y[17]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[15];
out[17] = -y[16]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[15];
out[18] = -p[29]*y[16] - p[30]*y[17] + y[18];
out[19] = -p[29]*y[17] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[30]*y[16] + y[19];
out[20] = -p[29]*y[20] - y[0]*sin(y[1]) - p[30]*y[21] + y[18]*cos(y[1]) + y[19]*sin(y[1]);
out[21] = -p[29]*y[21] - y[0]*cos(y[1]) + p[30]*y[20] - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[22] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]) - y[22];
out[23] = -y[0]*y[20]*cos(y[1]) + y[0]*y[21]*sin(y[1]) - y[23];
out[24] = 1.0*y[4] - y[24];
out[25] = p[48]*x[13] + p[47]*(1 - y[24]) - y[25];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = y[0];
out[1] = y[2];
out[2] = u[4];
out[3] = x[2];
out[4] = u[17];
out[5] = y[12]*y[10] + y[13]*y[11];
out[6] = -y[12]*y[11] + y[13]*y[10];
out[7] = y[22];
out[8] = y[23];
out[9] = y[20];
out[10] = y[21];
out[11] = (y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/x[12];
out[12] = (y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7);

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[123] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[127] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[168] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[208] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[285] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[287] = 0.5*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[328] = 0.5*(-p[22] - y[14])/p[20];
out[348] = -0.5*x[8]/p[20];
out[409] = p[27]*y[0]*sin(y[1])*cos(x[9]);
out[414] = p[27]*sin(y[1])*sin(x[9]);
out[415] = p[27]*y[0]*sin(x[9])*cos(y[1]);
out[449] = y[0]*sin(y[1])*cos(x[9]);
out[454] = sin(y[1])*sin(x[9]);
out[455] = y[0]*sin(x[9])*cos(y[1]);
out[492] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[495] = -0.5*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[504] = 0.5*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[505] = 0.5*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[506] = 0.5*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[507] = 0.5*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[512] = -0.5*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[513] = -0.5*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[514] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[515] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[574] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[575] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[576] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[577] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[614] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[615] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[616] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[617] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[654] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[655] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[656] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[657] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[694] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[695] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[696] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[697] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[760] = -y[2]*cos(x[0] + u[8] - y[3]);
out[776] = -sin(x[0] + u[8] - y[3]);
out[777] = y[2]*cos(x[0] + u[8] - y[3]);
out[800] = y[2]*sin(x[0] + u[8] - y[3]);
out[816] = -cos(x[0] + u[8] - y[3]);
out[817] = -y[2]*sin(x[0] + u[8] - y[3]);
out[840] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[856] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[857] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[859] = y[2]*sin(x[0] + u[8] - y[3]);
out[860] = y[2]*cos(x[0] + u[8] - y[3]);
out[880] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[896] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[897] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[899] = y[2]*cos(x[0] + u[8] - y[3]);
out[900] = -y[2]*sin(x[0] + u[8] - y[3]);
out[928] = p[25]*y[9];
out[943] = p[25]*x[8];
out[968] = -p[24]*y[9];
out[983] = -p[24]*x[8];
out[1048] = -p[24]*y[13];
out[1067] = -p[24]*x[8];
out[1088] = p[24]*y[12] + p[25];
out[1106] = p[24]*x[8];
out[1184] = y[12];
out[1185] = y[13];
out[1186] = y[10];
out[1187] = y[11];
out[1214] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1231] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1254] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1270] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1334] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1374] = -sin(y[1]);
out[1375] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1392] = cos(y[1]);
out[1393] = sin(y[1]);
out[1414] = -cos(y[1]);
out[1415] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1432] = -sin(y[1]);
out[1433] = cos(y[1]);
out[1454] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[1455] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[1474] = y[0]*sin(y[1]);
out[1475] = y[0]*cos(y[1]);
out[1494] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[1495] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[1514] = -y[0]*cos(y[1]);
out[1515] = y[0]*sin(y[1]);

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[18] = 6.2831853071795862*p[7];
out[38] = -6.2831853071795862*p[7];
out[41] = -p[11];
out[82] = -p[12];
out[204] = 1.0*p[18]/p[16];
out[205] = -1.0/p[16];
out[286] = -0.5*p[21]/p[19];
out[288] = 0.5*p[22]/p[19];
out[326] = 0.5*p[21]/p[20];
out[327] = 0.5*p[22]/p[20];
out[411] = p[28];
out[533] = -p[49];
out[596] = -p[13]/p[0];
out[637] = -p[13]/p[0];
out[661] = -p[6]/p[0];
out[702] = -p[6]/p[0];
out[779] = -p[9];
out[780] = p[8];
out[819] = -p[8];
out[820] = -p[9];
out[1008] = p[24]*u[12] + p[25];
out[1023] = -p[23];
out[1066] = -p[23];
out[1107] = -p[23];
out[1147] = p[25];
out[1172] = p[26];
out[1310] = -p[29];
out[1311] = -p[30];
out[1350] = p[30];
out[1351] = -p[29];
out[1394] = -p[29];
out[1395] = -p[30];
out[1434] = p[30];
out[1435] = -p[29];
out[1573] = p[48];
out[1598] = -p[47];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[164] = -1.0e-8;
out[247] = 1.0;
out[248] = -1.0;
out[370] = 6.2831853071795862;
out[398] = -6.2831853071795862;
out[558] = -1.0;
out[721] = 1.0;
out[738] = -1.0;
out[802] = 1.0;
out[861] = -1.0;
out[902] = -1.0;
out[923] = -1.0;
out[984] = -1.0;
out[1025] = -1.0;
out[1064] = -1.0;
out[1105] = -1.0;
out[1148] = -1.0;
out[1189] = -1.0;
out[1229] = -1.0;
out[1312] = 1.0;
out[1353] = 1.0;
out[1476] = -1.0;
out[1517] = -1.0;
out[1538] = 1.0;
out[1558] = -1.0;
out[1599] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[6] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[8] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[11] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[14] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[16] = 0.5*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[20] = 0.5*(-p[22] - y[14])/p[20];
out[21] = -0.5*x[8]/p[20];
out[24] = p[27]*y[0]*sin(y[1])*cos(x[9]);
out[26] = p[27]*sin(y[1])*sin(x[9]);
out[27] = p[27]*y[0]*sin(x[9])*cos(y[1]);
out[28] = y[0]*sin(y[1])*cos(x[9]);
out[29] = sin(y[1])*sin(x[9]);
out[30] = y[0]*sin(x[9])*cos(y[1]);
out[31] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[32] = -0.5*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[33] = 0.5*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[34] = 0.5*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[35] = 0.5*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[36] = 0.5*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[37] = -0.5*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[38] = -0.5*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[39] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[40] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[43] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[44] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[45] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[46] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[48] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[49] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[50] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[51] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[53] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[54] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[55] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[56] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[58] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[59] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[60] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[61] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[65] = -y[2]*cos(x[0] + u[8] - y[3]);
out[66] = -sin(x[0] + u[8] - y[3]);
out[67] = y[2]*cos(x[0] + u[8] - y[3]);
out[70] = y[2]*sin(x[0] + u[8] - y[3]);
out[72] = -cos(x[0] + u[8] - y[3]);
out[73] = -y[2]*sin(x[0] + u[8] - y[3]);
out[76] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[77] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[78] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[79] = y[2]*sin(x[0] + u[8] - y[3]);
out[80] = y[2]*cos(x[0] + u[8] - y[3]);
out[82] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[83] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[84] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[85] = y[2]*cos(x[0] + u[8] - y[3]);
out[86] = -y[2]*sin(x[0] + u[8] - y[3]);
out[89] = p[25]*y[9];
out[90] = p[25]*x[8];
out[91] = -p[24]*y[9];
out[92] = -p[24]*x[8];
out[97] = -p[24]*y[13];
out[100] = -p[24]*x[8];
out[101] = p[24]*y[12] + p[25];
out[103] = p[24]*x[8];
out[108] = y[12];
out[109] = y[13];
out[110] = y[10];
out[111] = y[11];
out[113] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[115] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[116] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[117] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[121] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[125] = -sin(y[1]);
out[126] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[127] = cos(y[1]);
out[128] = sin(y[1]);
out[131] = -cos(y[1]);
out[132] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[133] = -sin(y[1]);
out[134] = cos(y[1]);
out[137] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[138] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[139] = y[0]*sin(y[1]);
out[140] = y[0]*cos(y[1]);
out[142] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[143] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[144] = -y[0]*cos(y[1]);
out[145] = y[0]*sin(y[1]);

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[1] = 6.2831853071795862*p[7];
out[2] = -6.2831853071795862*p[7];
out[3] = -p[11];
out[4] = -p[12];
out[9] = 1.0*p[18]/p[16];
out[10] = -1.0/p[16];
out[15] = -0.5*p[21]/p[19];
out[17] = 0.5*p[22]/p[19];
out[18] = 0.5*p[21]/p[20];
out[19] = 0.5*p[22]/p[20];
out[25] = p[28];
out[41] = -p[49];
out[47] = -p[13]/p[0];
out[52] = -p[13]/p[0];
out[57] = -p[6]/p[0];
out[62] = -p[6]/p[0];
out[68] = -p[9];
out[69] = p[8];
out[74] = -p[8];
out[75] = -p[9];
out[94] = p[24]*u[12] + p[25];
out[95] = -p[23];
out[99] = -p[23];
out[104] = -p[23];
out[105] = p[25];
out[107] = p[26];
out[118] = -p[29];
out[119] = -p[30];
out[122] = p[30];
out[123] = -p[29];
out[129] = -p[29];
out[130] = -p[30];
out[135] = p[30];
out[136] = -p[29];
out[149] = p[48];
out[150] = -p[47];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[7] = -1.0e-8;
out[12] = 1.0;
out[13] = -1.0;
out[22] = 6.2831853071795862;
out[23] = -6.2831853071795862;
out[42] = -1.0;
out[63] = 1.0;
out[64] = -1.0;
out[71] = 1.0;
out[81] = -1.0;
out[87] = -1.0;
out[88] = -1.0;
out[93] = -1.0;
out[96] = -1.0;
out[98] = -1.0;
out[102] = -1.0;
out[106] = -1.0;
out[112] = -1.0;
out[114] = -1.0;
out[120] = 1.0;
out[124] = 1.0;
out[141] = -1.0;
out[146] = -1.0;
out[147] = 1.0;
out[148] = -1.0;
out[151] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[123] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[127] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[168] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[208] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[285] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[287] = 0.5*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[328] = 0.5*(-p[22] - y[14])/p[20];
out[348] = -0.5*x[8]/p[20];
out[409] = p[27]*y[0]*sin(y[1])*cos(x[9]);
out[414] = p[27]*sin(y[1])*sin(x[9]);
out[415] = p[27]*y[0]*sin(x[9])*cos(y[1]);
out[449] = y[0]*sin(y[1])*cos(x[9]);
out[454] = sin(y[1])*sin(x[9]);
out[455] = y[0]*sin(x[9])*cos(y[1]);
out[492] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[495] = -0.5*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[504] = 0.5*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[505] = 0.5*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[506] = 0.5*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[507] = 0.5*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[512] = -0.5*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[513] = -0.5*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[514] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[515] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[574] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[575] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[576] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[577] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[614] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[615] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[616] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[617] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[654] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[655] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[656] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[657] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[694] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[695] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[696] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[697] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[760] = -y[2]*cos(x[0] + u[8] - y[3]);
out[776] = -sin(x[0] + u[8] - y[3]);
out[777] = y[2]*cos(x[0] + u[8] - y[3]);
out[800] = y[2]*sin(x[0] + u[8] - y[3]);
out[816] = -cos(x[0] + u[8] - y[3]);
out[817] = -y[2]*sin(x[0] + u[8] - y[3]);
out[840] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[856] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[857] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[859] = y[2]*sin(x[0] + u[8] - y[3]);
out[860] = y[2]*cos(x[0] + u[8] - y[3]);
out[880] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[896] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[897] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[899] = y[2]*cos(x[0] + u[8] - y[3]);
out[900] = -y[2]*sin(x[0] + u[8] - y[3]);
out[928] = p[25]*y[9];
out[943] = p[25]*x[8];
out[968] = -p[24]*y[9];
out[983] = -p[24]*x[8];
out[1048] = -p[24]*y[13];
out[1067] = -p[24]*x[8];
out[1088] = p[24]*y[12] + p[25];
out[1106] = p[24]*x[8];
out[1184] = y[12];
out[1185] = y[13];
out[1186] = y[10];
out[1187] = y[11];
out[1214] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1231] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1254] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1270] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1334] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1374] = -sin(y[1]);
out[1375] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1392] = cos(y[1]);
out[1393] = sin(y[1]);
out[1414] = -cos(y[1]);
out[1415] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1432] = -sin(y[1]);
out[1433] = cos(y[1]);
out[1454] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[1455] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[1474] = y[0]*sin(y[1]);
out[1475] = y[0]*cos(y[1]);
out[1494] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[1495] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[1514] = -y[0]*cos(y[1]);
out[1515] = y[0]*sin(y[1]);

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[18] = 6.2831853071795862*p[7];
out[38] = -6.2831853071795862*p[7];
out[41] = -p[11];
out[82] = -p[12];
out[204] = 1.0*p[18]/p[16];
out[205] = -1.0/p[16];
out[286] = -0.5*p[21]/p[19];
out[288] = 0.5*p[22]/p[19];
out[326] = 0.5*p[21]/p[20];
out[327] = 0.5*p[22]/p[20];
out[411] = p[28];
out[533] = -p[49];
out[596] = -p[13]/p[0];
out[637] = -p[13]/p[0];
out[661] = -p[6]/p[0];
out[702] = -p[6]/p[0];
out[779] = -p[9];
out[780] = p[8];
out[819] = -p[8];
out[820] = -p[9];
out[1008] = p[24]*u[12] + p[25];
out[1023] = -p[23];
out[1066] = -p[23];
out[1107] = -p[23];
out[1147] = p[25];
out[1172] = p[26];
out[1310] = -p[29];
out[1311] = -p[30];
out[1350] = p[30];
out[1351] = -p[29];
out[1394] = -p[29];
out[1395] = -p[30];
out[1434] = p[30];
out[1435] = -p[29];
out[1573] = p[48];
out[1598] = -p[47];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[164] = -1.0e-8;
out[247] = 1.0;
out[248] = -1.0;
out[370] = 6.2831853071795862;
out[398] = -6.2831853071795862;
out[558] = -1.0;
out[721] = 1.0;
out[738] = -1.0;
out[802] = 1.0;
out[861] = -1.0;
out[902] = -1.0;
out[923] = -1.0;
out[984] = -1.0;
out[1025] = -1.0;
out[1064] = -1.0;
out[1105] = -1.0;
out[1148] = -1.0;
out[1189] = -1.0;
out[1229] = -1.0;
out[1312] = 1.0;
out[1353] = 1.0;
out[1476] = -1.0;
out[1517] = -1.0;
out[1538] = 1.0;
out[1558] = -1.0;
out[1599] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[6] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[8] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[11] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[14] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[16] = 0.5*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19];
out[20] = 0.5*(-p[22] - y[14])/p[20];
out[21] = -0.5*x[8]/p[20];
out[24] = p[27]*y[0]*sin(y[1])*cos(x[9]);
out[26] = p[27]*sin(y[1])*sin(x[9]);
out[27] = p[27]*y[0]*sin(x[9])*cos(y[1]);
out[28] = y[0]*sin(y[1])*cos(x[9]);
out[29] = sin(y[1])*sin(x[9]);
out[30] = y[0]*sin(x[9])*cos(y[1]);
out[31] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[32] = -0.5*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[33] = 0.5*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[34] = 0.5*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[35] = 0.5*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[36] = 0.5*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[37] = -0.5*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[38] = -0.5*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[39] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[40] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[43] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[44] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[45] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[46] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[48] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[49] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[50] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[51] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[53] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[54] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[55] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[56] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[58] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[59] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[60] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[61] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[65] = -y[2]*cos(x[0] + u[8] - y[3]);
out[66] = -sin(x[0] + u[8] - y[3]);
out[67] = y[2]*cos(x[0] + u[8] - y[3]);
out[70] = y[2]*sin(x[0] + u[8] - y[3]);
out[72] = -cos(x[0] + u[8] - y[3]);
out[73] = -y[2]*sin(x[0] + u[8] - y[3]);
out[76] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[77] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[78] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[79] = y[2]*sin(x[0] + u[8] - y[3]);
out[80] = y[2]*cos(x[0] + u[8] - y[3]);
out[82] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[83] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[84] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[85] = y[2]*cos(x[0] + u[8] - y[3]);
out[86] = -y[2]*sin(x[0] + u[8] - y[3]);
out[89] = p[25]*y[9];
out[90] = p[25]*x[8];
out[91] = -p[24]*y[9];
out[92] = -p[24]*x[8];
out[97] = -p[24]*y[13];
out[100] = -p[24]*x[8];
out[101] = p[24]*y[12] + p[25];
out[103] = p[24]*x[8];
out[108] = y[12];
out[109] = y[13];
out[110] = y[10];
out[111] = y[11];
out[113] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[115] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[116] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[117] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[121] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[125] = -sin(y[1]);
out[126] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[127] = cos(y[1]);
out[128] = sin(y[1]);
out[131] = -cos(y[1]);
out[132] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[133] = -sin(y[1]);
out[134] = cos(y[1]);
out[137] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[138] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[139] = y[0]*sin(y[1]);
out[140] = y[0]*cos(y[1]);
out[142] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[143] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[144] = -y[0]*cos(y[1]);
out[145] = y[0]*sin(y[1]);

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[1] = 6.2831853071795862*p[7];
out[2] = -6.2831853071795862*p[7];
out[3] = -p[11];
out[4] = -p[12];
out[9] = 1.0*p[18]/p[16];
out[10] = -1.0/p[16];
out[15] = -0.5*p[21]/p[19];
out[17] = 0.5*p[22]/p[19];
out[18] = 0.5*p[21]/p[20];
out[19] = 0.5*p[22]/p[20];
out[25] = p[28];
out[41] = -p[49];
out[47] = -p[13]/p[0];
out[52] = -p[13]/p[0];
out[57] = -p[6]/p[0];
out[62] = -p[6]/p[0];
out[68] = -p[9];
out[69] = p[8];
out[74] = -p[8];
out[75] = -p[9];
out[94] = p[24]*u[12] + p[25];
out[95] = -p[23];
out[99] = -p[23];
out[104] = -p[23];
out[105] = p[25];
out[107] = p[26];
out[118] = -p[29];
out[119] = -p[30];
out[122] = p[30];
out[123] = -p[29];
out[129] = -p[29];
out[130] = -p[30];
out[135] = p[30];
out[136] = -p[29];
out[149] = p[48];
out[150] = -p[47];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[7] = -1.0e-8;
out[12] = 1.0;
out[13] = -1.0;
out[22] = 6.2831853071795862;
out[23] = -6.2831853071795862;
out[42] = -1.0;
out[63] = 1.0;
out[64] = -1.0;
out[71] = 1.0;
out[81] = -1.0;
out[87] = -1.0;
out[88] = -1.0;
out[93] = -1.0;
out[96] = -1.0;
out[98] = -1.0;
out[102] = -1.0;
out[106] = -1.0;
out[112] = -1.0;
out[114] = -1.0;
out[120] = 1.0;
out[124] = 1.0;
out[141] = -1.0;
out[146] = -1.0;
out[147] = 1.0;
out[148] = -1.0;
out[151] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[123] = 0.5*Dt*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46] + 1.0;
out[127] = -1.5*Dt*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[168] = -0.5*Dt*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[208] = -0.5*Dt*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[285] = -0.25*Dt*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[287] = -0.25*Dt*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19] + 1.0;
out[328] = -0.25*Dt*(-p[22] - y[14])/p[20] + 1.0;
out[348] = 0.25*Dt*x[8]/p[20];
out[409] = -0.5*Dt*p[27]*y[0]*sin(y[1])*cos(x[9]);
out[414] = -0.5*Dt*p[27]*sin(y[1])*sin(x[9]);
out[415] = -0.5*Dt*p[27]*y[0]*sin(x[9])*cos(y[1]);
out[449] = -0.5*Dt*y[0]*sin(y[1])*cos(x[9]);
out[454] = -0.5*Dt*sin(y[1])*sin(x[9]);
out[455] = -0.5*Dt*y[0]*sin(x[9])*cos(y[1]);
out[492] = 1.0 - 0.5*Dt*(-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[495] = 0.25*Dt*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[504] = -0.25*Dt*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[505] = -0.25*Dt*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[506] = -0.25*Dt*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[507] = -0.25*Dt*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[512] = 0.25*Dt*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[513] = 0.25*Dt*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[514] = 0.25*Dt*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[515] = 0.25*Dt*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[574] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[575] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[576] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[577] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[614] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[615] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[616] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[617] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[654] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[655] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[656] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[657] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[694] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[695] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[696] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[697] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[760] = -y[2]*cos(x[0] + u[8] - y[3]);
out[776] = -sin(x[0] + u[8] - y[3]);
out[777] = y[2]*cos(x[0] + u[8] - y[3]);
out[800] = y[2]*sin(x[0] + u[8] - y[3]);
out[816] = -cos(x[0] + u[8] - y[3]);
out[817] = -y[2]*sin(x[0] + u[8] - y[3]);
out[840] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[856] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[857] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[859] = y[2]*sin(x[0] + u[8] - y[3]);
out[860] = y[2]*cos(x[0] + u[8] - y[3]);
out[880] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[896] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[897] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[899] = y[2]*cos(x[0] + u[8] - y[3]);
out[900] = -y[2]*sin(x[0] + u[8] - y[3]);
out[928] = p[25]*y[9];
out[943] = p[25]*x[8];
out[968] = -p[24]*y[9];
out[983] = -p[24]*x[8];
out[1048] = -p[24]*y[13];
out[1067] = -p[24]*x[8];
out[1088] = p[24]*y[12] + p[25];
out[1106] = p[24]*x[8];
out[1184] = y[12];
out[1185] = y[13];
out[1186] = y[10];
out[1187] = y[11];
out[1214] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1231] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1254] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1270] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1334] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1374] = -sin(y[1]);
out[1375] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1392] = cos(y[1]);
out[1393] = sin(y[1]);
out[1414] = -cos(y[1]);
out[1415] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1432] = -sin(y[1]);
out[1433] = cos(y[1]);
out[1454] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[1455] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[1474] = y[0]*sin(y[1]);
out[1475] = y[0]*cos(y[1]);
out[1494] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[1495] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[1514] = -y[0]*cos(y[1]);
out[1515] = y[0]*sin(y[1]);

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[10] + 1.0;
out[18] = -3.1415926535897931*Dt*p[7];
out[38] = 3.1415926535897931*Dt*p[7];
out[41] = 0.5*Dt*p[11] + 1.0;
out[82] = 0.5*Dt*p[12] + 1.0;
out[164] = 5.0000000000000001e-9*Dt + 1.0;
out[204] = -0.5*Dt*p[18]/p[16];
out[205] = 0.5*Dt/p[16] + 1.0;
out[247] = -0.5*Dt;
out[248] = 0.5*Dt;
out[286] = 0.25*Dt*p[21]/p[19];
out[288] = -0.25*p[22]*Dt/p[19];
out[326] = -0.25*Dt*p[21]/p[20];
out[327] = -0.25*p[22]*Dt/p[20];
out[370] = -3.1415926535897931*Dt;
out[398] = 3.1415926535897931*Dt;
out[411] = -0.5*Dt*p[28];
out[533] = 0.5*Dt*p[49] + 1.0;
out[558] = 0.5*Dt;
out[596] = -p[13]/p[0];
out[637] = -p[13]/p[0];
out[661] = -p[6]/p[0];
out[702] = -p[6]/p[0];
out[779] = -p[9];
out[780] = p[8];
out[819] = -p[8];
out[820] = -p[9];
out[1008] = p[24]*u[12] + p[25];
out[1023] = -p[23];
out[1066] = -p[23];
out[1107] = -p[23];
out[1147] = p[25];
out[1172] = p[26];
out[1310] = -p[29];
out[1311] = -p[30];
out[1350] = p[30];
out[1351] = -p[29];
out[1394] = -p[29];
out[1395] = -p[30];
out[1434] = p[30];
out[1435] = -p[29];
out[1573] = p[48];
out[1598] = -p[47];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[246] = 1.0;
out[369] = 1.0;
out[410] = 1.0;
out[451] = 1.0;
out[721] = 1.0;
out[738] = -1.0;
out[802] = 1.0;
out[861] = -1.0;
out[902] = -1.0;
out[923] = -1.0;
out[984] = -1.0;
out[1025] = -1.0;
out[1064] = -1.0;
out[1105] = -1.0;
out[1148] = -1.0;
out[1189] = -1.0;
out[1229] = -1.0;
out[1312] = 1.0;
out[1353] = 1.0;
out[1476] = -1.0;
out[1517] = -1.0;
out[1538] = 1.0;
out[1558] = -1.0;
out[1599] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = 0.5*Dt*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46] + 1.0;
out[6] = -1.5*Dt*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[46];
out[8] = -0.5*Dt*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[11] = -0.5*Dt*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[15] = -0.25*Dt*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[39]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2))*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[35]*(p[36]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[37])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[45]*pow(p[41], 3))
))/p[19];
out[17] = -0.25*Dt*(-p[22] + ((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(-p[35]*p[36]*p[42]*p[41]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[35]*p[39]*p[42]*p[41]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*u[17]*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) + p[40]*p[42]*p[41]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
)))/p[19] + 1.0;
out[21] = -0.25*Dt*(-p[22] - y[14])/p[20] + 1.0;
out[22] = 0.25*Dt*x[8]/p[20];
out[26] = -0.5*Dt*p[27]*y[0]*sin(y[1])*cos(x[9]);
out[29] = -0.5*Dt*p[27]*sin(y[1])*sin(x[9]);
out[30] = -0.5*Dt*p[27]*y[0]*sin(x[9])*cos(y[1]);
out[31] = -0.5*Dt*y[0]*sin(y[1])*cos(x[9]);
out[33] = -0.5*Dt*sin(y[1])*sin(x[9]);
out[34] = -0.5*Dt*y[0]*sin(x[9])*cos(y[1]);
out[35] = 1.0 - 0.5*Dt*(-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[31];
out[36] = 0.25*Dt*(y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[37] = -0.25*Dt*y[12]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[38] = -0.25*Dt*y[13]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[39] = -0.25*Dt*y[10]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[40] = -0.25*Dt*y[11]/(p[31]*(x[12] + 9.9999999999999995e-7));
out[41] = 0.25*Dt*(y[20]*cos(y[1]) - y[21]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[42] = 0.25*Dt*(y[20]*sin(y[1]) + y[21]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[43] = 0.25*Dt*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[44] = 0.25*Dt*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[31]*(x[12] + 9.9999999999999995e-7));
out[47] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[48] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[49] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[50] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[52] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[53] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[54] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[57] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[58] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[59] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[60] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[62] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[63] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[64] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[65] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[69] = -y[2]*cos(x[0] + u[8] - y[3]);
out[70] = -sin(x[0] + u[8] - y[3]);
out[71] = y[2]*cos(x[0] + u[8] - y[3]);
out[74] = y[2]*sin(x[0] + u[8] - y[3]);
out[76] = -cos(x[0] + u[8] - y[3]);
out[77] = -y[2]*sin(x[0] + u[8] - y[3]);
out[80] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[81] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[82] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[83] = y[2]*sin(x[0] + u[8] - y[3]);
out[84] = y[2]*cos(x[0] + u[8] - y[3]);
out[86] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[87] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[88] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[89] = y[2]*cos(x[0] + u[8] - y[3]);
out[90] = -y[2]*sin(x[0] + u[8] - y[3]);
out[93] = p[25]*y[9];
out[94] = p[25]*x[8];
out[95] = -p[24]*y[9];
out[96] = -p[24]*x[8];
out[101] = -p[24]*y[13];
out[104] = -p[24]*x[8];
out[105] = p[24]*y[12] + p[25];
out[107] = p[24]*x[8];
out[112] = y[12];
out[113] = y[13];
out[114] = y[10];
out[115] = y[11];
out[117] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[119] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[120] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[121] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[125] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[129] = -sin(y[1]);
out[130] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[131] = cos(y[1]);
out[132] = sin(y[1]);
out[135] = -cos(y[1]);
out[136] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[137] = -sin(y[1]);
out[138] = cos(y[1]);
out[141] = y[20]*sin(y[1]) + y[21]*cos(y[1]);
out[142] = y[0]*y[20]*cos(y[1]) - y[0]*y[21]*sin(y[1]);
out[143] = y[0]*sin(y[1]);
out[144] = y[0]*cos(y[1]);
out[146] = -y[20]*cos(y[1]) + y[21]*sin(y[1]);
out[147] = y[0]*y[20]*sin(y[1]) + y[0]*y[21]*cos(y[1]);
out[148] = -y[0]*cos(y[1]);
out[149] = y[0]*sin(y[1]);

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[10] + 1.0;
out[1] = -3.1415926535897931*Dt*p[7];
out[2] = 3.1415926535897931*Dt*p[7];
out[3] = 0.5*Dt*p[11] + 1.0;
out[4] = 0.5*Dt*p[12] + 1.0;
out[7] = 5.0000000000000001e-9*Dt + 1.0;
out[9] = -0.5*Dt*p[18]/p[16];
out[10] = 0.5*Dt/p[16] + 1.0;
out[13] = -0.5*Dt;
out[14] = 0.5*Dt;
out[16] = 0.25*Dt*p[21]/p[19];
out[18] = -0.25*p[22]*Dt/p[19];
out[19] = -0.25*Dt*p[21]/p[20];
out[20] = -0.25*p[22]*Dt/p[20];
out[24] = -3.1415926535897931*Dt;
out[25] = 3.1415926535897931*Dt;
out[28] = -0.5*Dt*p[28];
out[45] = 0.5*Dt*p[49] + 1.0;
out[46] = 0.5*Dt;
out[51] = -p[13]/p[0];
out[56] = -p[13]/p[0];
out[61] = -p[6]/p[0];
out[66] = -p[6]/p[0];
out[72] = -p[9];
out[73] = p[8];
out[78] = -p[8];
out[79] = -p[9];
out[98] = p[24]*u[12] + p[25];
out[99] = -p[23];
out[103] = -p[23];
out[108] = -p[23];
out[109] = p[25];
out[111] = p[26];
out[122] = -p[29];
out[123] = -p[30];
out[126] = p[30];
out[127] = -p[29];
out[133] = -p[29];
out[134] = -p[30];
out[139] = p[30];
out[140] = -p[29];
out[153] = p[48];
out[154] = -p[47];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[12] = 1.0;
out[23] = 1.0;
out[27] = 1.0;
out[32] = 1.0;
out[67] = 1.0;
out[68] = -1.0;
out[75] = 1.0;
out[85] = -1.0;
out[91] = -1.0;
out[92] = -1.0;
out[97] = -1.0;
out[100] = -1.0;
out[102] = -1.0;
out[106] = -1.0;
out[110] = -1.0;
out[116] = -1.0;
out[118] = -1.0;
out[124] = 1.0;
out[128] = 1.0;
out[145] = -1.0;
out[150] = -1.0;
out[151] = 1.0;
out[152] = -1.0;
out[155] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[67] = ((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[10] < 0) ? (
   1.0
)
: (
   0
))/p[46];
out[150] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(p[35]*p[36]*p[42]*p[41]*x[7]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*pow(u[17], 2)*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[35]*p[39]*p[42]*p[41]*x[7]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*pow(u[17], 2)*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[40]*p[42]*p[41]*x[7]/(p[43]*pow(u[17], 2)))/(p[45]*pow(p[41], 3)) + 3.0*p[44]*pow(u[17], 2)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
))/p[19];

}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[7] = p[10];
out[106] = 1.0/p[16];

}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[23] = 1.0;
out[47] = 1.0;
out[132] = -1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[103] = -y[2]*cos(x[0] + u[8] - y[3]);
out[122] = y[2]*sin(x[0] + u[8] - y[3]);
out[141] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[160] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[221] = p[24]*x[8];

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[20] = -1/p[0];
out[40] = -1/p[0];
out[60] = -1/p[0];
out[202] = -p[23];
out[299] = -p[26];

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[82] = 1.0;
out[119] = 1.0;
out[184] = -1.0;
out[338] = -1.0;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[166] = -(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12], 2);
out[180] = -(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2);

}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[44] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[140] = y[12];
out[141] = y[13];
out[142] = y[10];
out[143] = y[11];
out[166] = y[13];
out[167] = -y[12];
out[168] = -y[11];
out[169] = y[10];
out[287] = (y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/x[12];
out[304] = (y[20]*cos(y[1]) - y[21]*sin(y[1]))/x[12];
out[305] = (y[20]*sin(y[1]) + y[21]*cos(y[1]))/x[12];
out[306] = (y[18]*cos(y[1]) + y[19]*sin(y[1]))/x[12];
out[307] = (-y[18]*sin(y[1]) + y[19]*cos(y[1]))/x[12];
out[322] = y[12]/(x[12] + 9.9999999999999995e-7);
out[323] = y[13]/(x[12] + 9.9999999999999995e-7);
out[324] = y[10]/(x[12] + 9.9999999999999995e-7);
out[325] = y[11]/(x[12] + 9.9999999999999995e-7);

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[28] = 1.0;
out[204] = 1.0;
out[231] = 1.0;
out[254] = 1.0;
out[281] = 1.0;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[42] = 1.0;
out[93] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = ((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[10] < 0) ? (
   1.0
)
: (
   0
))/p[46];
out[6] = 0.5*((p[44]*pow(u[17], 3)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3)) < 0) ? (
   0
)
: (
   p[44]*pow(u[17], 3)*(p[35]*p[36]*p[42]*p[41]*x[7]*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*pow(u[17], 2)*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[35]*p[39]*p[42]*p[41]*x[7]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[43]*pow(u[17], 2)*pow(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5], 2)) - p[40]*p[42]*p[41]*x[7]/(p[43]*pow(u[17], 2)))/(p[45]*pow(p[41], 3)) + 3.0*p[44]*pow(u[17], 2)*(p[35]*(p[36]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[37]*x[5] - p[38])*exp(-p[39]*(1.0/(p[42]*p[41]*x[7]/(p[43]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[40]*p[42]*p[41]*x[7]/(p[43]*u[17]))/(p[45]*pow(p[41], 3))
))/p[19];

}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = p[10];
out[4] = 1.0/p[16];

}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 1.0;
out[2] = 1.0;
out[5] = -1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -y[2]*cos(x[0] + u[8] - y[3]);
out[7] = y[2]*sin(x[0] + u[8] - y[3]);
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[9] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[12] = p[24]*x[8];

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[1] = -1/p[0];
out[2] = -1/p[0];
out[3] = -1/p[0];
out[11] = -p[23];
out[13] = -p[26];

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 1.0;
out[6] = 1.0;
out[10] = -1.0;
out[14] = -1.0;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = -(y[20]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12], 2);
out[2] = -(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2);

}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = y[12];
out[3] = y[13];
out[4] = y[10];
out[5] = y[11];
out[6] = y[13];
out[7] = -y[12];
out[8] = -y[11];
out[9] = y[10];
out[14] = (y[20]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[21]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/x[12];
out[15] = (y[20]*cos(y[1]) - y[21]*sin(y[1]))/x[12];
out[16] = (y[20]*sin(y[1]) + y[21]*cos(y[1]))/x[12];
out[17] = (y[18]*cos(y[1]) + y[19]*sin(y[1]))/x[12];
out[18] = (-y[18]*sin(y[1]) + y[19]*cos(y[1]))/x[12];
out[19] = y[12]/(x[12] + 9.9999999999999995e-7);
out[20] = y[13]/(x[12] + 9.9999999999999995e-7);
out[21] = y[10]/(x[12] + 9.9999999999999995e-7);
out[22] = y[11]/(x[12] + 9.9999999999999995e-7);

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[10] = 1.0;
out[11] = 1.0;
out[12] = 1.0;
out[13] = 1.0;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_pmsm_test_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_pmsm_test_cffi(void) { return NULL; }
#  else
     initpmsm_test_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_pmsm_test_cffi(void)
{
  return _cffi_init("pmsm_test_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
initpmsm_test_cffi(void)
{
  _cffi_init("pmsm_test_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
