#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21]*x[0] + p[11]*(x[1] - y[28]);
out[1] = (1.0/2.0)*(-p[19]*(x[1] - y[28]) - y[6]*(p[20]*y[6] + y[4]*sin(x[0] - y[5])) - y[7]*(p[20]*y[7] + y[4]*cos(x[0] - y[5])) + y[12])/p[12];
out[2] = (-x[2] - y[6]*(-p[17] + p[15]) + y[10])/p[13];
out[3] = (-x[3] + y[7]*(-p[18] + p[16]))/p[14];
out[4] = (p[24]*x[6] - y[4] + u[7] + u[6] - x[4])/p[26];
out[5] = (p[23]*(p[25]*(p[24]*x[6] - y[4] + u[7] + u[6] - x[4])/p[26] + x[4]) - x[5])/p[27];
out[6] = -y[4] + u[6];
out[7] = (y[11] - x[7])/p[31];
out[8] = (x[7] - x[8])/p[33];
out[9] = (-x[9] + ((u[9] < 0) ? (
   p[37]*pow(x[13], 3) + u[9]
)
: (
   p[37]*pow(x[13], 3)
)))*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[67];
out[10] = -1.0e-8*x[10] + ((p[38] - x[14] > 0) ? (
   0.0
)
: (
   -p[38] + x[14]
));
out[11] = 1.0*(p[41]*x[10] + p[40]*((p[38] - x[14] > 0) ? (
   0.0
)
: (
   -p[38] + x[14]
)) - x[11] + u[10])/p[39];
out[12] = -x[14] + x[13] - u[17];
out[13] = 0.5*(-p[45]*(-x[14] + x[13]) - p[44]*x[12] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0.0
)
: (
   p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[14] = 0.5*(p[45]*(-x[14] + x[13]) + p[44]*x[12] - x[14]*y[18])/p[43];
out[15] = (0.5*(y[16]*y[14] + y[17]*y[15])/(x[15] + 9.9999999999999995e-7) - 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/(x[15] + 9.9999999999999995e-7))/p[52];
out[16] = -p[70]*x[16] - y[28] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[36]*y[26]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[36]*y[27]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*(p[1] + p[4]) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - p[5] - 1.0/2.0*p[3] - 1.0/2.0*p[6]) + y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[4] = -u[4]/p[0] + y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + pow(y[4], 2)*p[4] - p[10]*y[8]/p[0];
out[5] = -u[5]/p[0] + y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + pow(y[4], 2)*(-p[5] - 1.0/2.0*p[6]) - p[10]*y[9]/p[0];
out[6] = p[20]*y[7] + y[4]*cos(x[0] - y[5]) + p[17]*y[6] - x[2];
out[7] = p[20]*y[6] + y[4]*sin(x[0] - y[5]) - p[18]*y[7] - x[3];
out[8] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]) - y[8];
out[9] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]) - y[9];
out[10] = -y[10] + ((p[28] > x[5] + 1.0) ? (
   p[28]
)
: ((p[29] < x[5] + 1.0) ? (
   p[29]
)
: (
   x[5] + 1.0
)));
out[11] = p[22]*y[29] + u[8] - y[11] - (x[1] - p[35])/p[30];
out[12] = -p[34]*(x[1] - p[35]) + p[32]*(x[7] - x[8])/p[33] - y[12] + x[8];
out[13] = p[48]*y[13]*x[14] - u[12] - x[9];
out[14] = -p[47]*y[13]*x[14] - p[46]*u[11] - y[14];
out[15] = p[47]*u[11]*x[14] + p[48]*x[14] - p[46]*y[13] - y[15];
out[16] = -p[47]*y[17]*x[14] - p[46]*y[16] - y[14];
out[17] = p[47]*y[16]*x[14] + p[48]*x[14] - p[46]*y[17] - y[15];
out[18] = p[48]*y[17] - y[18];
out[19] = -p[49]*(-x[15] + u[13]) + y[16]*y[14] + y[17]*y[15] - y[19];
out[20] = y[21]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[19];
out[21] = -y[20]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[14];
out[22] = -p[50]*y[20] - p[51]*y[21] + y[22];
out[23] = -p[50]*y[21] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[51]*y[20] + y[23];
out[24] = -p[50]*y[24] - y[0]*sin(y[1]) - p[51]*y[25] + y[22]*cos(y[1]) + y[23]*sin(y[1]);
out[25] = -p[50]*y[25] - y[0]*cos(y[1]) + p[51]*y[24] - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[26] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]) - y[26];
out[27] = -y[0]*y[24]*cos(y[1]) + y[0]*y[25]*sin(y[1]) - y[27];
out[28] = x[1] - y[28];
out[29] = p[69]*x[16] + p[68]*(1 - y[28]) - y[29];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21]*x[0] + p[11]*(x[1] - y[28]);
out[1] = (1.0/2.0)*(-p[19]*(x[1] - y[28]) - y[6]*(p[20]*y[6] + y[4]*sin(x[0] - y[5])) - y[7]*(p[20]*y[7] + y[4]*cos(x[0] - y[5])) + y[12])/p[12];
out[2] = (-x[2] - y[6]*(-p[17] + p[15]) + y[10])/p[13];
out[3] = (-x[3] + y[7]*(-p[18] + p[16]))/p[14];
out[4] = (p[24]*x[6] - y[4] + u[7] + u[6] - x[4])/p[26];
out[5] = (p[23]*(p[25]*(p[24]*x[6] - y[4] + u[7] + u[6] - x[4])/p[26] + x[4]) - x[5])/p[27];
out[6] = -y[4] + u[6];
out[7] = (y[11] - x[7])/p[31];
out[8] = (x[7] - x[8])/p[33];
out[9] = (-x[9] + ((u[9] < 0) ? (
   p[37]*pow(x[13], 3) + u[9]
)
: (
   p[37]*pow(x[13], 3)
)))*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[67];
out[10] = -1.0e-8*x[10] + ((p[38] - x[14] > 0) ? (
   0.0
)
: (
   -p[38] + x[14]
));
out[11] = 1.0*(p[41]*x[10] + p[40]*((p[38] - x[14] > 0) ? (
   0.0
)
: (
   -p[38] + x[14]
)) - x[11] + u[10])/p[39];
out[12] = -x[14] + x[13] - u[17];
out[13] = 0.5*(-p[45]*(-x[14] + x[13]) - p[44]*x[12] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0.0
)
: (
   p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[14] = 0.5*(p[45]*(-x[14] + x[13]) + p[44]*x[12] - x[14]*y[18])/p[43];
out[15] = (0.5*(y[16]*y[14] + y[17]*y[15])/(x[15] + 9.9999999999999995e-7) - 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/(x[15] + 9.9999999999999995e-7))/p[52];
out[16] = -p[70]*x[16] - y[28] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[36]*y[26]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[36]*y[27]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*(p[1] + p[4]) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - p[5] - 1.0/2.0*p[3] - 1.0/2.0*p[6]) + y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[4] = -u[4]/p[0] + y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + pow(y[4], 2)*p[4] - p[10]*y[8]/p[0];
out[5] = -u[5]/p[0] + y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + pow(y[4], 2)*(-p[5] - 1.0/2.0*p[6]) - p[10]*y[9]/p[0];
out[6] = p[20]*y[7] + y[4]*cos(x[0] - y[5]) + p[17]*y[6] - x[2];
out[7] = p[20]*y[6] + y[4]*sin(x[0] - y[5]) - p[18]*y[7] - x[3];
out[8] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]) - y[8];
out[9] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]) - y[9];
out[10] = -y[10] + ((p[28] > x[5] + 1.0) ? (
   p[28]
)
: ((p[29] < x[5] + 1.0) ? (
   p[29]
)
: (
   x[5] + 1.0
)));
out[11] = p[22]*y[29] + u[8] - y[11] - (x[1] - p[35])/p[30];
out[12] = -p[34]*(x[1] - p[35]) + p[32]*(x[7] - x[8])/p[33] - y[12] + x[8];
out[13] = p[48]*y[13]*x[14] - u[12] - x[9];
out[14] = -p[47]*y[13]*x[14] - p[46]*u[11] - y[14];
out[15] = p[47]*u[11]*x[14] + p[48]*x[14] - p[46]*y[13] - y[15];
out[16] = -p[47]*y[17]*x[14] - p[46]*y[16] - y[14];
out[17] = p[47]*y[16]*x[14] + p[48]*x[14] - p[46]*y[17] - y[15];
out[18] = p[48]*y[17] - y[18];
out[19] = -p[49]*(-x[15] + u[13]) + y[16]*y[14] + y[17]*y[15] - y[19];
out[20] = y[21]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[19];
out[21] = -y[20]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[14];
out[22] = -p[50]*y[20] - p[51]*y[21] + y[22];
out[23] = -p[50]*y[21] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[51]*y[20] + y[23];
out[24] = -p[50]*y[24] - y[0]*sin(y[1]) - p[51]*y[25] + y[22]*cos(y[1]) + y[23]*sin(y[1]);
out[25] = -p[50]*y[25] - y[0]*cos(y[1]) + p[51]*y[24] - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[26] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]) - y[26];
out[27] = -y[0]*y[24]*cos(y[1]) + y[0]*y[25]*sin(y[1]) - y[27];
out[28] = x[1] - y[28];
out[29] = p[69]*x[16] + p[68]*(1 - y[28]) - y[29];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = y[0];
out[1] = y[2];
out[2] = y[4];
out[3] = y[6]*(p[20]*y[6] + y[4]*sin(x[0] - y[5])) + y[7]*(p[20]*y[7] + y[4]*cos(x[0] - y[5]));
out[4] = y[10];
out[5] = y[12];
out[6] = u[7];
out[7] = u[6];
out[8] = 0;
out[9] = u[16];
out[10] = y[16]*y[14] + y[17]*y[15];
out[11] = -y[16]*y[15] + y[17]*y[14];
out[12] = y[26];
out[13] = y[27];
out[14] = y[24];
out[15] = y[25];
out[16] = (y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/x[15];
out[17] = (y[16]*y[14] + y[17]*y[15])/(x[15] + 9.9999999999999995e-7);

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[47] = 0.5*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[68] = 0.5*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[69] = 0.5*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[70] = 0.5*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[71] = 0.5*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[432] = -((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[436] = 3.0*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[484] = ((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[531] = 1.0*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[622] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[624] = 0.5*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[672] = 0.5*(-p[45] - y[18])/p[43];
out[693] = -0.5*x[14]/p[43];
out[720] = (-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[723] = -0.5*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[736] = 0.5*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[737] = 0.5*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[738] = 0.5*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[739] = 0.5*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[744] = -0.5*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[745] = -0.5*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[746] = -0.5*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[747] = -0.5*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[816] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[817] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[818] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[819] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[863] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[864] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[865] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[866] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[910] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[911] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[912] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[913] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[914] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[915] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[957] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[958] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[959] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[960] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[961] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[962] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1006] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1007] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1008] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[1009] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[1053] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1054] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1055] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[1056] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1081] = -y[4]*sin(x[0] - y[5]);
out[1102] = cos(x[0] - y[5]);
out[1103] = y[4]*sin(x[0] - y[5]);
out[1128] = y[4]*cos(x[0] - y[5]);
out[1149] = sin(x[0] - y[5]);
out[1150] = -y[4]*cos(x[0] - y[5]);
out[1175] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[1196] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[1197] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[1198] = y[4]*sin(x[0] - y[5]);
out[1199] = y[4]*cos(x[0] - y[5]);
out[1222] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[1243] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[1244] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[1245] = y[4]*cos(x[0] - y[5]);
out[1246] = -y[4]*sin(x[0] - y[5]);
out[1274] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[1424] = p[48]*y[13];
out[1440] = p[48]*x[14];
out[1471] = -p[47]*y[13];
out[1487] = -p[47]*x[14];
out[1565] = -p[47]*y[17];
out[1585] = -p[47]*x[14];
out[1612] = p[47]*y[16] + p[48];
out[1631] = p[47]*x[14];
out[1723] = y[16];
out[1724] = y[17];
out[1725] = y[14];
out[1726] = y[15];
out[1756] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1777] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1803] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1823] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1897] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1944] = -sin(y[1]);
out[1945] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[1966] = cos(y[1]);
out[1967] = sin(y[1]);
out[1991] = -cos(y[1]);
out[1992] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[2013] = -sin(y[1]);
out[2014] = cos(y[1]);
out[2038] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[2039] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[2062] = y[0]*sin(y[1]);
out[2063] = y[0]*cos(y[1]);
out[2085] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[2086] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[2109] = -y[0]*cos(y[1]);
out[2110] = y[0]*sin(y[1]);

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21];
out[1] = p[11];
out[45] = -p[11];
out[48] = -0.5*p[19]/p[12];
out[76] = 0.5/p[12];
out[92] = 0.5*p[19]/p[12];
out[96] = -1/p[13];
out[117] = (p[17] - p[15])/p[13];
out[121] = 1.0/p[13];
out[144] = -1/p[14];
out[165] = (-p[18] + p[16])/p[14];
out[192] = -1/p[26];
out[194] = p[24]/p[26];
out[209] = -1/p[26];
out[239] = p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[240] = -1/p[27];
out[241] = p[23]*p[24]*p[25]/(p[26]*p[27]);
out[256] = -p[23]*p[25]/(p[26]*p[27]);
out[336] = -1/p[31];
out[357] = 1.0/p[31];
out[383] = 1.0/p[33];
out[384] = -1/p[33];
out[527] = 1.0*p[41]/p[39];
out[528] = -1.0/p[39];
out[623] = -0.5*p[44]/p[42];
out[625] = 0.5*p[45]/p[42];
out[670] = 0.5*p[44]/p[43];
out[671] = 0.5*p[45]/p[43];
out[768] = -p[70];
out[842] = -p[36]/p[0];
out[890] = -p[36]/p[0];
out[1012] = -p[10]/p[0];
out[1060] = -p[10]/p[0];
out[1104] = p[17];
out[1105] = p[20];
out[1151] = p[20];
out[1152] = -p[18];
out[1317] = -1/p[30];
out[1362] = p[22];
out[1364] = -p[34];
out[1370] = p[32]/p[33];
out[1371] = -p[32]/p[33] + 1.0;
out[1518] = p[47]*u[11] + p[48];
out[1534] = -p[46];
out[1584] = -p[46];
out[1632] = -p[46];
out[1679] = p[48];
out[1707] = p[49];
out[1870] = -p[50];
out[1871] = -p[51];
out[1917] = p[51];
out[1918] = -p[50];
out[1968] = -p[50];
out[1969] = -p[51];
out[2015] = p[51];
out[2016] = -p[50];
out[2178] = p[69];
out[2207] = -p[68];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[303] = -1.0;
out[480] = -1.0e-8;
out[577] = 1.0;
out[578] = -1.0;
out[797] = -1.0;
out[1083] = -1.0;
out[1131] = -1.0;
out[1200] = -1.0;
out[1248] = -1.0;
out[1296] = -1.0;
out[1344] = -1.0;
out[1392] = -1.0;
out[1419] = -1.0;
out[1488] = -1.0;
out[1536] = -1.0;
out[1582] = -1.0;
out[1630] = -1.0;
out[1680] = -1.0;
out[1728] = -1.0;
out[1775] = -1.0;
out[1872] = 1.0;
out[1920] = 1.0;
out[2064] = -1.0;
out[2112] = -1.0;
out[2116] = 1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = 0.5*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[5] = 0.5*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[6] = 0.5*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[7] = 0.5*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[8] = 0.5*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[28] = -((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[29] = 3.0*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[31] = ((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[34] = 1.0*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[37] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[39] = 0.5*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[43] = 0.5*(-p[45] - y[18])/p[43];
out[44] = -0.5*x[14]/p[43];
out[45] = (-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[46] = -0.5*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[47] = 0.5*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[48] = 0.5*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[49] = 0.5*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[50] = 0.5*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[51] = -0.5*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[52] = -0.5*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[53] = -0.5*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[54] = -0.5*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[57] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[58] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[59] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[60] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[62] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[63] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[64] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[67] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[68] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[69] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[70] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[71] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[72] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[73] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[74] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[75] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[76] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[77] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[78] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[79] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[80] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[81] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[82] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[84] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[85] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[86] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[87] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[89] = -y[4]*sin(x[0] - y[5]);
out[91] = cos(x[0] - y[5]);
out[92] = y[4]*sin(x[0] - y[5]);
out[95] = y[4]*cos(x[0] - y[5]);
out[97] = sin(x[0] - y[5]);
out[98] = -y[4]*cos(x[0] - y[5]);
out[101] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[102] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[103] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[104] = y[4]*sin(x[0] - y[5]);
out[105] = y[4]*cos(x[0] - y[5]);
out[107] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[108] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[109] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[110] = y[4]*cos(x[0] - y[5]);
out[111] = -y[4]*sin(x[0] - y[5]);
out[113] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[123] = p[48]*y[13];
out[124] = p[48]*x[14];
out[125] = -p[47]*y[13];
out[126] = -p[47]*x[14];
out[131] = -p[47]*y[17];
out[134] = -p[47]*x[14];
out[135] = p[47]*y[16] + p[48];
out[137] = p[47]*x[14];
out[142] = y[16];
out[143] = y[17];
out[144] = y[14];
out[145] = y[15];
out[147] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[149] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[150] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[151] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[155] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[159] = -sin(y[1]);
out[160] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[161] = cos(y[1]);
out[162] = sin(y[1]);
out[165] = -cos(y[1]);
out[166] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[167] = -sin(y[1]);
out[168] = cos(y[1]);
out[171] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[172] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[173] = y[0]*sin(y[1]);
out[174] = y[0]*cos(y[1]);
out[176] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[177] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[178] = -y[0]*cos(y[1]);
out[179] = y[0]*sin(y[1]);

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21];
out[1] = p[11];
out[2] = -p[11];
out[4] = -0.5*p[19]/p[12];
out[9] = 0.5/p[12];
out[10] = 0.5*p[19]/p[12];
out[11] = -1/p[13];
out[12] = (p[17] - p[15])/p[13];
out[13] = 1.0/p[13];
out[14] = -1/p[14];
out[15] = (-p[18] + p[16])/p[14];
out[16] = -1/p[26];
out[17] = p[24]/p[26];
out[18] = -1/p[26];
out[19] = p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[20] = -1/p[27];
out[21] = p[23]*p[24]*p[25]/(p[26]*p[27]);
out[22] = -p[23]*p[25]/(p[26]*p[27]);
out[24] = -1/p[31];
out[25] = 1.0/p[31];
out[26] = 1.0/p[33];
out[27] = -1/p[33];
out[32] = 1.0*p[41]/p[39];
out[33] = -1.0/p[39];
out[38] = -0.5*p[44]/p[42];
out[40] = 0.5*p[45]/p[42];
out[41] = 0.5*p[44]/p[43];
out[42] = 0.5*p[45]/p[43];
out[55] = -p[70];
out[61] = -p[36]/p[0];
out[66] = -p[36]/p[0];
out[83] = -p[10]/p[0];
out[88] = -p[10]/p[0];
out[93] = p[17];
out[94] = p[20];
out[99] = p[20];
out[100] = -p[18];
out[115] = -1/p[30];
out[117] = p[22];
out[118] = -p[34];
out[119] = p[32]/p[33];
out[120] = -p[32]/p[33] + 1.0;
out[128] = p[47]*u[11] + p[48];
out[129] = -p[46];
out[133] = -p[46];
out[138] = -p[46];
out[139] = p[48];
out[141] = p[49];
out[152] = -p[50];
out[153] = -p[51];
out[156] = p[51];
out[157] = -p[50];
out[163] = -p[50];
out[164] = -p[51];
out[169] = p[51];
out[170] = -p[50];
out[183] = p[69];
out[184] = -p[68];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[23] = -1.0;
out[30] = -1.0e-8;
out[35] = 1.0;
out[36] = -1.0;
out[56] = -1.0;
out[90] = -1.0;
out[96] = -1.0;
out[106] = -1.0;
out[112] = -1.0;
out[114] = -1.0;
out[116] = -1.0;
out[121] = -1.0;
out[122] = -1.0;
out[127] = -1.0;
out[130] = -1.0;
out[132] = -1.0;
out[136] = -1.0;
out[140] = -1.0;
out[146] = -1.0;
out[148] = -1.0;
out[154] = 1.0;
out[158] = 1.0;
out[175] = -1.0;
out[180] = -1.0;
out[181] = 1.0;
out[182] = -1.0;
out[185] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[47] = 0.5*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[68] = 0.5*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[69] = 0.5*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[70] = 0.5*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[71] = 0.5*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[432] = -((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[436] = 3.0*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[484] = ((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[531] = 1.0*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[622] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[624] = 0.5*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[672] = 0.5*(-p[45] - y[18])/p[43];
out[693] = -0.5*x[14]/p[43];
out[720] = (-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[723] = -0.5*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[736] = 0.5*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[737] = 0.5*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[738] = 0.5*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[739] = 0.5*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[744] = -0.5*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[745] = -0.5*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[746] = -0.5*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[747] = -0.5*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[816] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[817] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[818] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[819] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[863] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[864] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[865] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[866] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[910] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[911] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[912] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[913] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[914] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[915] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[957] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[958] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[959] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[960] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[961] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[962] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1006] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1007] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1008] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[1009] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[1053] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1054] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1055] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[1056] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1081] = -y[4]*sin(x[0] - y[5]);
out[1102] = cos(x[0] - y[5]);
out[1103] = y[4]*sin(x[0] - y[5]);
out[1128] = y[4]*cos(x[0] - y[5]);
out[1149] = sin(x[0] - y[5]);
out[1150] = -y[4]*cos(x[0] - y[5]);
out[1175] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[1196] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[1197] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[1198] = y[4]*sin(x[0] - y[5]);
out[1199] = y[4]*cos(x[0] - y[5]);
out[1222] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[1243] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[1244] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[1245] = y[4]*cos(x[0] - y[5]);
out[1246] = -y[4]*sin(x[0] - y[5]);
out[1274] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[1424] = p[48]*y[13];
out[1440] = p[48]*x[14];
out[1471] = -p[47]*y[13];
out[1487] = -p[47]*x[14];
out[1565] = -p[47]*y[17];
out[1585] = -p[47]*x[14];
out[1612] = p[47]*y[16] + p[48];
out[1631] = p[47]*x[14];
out[1723] = y[16];
out[1724] = y[17];
out[1725] = y[14];
out[1726] = y[15];
out[1756] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1777] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1803] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1823] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1897] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1944] = -sin(y[1]);
out[1945] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[1966] = cos(y[1]);
out[1967] = sin(y[1]);
out[1991] = -cos(y[1]);
out[1992] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[2013] = -sin(y[1]);
out[2014] = cos(y[1]);
out[2038] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[2039] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[2062] = y[0]*sin(y[1]);
out[2063] = y[0]*cos(y[1]);
out[2085] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[2086] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[2109] = -y[0]*cos(y[1]);
out[2110] = y[0]*sin(y[1]);

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21];
out[1] = p[11];
out[45] = -p[11];
out[48] = -0.5*p[19]/p[12];
out[76] = 0.5/p[12];
out[92] = 0.5*p[19]/p[12];
out[96] = -1/p[13];
out[117] = (p[17] - p[15])/p[13];
out[121] = 1.0/p[13];
out[144] = -1/p[14];
out[165] = (-p[18] + p[16])/p[14];
out[192] = -1/p[26];
out[194] = p[24]/p[26];
out[209] = -1/p[26];
out[239] = p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[240] = -1/p[27];
out[241] = p[23]*p[24]*p[25]/(p[26]*p[27]);
out[256] = -p[23]*p[25]/(p[26]*p[27]);
out[336] = -1/p[31];
out[357] = 1.0/p[31];
out[383] = 1.0/p[33];
out[384] = -1/p[33];
out[527] = 1.0*p[41]/p[39];
out[528] = -1.0/p[39];
out[623] = -0.5*p[44]/p[42];
out[625] = 0.5*p[45]/p[42];
out[670] = 0.5*p[44]/p[43];
out[671] = 0.5*p[45]/p[43];
out[768] = -p[70];
out[842] = -p[36]/p[0];
out[890] = -p[36]/p[0];
out[1012] = -p[10]/p[0];
out[1060] = -p[10]/p[0];
out[1104] = p[17];
out[1105] = p[20];
out[1151] = p[20];
out[1152] = -p[18];
out[1317] = -1/p[30];
out[1362] = p[22];
out[1364] = -p[34];
out[1370] = p[32]/p[33];
out[1371] = -p[32]/p[33] + 1.0;
out[1518] = p[47]*u[11] + p[48];
out[1534] = -p[46];
out[1584] = -p[46];
out[1632] = -p[46];
out[1679] = p[48];
out[1707] = p[49];
out[1870] = -p[50];
out[1871] = -p[51];
out[1917] = p[51];
out[1918] = -p[50];
out[1968] = -p[50];
out[1969] = -p[51];
out[2015] = p[51];
out[2016] = -p[50];
out[2178] = p[69];
out[2207] = -p[68];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[303] = -1.0;
out[480] = -1.0e-8;
out[577] = 1.0;
out[578] = -1.0;
out[797] = -1.0;
out[1083] = -1.0;
out[1131] = -1.0;
out[1200] = -1.0;
out[1248] = -1.0;
out[1296] = -1.0;
out[1344] = -1.0;
out[1392] = -1.0;
out[1419] = -1.0;
out[1488] = -1.0;
out[1536] = -1.0;
out[1582] = -1.0;
out[1630] = -1.0;
out[1680] = -1.0;
out[1728] = -1.0;
out[1775] = -1.0;
out[1872] = 1.0;
out[1920] = 1.0;
out[2064] = -1.0;
out[2112] = -1.0;
out[2116] = 1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = 0.5*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[5] = 0.5*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[6] = 0.5*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[7] = 0.5*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[8] = 0.5*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[28] = -((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[29] = 3.0*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[31] = ((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[34] = 1.0*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[37] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[39] = 0.5*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42];
out[43] = 0.5*(-p[45] - y[18])/p[43];
out[44] = -0.5*x[14]/p[43];
out[45] = (-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[46] = -0.5*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[47] = 0.5*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[48] = 0.5*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[49] = 0.5*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[50] = 0.5*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[51] = -0.5*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[52] = -0.5*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[53] = -0.5*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[54] = -0.5*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[57] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[58] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[59] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[60] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[62] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[63] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[64] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[67] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[68] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[69] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[70] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[71] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[72] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[73] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[74] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[75] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[76] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[77] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[78] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[79] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[80] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[81] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[82] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[84] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[85] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[86] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[87] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[89] = -y[4]*sin(x[0] - y[5]);
out[91] = cos(x[0] - y[5]);
out[92] = y[4]*sin(x[0] - y[5]);
out[95] = y[4]*cos(x[0] - y[5]);
out[97] = sin(x[0] - y[5]);
out[98] = -y[4]*cos(x[0] - y[5]);
out[101] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[102] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[103] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[104] = y[4]*sin(x[0] - y[5]);
out[105] = y[4]*cos(x[0] - y[5]);
out[107] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[108] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[109] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[110] = y[4]*cos(x[0] - y[5]);
out[111] = -y[4]*sin(x[0] - y[5]);
out[113] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[123] = p[48]*y[13];
out[124] = p[48]*x[14];
out[125] = -p[47]*y[13];
out[126] = -p[47]*x[14];
out[131] = -p[47]*y[17];
out[134] = -p[47]*x[14];
out[135] = p[47]*y[16] + p[48];
out[137] = p[47]*x[14];
out[142] = y[16];
out[143] = y[17];
out[144] = y[14];
out[145] = y[15];
out[147] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[149] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[150] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[151] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[155] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[159] = -sin(y[1]);
out[160] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[161] = cos(y[1]);
out[162] = sin(y[1]);
out[165] = -cos(y[1]);
out[166] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[167] = -sin(y[1]);
out[168] = cos(y[1]);
out[171] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[172] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[173] = y[0]*sin(y[1]);
out[174] = y[0]*cos(y[1]);
out[176] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[177] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[178] = -y[0]*cos(y[1]);
out[179] = y[0]*sin(y[1]);

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[21];
out[1] = p[11];
out[2] = -p[11];
out[4] = -0.5*p[19]/p[12];
out[9] = 0.5/p[12];
out[10] = 0.5*p[19]/p[12];
out[11] = -1/p[13];
out[12] = (p[17] - p[15])/p[13];
out[13] = 1.0/p[13];
out[14] = -1/p[14];
out[15] = (-p[18] + p[16])/p[14];
out[16] = -1/p[26];
out[17] = p[24]/p[26];
out[18] = -1/p[26];
out[19] = p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[20] = -1/p[27];
out[21] = p[23]*p[24]*p[25]/(p[26]*p[27]);
out[22] = -p[23]*p[25]/(p[26]*p[27]);
out[24] = -1/p[31];
out[25] = 1.0/p[31];
out[26] = 1.0/p[33];
out[27] = -1/p[33];
out[32] = 1.0*p[41]/p[39];
out[33] = -1.0/p[39];
out[38] = -0.5*p[44]/p[42];
out[40] = 0.5*p[45]/p[42];
out[41] = 0.5*p[44]/p[43];
out[42] = 0.5*p[45]/p[43];
out[55] = -p[70];
out[61] = -p[36]/p[0];
out[66] = -p[36]/p[0];
out[83] = -p[10]/p[0];
out[88] = -p[10]/p[0];
out[93] = p[17];
out[94] = p[20];
out[99] = p[20];
out[100] = -p[18];
out[115] = -1/p[30];
out[117] = p[22];
out[118] = -p[34];
out[119] = p[32]/p[33];
out[120] = -p[32]/p[33] + 1.0;
out[128] = p[47]*u[11] + p[48];
out[129] = -p[46];
out[133] = -p[46];
out[138] = -p[46];
out[139] = p[48];
out[141] = p[49];
out[152] = -p[50];
out[153] = -p[51];
out[156] = p[51];
out[157] = -p[50];
out[163] = -p[50];
out[164] = -p[51];
out[169] = p[51];
out[170] = -p[50];
out[183] = p[69];
out[184] = -p[68];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[23] = -1.0;
out[30] = -1.0e-8;
out[35] = 1.0;
out[36] = -1.0;
out[56] = -1.0;
out[90] = -1.0;
out[96] = -1.0;
out[106] = -1.0;
out[112] = -1.0;
out[114] = -1.0;
out[116] = -1.0;
out[121] = -1.0;
out[122] = -1.0;
out[127] = -1.0;
out[130] = -1.0;
out[132] = -1.0;
out[136] = -1.0;
out[140] = -1.0;
out[146] = -1.0;
out[148] = -1.0;
out[154] = 1.0;
out[158] = 1.0;
out[175] = -1.0;
out[180] = -1.0;
out[181] = 1.0;
out[182] = -1.0;
out[185] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[47] = -0.25*Dt*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[68] = -0.25*Dt*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[69] = -0.25*Dt*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[70] = -0.25*Dt*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[71] = -0.25*Dt*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[432] = 0.5*Dt*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67] + 1.0;
out[436] = -1.5*Dt*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[484] = -0.5*Dt*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[531] = -0.5*Dt*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[622] = -0.25*Dt*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[624] = -0.25*Dt*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42] + 1.0;
out[672] = -0.25*Dt*(-p[45] - y[18])/p[43] + 1.0;
out[693] = 0.25*Dt*x[14]/p[43];
out[720] = 1.0 - 0.5*Dt*(-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[723] = 0.25*Dt*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[736] = -0.25*Dt*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[737] = -0.25*Dt*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[738] = -0.25*Dt*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[739] = -0.25*Dt*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[744] = 0.25*Dt*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[745] = 0.25*Dt*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[746] = 0.25*Dt*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[747] = 0.25*Dt*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[816] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[817] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[818] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[819] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[863] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[864] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[865] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[866] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[910] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[911] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[912] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[913] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[914] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[915] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[957] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[958] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[959] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[960] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[961] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[962] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1006] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1007] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1008] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[1009] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[1053] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[1054] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[1055] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[1056] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[1081] = -y[4]*sin(x[0] - y[5]);
out[1102] = cos(x[0] - y[5]);
out[1103] = y[4]*sin(x[0] - y[5]);
out[1128] = y[4]*cos(x[0] - y[5]);
out[1149] = sin(x[0] - y[5]);
out[1150] = -y[4]*cos(x[0] - y[5]);
out[1175] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[1196] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[1197] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[1198] = y[4]*sin(x[0] - y[5]);
out[1199] = y[4]*cos(x[0] - y[5]);
out[1222] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[1243] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[1244] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[1245] = y[4]*cos(x[0] - y[5]);
out[1246] = -y[4]*sin(x[0] - y[5]);
out[1274] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[1424] = p[48]*y[13];
out[1440] = p[48]*x[14];
out[1471] = -p[47]*y[13];
out[1487] = -p[47]*x[14];
out[1565] = -p[47]*y[17];
out[1585] = -p[47]*x[14];
out[1612] = p[47]*y[16] + p[48];
out[1631] = p[47]*x[14];
out[1723] = y[16];
out[1724] = y[17];
out[1725] = y[14];
out[1726] = y[15];
out[1756] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1777] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1803] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1823] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1897] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1944] = -sin(y[1]);
out[1945] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[1966] = cos(y[1]);
out[1967] = sin(y[1]);
out[1991] = -cos(y[1]);
out[1992] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[2013] = -sin(y[1]);
out[2014] = cos(y[1]);
out[2038] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[2039] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[2062] = y[0]*sin(y[1]);
out[2063] = y[0]*cos(y[1]);
out[2085] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[2086] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[2109] = -y[0]*cos(y[1]);
out[2110] = y[0]*sin(y[1]);

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[21] + 1.0;
out[1] = -0.5*Dt*p[11];
out[45] = 0.5*Dt*p[11];
out[48] = 0.25*p[19]*Dt/p[12] + 1.0;
out[76] = -0.25*Dt/p[12];
out[92] = -0.25*p[19]*Dt/p[12];
out[96] = 0.5*Dt/p[13] + 1.0;
out[117] = -0.5*Dt*(p[17] - p[15])/p[13];
out[121] = -0.5*Dt/p[13];
out[144] = 0.5*Dt/p[14] + 1.0;
out[165] = -0.5*Dt*(-p[18] + p[16])/p[14];
out[192] = 0.5*Dt/p[26] + 1.0;
out[194] = -0.5*Dt*p[24]/p[26];
out[209] = 0.5*Dt/p[26];
out[239] = -0.5*Dt*p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[240] = 0.5*Dt/p[27] + 1.0;
out[241] = -0.5*Dt*p[23]*p[24]*p[25]/(p[26]*p[27]);
out[256] = 0.5*Dt*p[23]*p[25]/(p[26]*p[27]);
out[303] = 0.5*Dt;
out[336] = 0.5*Dt/p[31] + 1.0;
out[357] = -0.5*Dt/p[31];
out[383] = -0.5*Dt/p[33];
out[384] = 0.5*Dt/p[33] + 1.0;
out[480] = 5.0000000000000001e-9*Dt + 1.0;
out[527] = -0.5*Dt*p[41]/p[39];
out[528] = 0.5*Dt/p[39] + 1.0;
out[577] = -0.5*Dt;
out[578] = 0.5*Dt;
out[623] = 0.25*Dt*p[44]/p[42];
out[625] = -0.25*p[45]*Dt/p[42];
out[670] = -0.25*Dt*p[44]/p[43];
out[671] = -0.25*p[45]*Dt/p[43];
out[768] = 0.5*Dt*p[70] + 1.0;
out[797] = 0.5*Dt;
out[842] = -p[36]/p[0];
out[890] = -p[36]/p[0];
out[1012] = -p[10]/p[0];
out[1060] = -p[10]/p[0];
out[1104] = p[17];
out[1105] = p[20];
out[1151] = p[20];
out[1152] = -p[18];
out[1317] = -1/p[30];
out[1362] = p[22];
out[1364] = -p[34];
out[1370] = p[32]/p[33];
out[1371] = -p[32]/p[33] + 1.0;
out[1518] = p[47]*u[11] + p[48];
out[1534] = -p[46];
out[1584] = -p[46];
out[1632] = -p[46];
out[1679] = p[48];
out[1707] = p[49];
out[1870] = -p[50];
out[1871] = -p[51];
out[1917] = p[51];
out[1918] = -p[50];
out[1968] = -p[50];
out[1969] = -p[51];
out[2015] = p[51];
out[2016] = -p[50];
out[2178] = p[69];
out[2207] = -p[68];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[288] = 1.0;
out[576] = 1.0;
out[1083] = -1.0;
out[1131] = -1.0;
out[1200] = -1.0;
out[1248] = -1.0;
out[1296] = -1.0;
out[1344] = -1.0;
out[1392] = -1.0;
out[1419] = -1.0;
out[1488] = -1.0;
out[1536] = -1.0;
out[1582] = -1.0;
out[1630] = -1.0;
out[1680] = -1.0;
out[1728] = -1.0;
out[1775] = -1.0;
out[1872] = 1.0;
out[1920] = 1.0;
out[2064] = -1.0;
out[2112] = -1.0;
out[2116] = 1.0;
out[2160] = -1.0;
out[2208] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -0.25*Dt*(-y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[5] = -0.25*Dt*(-y[6]*sin(x[0] - y[5]) - y[7]*cos(x[0] - y[5]))/p[12];
out[6] = -0.25*Dt*(y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]))/p[12];
out[7] = -0.25*Dt*(-2.0*p[20]*y[6] - y[4]*sin(x[0] - y[5]))/p[12];
out[8] = -0.25*Dt*(-2.0*p[20]*y[7] - y[4]*cos(x[0] - y[5]))/p[12];
out[29] = 0.5*Dt*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67] + 1.0;
out[30] = -1.5*Dt*p[37]*pow(x[13], 2)*((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))/p[67];
out[32] = -0.5*Dt*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
));
out[35] = -0.5*Dt*p[40]*((p[38] - x[14] > 0) ? (
   0
)
: (
   1.0
))/p[39];
out[39] = -0.25*Dt*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[60]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2))*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[56]*(p[57]*(0.10500000000000001*pow(x[11], 2)/pow(pow(x[11], 3) + 1.0, 2) - 0.080000000000000002/pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[58])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))))/(p[66]*pow(p[62], 3))
))/p[42];
out[41] = -0.25*Dt*(-p[45] + ((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(-p[56]*p[57]*p[63]*p[62]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[56]*p[60]*p[63]*p[62]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*u[16]*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) + p[61]*p[63]*p[62]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
)))/p[42] + 1.0;
out[45] = -0.25*Dt*(-p[45] - y[18])/p[43] + 1.0;
out[46] = 0.25*Dt*x[14]/p[43];
out[47] = 1.0 - 0.5*Dt*(-0.5*(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2) + 0.5*(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15] + 9.9999999999999995e-7, 2))/p[52];
out[48] = 0.25*Dt*(y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[49] = -0.25*Dt*y[16]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[50] = -0.25*Dt*y[17]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[51] = -0.25*Dt*y[14]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[52] = -0.25*Dt*y[15]/(p[52]*(x[15] + 9.9999999999999995e-7));
out[53] = 0.25*Dt*(y[24]*cos(y[1]) - y[25]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[54] = 0.25*Dt*(y[24]*sin(y[1]) + y[25]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[55] = 0.25*Dt*(y[22]*cos(y[1]) + y[23]*sin(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[56] = 0.25*Dt*(-y[22]*sin(y[1]) + y[23]*cos(y[1]))/(p[52]*(x[15] + 9.9999999999999995e-7));
out[59] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[60] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[61] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[62] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[64] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[66] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[67] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[69] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[70] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[71] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*(p[1] + p[4]) + y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[72] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) + y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[73] = y[2]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[74] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[75] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[76] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[77] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - p[5] - 0.5*p[3] - 0.5*p[6]) + y[4]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[78] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[79] = y[2]*(p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[80] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[81] = y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[82] = y[2]*y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[83] = y[2]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5])) + 2.0*y[4]*p[4];
out[84] = y[2]*y[4]*(-p[5]*cos(y[3] - y[5]) - p[4]*sin(y[3] - y[5]));
out[86] = y[4]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5]));
out[87] = y[2]*y[4]*(-p[5]*sin(y[3] - y[5]) + p[4]*cos(y[3] - y[5]));
out[88] = y[2]*(p[5]*cos(y[3] - y[5]) + p[4]*sin(y[3] - y[5])) + 2.0*y[4]*(-p[5] - 0.5*p[6]);
out[89] = y[2]*y[4]*(p[5]*sin(y[3] - y[5]) - p[4]*cos(y[3] - y[5]));
out[91] = -y[4]*sin(x[0] - y[5]);
out[93] = cos(x[0] - y[5]);
out[94] = y[4]*sin(x[0] - y[5]);
out[97] = y[4]*cos(x[0] - y[5]);
out[99] = sin(x[0] - y[5]);
out[100] = -y[4]*cos(x[0] - y[5]);
out[103] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[104] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[105] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[106] = y[4]*sin(x[0] - y[5]);
out[107] = y[4]*cos(x[0] - y[5]);
out[109] = -y[4]*y[6]*sin(x[0] - y[5]) - y[4]*y[7]*cos(x[0] - y[5]);
out[110] = y[6]*cos(x[0] - y[5]) - y[7]*sin(x[0] - y[5]);
out[111] = y[4]*y[6]*sin(x[0] - y[5]) + y[4]*y[7]*cos(x[0] - y[5]);
out[112] = y[4]*cos(x[0] - y[5]);
out[113] = -y[4]*sin(x[0] - y[5]);
out[115] = ((p[28] > x[5] + 1.0 || p[29] < x[5] + 1.0) ? (
   0
)
: (
   1.0
));
out[125] = p[48]*y[13];
out[126] = p[48]*x[14];
out[127] = -p[47]*y[13];
out[128] = -p[47]*x[14];
out[133] = -p[47]*y[17];
out[136] = -p[47]*x[14];
out[137] = p[47]*y[16] + p[48];
out[139] = p[47]*x[14];
out[144] = y[16];
out[145] = y[17];
out[146] = y[14];
out[147] = y[15];
out[149] = y[21]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[151] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[152] = -y[20]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[153] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[157] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[161] = -sin(y[1]);
out[162] = -y[0]*cos(y[1]) - y[22]*sin(y[1]) + y[23]*cos(y[1]);
out[163] = cos(y[1]);
out[164] = sin(y[1]);
out[167] = -cos(y[1]);
out[168] = y[0]*sin(y[1]) - y[22]*cos(y[1]) - y[23]*sin(y[1]);
out[169] = -sin(y[1]);
out[170] = cos(y[1]);
out[173] = y[24]*sin(y[1]) + y[25]*cos(y[1]);
out[174] = y[0]*y[24]*cos(y[1]) - y[0]*y[25]*sin(y[1]);
out[175] = y[0]*sin(y[1]);
out[176] = y[0]*cos(y[1]);
out[178] = -y[24]*cos(y[1]) + y[25]*sin(y[1]);
out[179] = y[0]*y[24]*sin(y[1]) + y[0]*y[25]*cos(y[1]);
out[180] = -y[0]*cos(y[1]);
out[181] = y[0]*sin(y[1]);

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[21] + 1.0;
out[1] = -0.5*Dt*p[11];
out[2] = 0.5*Dt*p[11];
out[4] = 0.25*p[19]*Dt/p[12] + 1.0;
out[9] = -0.25*Dt/p[12];
out[10] = -0.25*p[19]*Dt/p[12];
out[11] = 0.5*Dt/p[13] + 1.0;
out[12] = -0.5*Dt*(p[17] - p[15])/p[13];
out[13] = -0.5*Dt/p[13];
out[14] = 0.5*Dt/p[14] + 1.0;
out[15] = -0.5*Dt*(-p[18] + p[16])/p[14];
out[16] = 0.5*Dt/p[26] + 1.0;
out[17] = -0.5*Dt*p[24]/p[26];
out[18] = 0.5*Dt/p[26];
out[19] = -0.5*Dt*p[23]*(-p[25]/p[26] + 1.0)/p[27];
out[20] = 0.5*Dt/p[27] + 1.0;
out[21] = -0.5*Dt*p[23]*p[24]*p[25]/(p[26]*p[27]);
out[22] = 0.5*Dt*p[23]*p[25]/(p[26]*p[27]);
out[24] = 0.5*Dt;
out[25] = 0.5*Dt/p[31] + 1.0;
out[26] = -0.5*Dt/p[31];
out[27] = -0.5*Dt/p[33];
out[28] = 0.5*Dt/p[33] + 1.0;
out[31] = 5.0000000000000001e-9*Dt + 1.0;
out[33] = -0.5*Dt*p[41]/p[39];
out[34] = 0.5*Dt/p[39] + 1.0;
out[37] = -0.5*Dt;
out[38] = 0.5*Dt;
out[40] = 0.25*Dt*p[44]/p[42];
out[42] = -0.25*p[45]*Dt/p[42];
out[43] = -0.25*Dt*p[44]/p[43];
out[44] = -0.25*p[45]*Dt/p[43];
out[57] = 0.5*Dt*p[70] + 1.0;
out[58] = 0.5*Dt;
out[63] = -p[36]/p[0];
out[68] = -p[36]/p[0];
out[85] = -p[10]/p[0];
out[90] = -p[10]/p[0];
out[95] = p[17];
out[96] = p[20];
out[101] = p[20];
out[102] = -p[18];
out[117] = -1/p[30];
out[119] = p[22];
out[120] = -p[34];
out[121] = p[32]/p[33];
out[122] = -p[32]/p[33] + 1.0;
out[130] = p[47]*u[11] + p[48];
out[131] = -p[46];
out[135] = -p[46];
out[140] = -p[46];
out[141] = p[48];
out[143] = p[49];
out[154] = -p[50];
out[155] = -p[51];
out[158] = p[51];
out[159] = -p[50];
out[165] = -p[50];
out[166] = -p[51];
out[171] = p[51];
out[172] = -p[50];
out[185] = p[69];
out[186] = -p[68];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[23] = 1.0;
out[36] = 1.0;
out[92] = -1.0;
out[98] = -1.0;
out[108] = -1.0;
out[114] = -1.0;
out[116] = -1.0;
out[118] = -1.0;
out[123] = -1.0;
out[124] = -1.0;
out[129] = -1.0;
out[132] = -1.0;
out[134] = -1.0;
out[138] = -1.0;
out[142] = -1.0;
out[148] = -1.0;
out[150] = -1.0;
out[156] = 1.0;
out[160] = 1.0;
out[177] = -1.0;
out[182] = -1.0;
out[183] = 1.0;
out[184] = -1.0;
out[187] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[171] = ((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[9] < 0) ? (
   1.0
)
: (
   0
))/p[67];
out[250] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(p[56]*p[57]*p[63]*p[62]*x[13]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*pow(u[16], 2)*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[56]*p[60]*p[63]*p[62]*x[13]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*pow(u[16], 2)*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[61]*p[63]*p[62]*x[13]/(p[64]*pow(u[16], 2)))/(p[66]*pow(p[62], 3)) + 3.0*p[65]*pow(u[16], 2)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
))/p[42];

}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[78] = 1.0/p[26];
out[79] = 1.0/p[26];
out[96] = p[23]*p[25]/(p[26]*p[27]);
out[97] = p[23]*p[25]/(p[26]*p[27]);
out[208] = 1.0/p[39];

}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[114] = 1.0;
out[233] = -1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[281] = p[47]*x[14];

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[19] = -1/p[0];
out[38] = -1/p[0];
out[57] = -1/p[0];
out[76] = -1/p[0];
out[95] = -1/p[0];
out[263] = -p[46];
out[355] = -p[49];

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[206] = 1.0;
out[246] = -1.0;
out[392] = -1.0;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[51] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[287] = -(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15], 2);
out[304] = -(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2);

}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[94] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[95] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[96] = 2.0*p[20]*y[6] + y[4]*sin(x[0] - y[5]);
out[97] = 2.0*p[20]*y[7] + y[4]*cos(x[0] - y[5]);
out[314] = y[16];
out[315] = y[17];
out[316] = y[14];
out[317] = y[15];
out[344] = y[17];
out[345] = -y[16];
out[346] = -y[15];
out[347] = y[14];
out[481] = (y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/x[15];
out[502] = (y[24]*cos(y[1]) - y[25]*sin(y[1]))/x[15];
out[503] = (y[24]*sin(y[1]) + y[25]*cos(y[1]))/x[15];
out[504] = (y[22]*cos(y[1]) + y[23]*sin(y[1]))/x[15];
out[505] = (-y[22]*sin(y[1]) + y[23]*cos(y[1]))/x[15];
out[524] = y[16]/(x[15] + 9.9999999999999995e-7);
out[525] = y[17]/(x[15] + 9.9999999999999995e-7);
out[526] = y[14]/(x[15] + 9.9999999999999995e-7);
out[527] = y[15]/(x[15] + 9.9999999999999995e-7);

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[32] = 1.0;
out[64] = 1.0;
out[130] = 1.0;
out[162] = 1.0;
out[386] = 1.0;
out[417] = 1.0;
out[444] = 1.0;
out[475] = 1.0;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[115] = 1.0;
out[132] = 1.0;
out[178] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = ((x[14] > 0.20000000000000001 && fabs(u[15]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[9] < 0) ? (
   1.0
)
: (
   0
))/p[67];
out[8] = 0.5*((p[65]*pow(u[16], 3)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3)) < 0) ? (
   0
)
: (
   p[65]*pow(u[16], 3)*(p[56]*p[57]*p[63]*p[62]*x[13]*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*pow(u[16], 2)*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[56]*p[60]*p[63]*p[62]*x[13]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)))/(p[64]*pow(u[16], 2)*pow(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11], 2)) - p[61]*p[63]*p[62]*x[13]/(p[64]*pow(u[16], 2)))/(p[66]*pow(p[62], 3)) + 3.0*p[65]*pow(u[16], 2)*(p[56]*(p[57]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0)) - p[58]*x[11] - p[59])*exp(-p[60]*(1.0/(p[63]*p[62]*x[13]/(p[64]*u[16]) + 0.080000000000000002*x[11]) - 0.035000000000000003/(pow(x[11], 3) + 1.0))) + p[61]*p[63]*p[62]*x[13]/(p[64]*u[16]))/(p[66]*pow(p[62], 3))
))/p[42];

}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0/p[26];
out[1] = 1.0/p[26];
out[2] = p[23]*p[25]/(p[26]*p[27]);
out[3] = p[23]*p[25]/(p[26]*p[27]);
out[6] = 1.0/p[39];

}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 1.0;
out[7] = -1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[9] = p[47]*x[14];

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[1] = -1/p[0];
out[2] = -1/p[0];
out[3] = -1/p[0];
out[4] = -1/p[0];
out[5] = -1/p[0];
out[8] = -p[46];
out[10] = -p[49];

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[6] = 1.0;
out[7] = -1.0;
out[11] = -1.0;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = y[4]*y[6]*cos(x[0] - y[5]) - y[4]*y[7]*sin(x[0] - y[5]);
out[1] = -(y[24]*(y[22]*cos(y[1]) + y[23]*sin(y[1])) + y[25]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])))/pow(x[15], 2);
out[2] = -(y[16]*y[14] + y[17]*y[15])/pow(x[15] + 9.9999999999999995e-7, 2);

}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = y[6]*sin(x[0] - y[5]) + y[7]*cos(x[0] - y[5]);
out[4] = -y[4]*y[6]*cos(x[0] - y[5]) + y[4]*y[7]*sin(x[0] - y[5]);
out[5] = 2.0*p[20]*y[6] + y[4]*sin(x[0] - y[5]);
out[6] = 2.0*p[20]*y[7] + y[4]*cos(x[0] - y[5]);
out[9] = y[16];
out[10] = y[17];
out[11] = y[14];
out[12] = y[15];
out[13] = y[17];
out[14] = -y[16];
out[15] = -y[15];
out[16] = y[14];
out[21] = (y[24]*(-y[22]*sin(y[1]) + y[23]*cos(y[1])) + y[25]*(-y[22]*cos(y[1]) - y[23]*sin(y[1])))/x[15];
out[22] = (y[24]*cos(y[1]) - y[25]*sin(y[1]))/x[15];
out[23] = (y[24]*sin(y[1]) + y[25]*cos(y[1]))/x[15];
out[24] = (y[22]*cos(y[1]) + y[23]*sin(y[1]))/x[15];
out[25] = (-y[22]*sin(y[1]) + y[23]*cos(y[1]))/x[15];
out[26] = y[16]/(x[15] + 9.9999999999999995e-7);
out[27] = y[17]/(x[15] + 9.9999999999999995e-7);
out[28] = y[14]/(x[15] + 9.9999999999999995e-7);
out[29] = y[15]/(x[15] + 9.9999999999999995e-7);

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[2] = 1.0;
out[7] = 1.0;
out[8] = 1.0;
out[17] = 1.0;
out[18] = 1.0;
out[19] = 1.0;
out[20] = 1.0;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[2] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_wecs_pmsm_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_wecs_pmsm_cffi(void) { return NULL; }
#  else
     initwecs_pmsm_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_wecs_pmsm_cffi(void)
{
  return _cffi_init("wecs_pmsm_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
initwecs_pmsm_cffi(void)
{
  _cffi_init("wecs_pmsm_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
