#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1.0e-8*x[0]*(1 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
))) + (0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
));
out[1] = -p[27]*x[1] - y[49] + u[18] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[41];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[45];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[42];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[46];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[43];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[47];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[44];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[48];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[35];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[36];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[37];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[38];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[39];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[40];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[38] + y[16]*y[35] + 1.0*y[22]*y[39] + y[17]*y[36] + 1.0*y[23]*y[40] + 1.0*y[23]*u[1] + y[18]*y[37] + y[18]*u[0] - y[26];
out[27] = p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1) - y[27] - 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1) - y[26]/y[27])/(p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1));
out[28] = u[4]*(1.0 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
))) - y[28] + (0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26]))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
));
out[29] = -1.0*y[1]*y[32] - y[0]*y[29] + u[5] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[30] = -1.0*y[3]*y[33] - y[2]*y[30] + u[6] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[31] = -1.0*y[5]*y[34] - y[4]*y[31] + u[7] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[32] = -1.0*y[1]*y[29] + 1.0*y[0]*y[32] + u[9] + (1.0/3.0)*u[12];
out[33] = -1.0*y[3]*y[30] + 1.0*y[2]*y[33] + u[10] + (1.0/3.0)*u[12];
out[34] = -1.0*y[5]*y[31] + 1.0*y[4]*y[34] + u[11] + (1.0/3.0)*u[12];
out[35] = -p[1]*y[29] - y[0] + 1.0*p[0]*y[32] + y[35];
out[36] = -p[1]*y[30] - y[2] + 1.0*p[0]*y[33] + y[36];
out[37] = -p[1]*y[31] - y[4] + 1.0*p[0]*y[34] + y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[1] - p[0]*y[29] + 1.0*y[38];
out[39] = -1.0*p[1]*y[33] - 1.0*y[3] - p[0]*y[30] + 1.0*y[39];
out[40] = -1.0*p[1]*y[34] - 1.0*y[5] - p[0]*y[31] + 1.0*y[40];
out[41] = -p[20]*y[41] - y[8] + 1.0*p[19]*y[45] + u[13]*cos(u[17]);
out[42] = -p[20]*y[42] - y[10] + 1.0*p[19]*y[46] + u[14]*cos(u[17] - 2.0943951023931953);
out[43] = -p[20]*y[43] - y[12] + 1.0*p[19]*y[47] + u[15]*cos(u[17] - 4.1887902047863905);
out[44] = -p[22]*y[44] - y[14] + 1.0*p[21]*y[48];
out[45] = -1.0*p[20]*y[45] - 1.0*y[9] - 1.0*p[19]*y[41] + 1.0*u[13]*sin(u[17]);
out[46] = -1.0*p[20]*y[46] - 1.0*y[11] - 1.0*p[19]*y[42] + 1.0*u[14]*sin(u[17] - 2.0943951023931953);
out[47] = -1.0*p[20]*y[47] - 1.0*y[13] - 1.0*p[19]*y[43] + 1.0*u[15]*sin(u[17] - 4.1887902047863905);
out[48] = -1.0*p[22]*y[48] - 1.0*y[15] - 1.0*p[21]*y[44];
out[49] = 1.0 - y[49];
out[50] = p[26]*x[1] + p[25]*(1 - y[49]) - y[50];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1.0e-8*x[0]*(1 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
))) + (0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
));
out[1] = -p[27]*x[1] - y[49] + u[18] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[41];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[45];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[42];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[46];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[43];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[47];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[44];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[48];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[35];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[36];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[37];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[38];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[39];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[40];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[38] + y[16]*y[35] + 1.0*y[22]*y[39] + y[17]*y[36] + 1.0*y[23]*y[40] + 1.0*y[23]*u[1] + y[18]*y[37] + y[18]*u[0] - y[26];
out[27] = p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1) - y[27] - 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1) - y[26]/y[27])/(p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1));
out[28] = u[4]*(1.0 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
))) - y[28] + (0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26]))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0.0
)
: (
   1.0
));
out[29] = -1.0*y[1]*y[32] - y[0]*y[29] + u[5] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[30] = -1.0*y[3]*y[33] - y[2]*y[30] + u[6] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[31] = -1.0*y[5]*y[34] - y[4]*y[31] + u[7] + (1.0/3.0)*y[28] + (1.0/3.0)*u[8];
out[32] = -1.0*y[1]*y[29] + 1.0*y[0]*y[32] + u[9] + (1.0/3.0)*u[12];
out[33] = -1.0*y[3]*y[30] + 1.0*y[2]*y[33] + u[10] + (1.0/3.0)*u[12];
out[34] = -1.0*y[5]*y[31] + 1.0*y[4]*y[34] + u[11] + (1.0/3.0)*u[12];
out[35] = -p[1]*y[29] - y[0] + 1.0*p[0]*y[32] + y[35];
out[36] = -p[1]*y[30] - y[2] + 1.0*p[0]*y[33] + y[36];
out[37] = -p[1]*y[31] - y[4] + 1.0*p[0]*y[34] + y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[1] - p[0]*y[29] + 1.0*y[38];
out[39] = -1.0*p[1]*y[33] - 1.0*y[3] - p[0]*y[30] + 1.0*y[39];
out[40] = -1.0*p[1]*y[34] - 1.0*y[5] - p[0]*y[31] + 1.0*y[40];
out[41] = -p[20]*y[41] - y[8] + 1.0*p[19]*y[45] + u[13]*cos(u[17]);
out[42] = -p[20]*y[42] - y[10] + 1.0*p[19]*y[46] + u[14]*cos(u[17] - 2.0943951023931953);
out[43] = -p[20]*y[43] - y[12] + 1.0*p[19]*y[47] + u[15]*cos(u[17] - 4.1887902047863905);
out[44] = -p[22]*y[44] - y[14] + 1.0*p[21]*y[48];
out[45] = -1.0*p[20]*y[45] - 1.0*y[9] - 1.0*p[19]*y[41] + 1.0*u[13]*sin(u[17]);
out[46] = -1.0*p[20]*y[46] - 1.0*y[11] - 1.0*p[19]*y[42] + 1.0*u[14]*sin(u[17] - 2.0943951023931953);
out[47] = -1.0*p[20]*y[47] - 1.0*y[13] - 1.0*p[19]*y[43] + 1.0*u[15]*sin(u[17] - 4.1887902047863905);
out[48] = -1.0*p[22]*y[48] - 1.0*y[15] - 1.0*p[21]*y[44];
out[49] = 1.0 - y[49];
out[50] = p[26]*x[1] + p[25]*(1 - y[49]) - y[50];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14];
out[8] = sqrt(1.0*pow(y[21], 2) + pow(y[16], 2));
out[9] = sqrt(1.0*pow(y[22], 2) + pow(y[17], 2));
out[10] = sqrt(1.0*pow(y[23], 2) + pow(y[18], 2));
out[11] = sqrt(1.0*pow(y[24], 2) + pow(y[19], 2));
out[12] = 1.0*y[1]*y[21] + y[0]*y[16];
out[13] = 1.0*y[1]*y[16] - 1.0*y[0]*y[21];
out[14] = 1.0*y[3]*y[22] + y[2]*y[17];
out[15] = 1.0*y[3]*y[17] - 1.0*y[2]*y[22];
out[16] = 1.0*y[5]*y[23] + y[4]*y[18];
out[17] = 1.0*y[5]*y[18] - 1.0*y[4]*y[23];
out[18] = 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1);
out[19] = y[28];
out[20] = sqrt(1.0*pow(y[45], 2) + pow(y[41], 2));
out[21] = sqrt(1.0*pow(y[46], 2) + pow(y[42], 2));
out[22] = sqrt(1.0*pow(y[47], 2) + pow(y[43], 2));
out[23] = sqrt(1.0*pow(y[48], 2) + pow(y[44], 2));
out[24] = 1.0*y[9]*y[45] + y[8]*y[41] + 1.0*y[11]*y[46] + y[10]*y[42] + 1.0*y[13]*y[47] + y[12]*y[43];
out[25] = 1.0*y[9]*y[41] - 1.0*y[8]*y[45] + 1.0*y[11]*y[42] - 1.0*y[10]*y[46] + 1.0*y[13]*y[43] - 1.0*y[12]*y[47];
out[26] = x[1];
out[27] = u[18];

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8;
out[28] = -((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1502] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1503] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1504] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1505] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1507] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1508] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1509] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1510] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1521] = y[16];
out[1522] = y[17];
out[1523] = y[18];
out[1524] = 1.0*y[21];
out[1525] = 1.0*y[22];
out[1526] = 1.0*y[23];
out[1565] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1566] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1590] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1618] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1645] = -y[29];
out[1646] = -1.0*y[32];
out[1674] = -y[0];
out[1677] = -1.0*y[1];
out[1700] = -y[30];
out[1701] = -1.0*y[33];
out[1728] = -y[2];
out[1731] = -1.0*y[3];
out[1755] = -y[31];
out[1756] = -1.0*y[34];
out[1782] = -y[4];
out[1785] = -1.0*y[5];
out[1804] = 1.0*y[32];
out[1805] = -1.0*y[29];
out[1833] = -1.0*y[1];
out[1836] = 1.0*y[0];
out[1859] = 1.0*y[33];
out[1860] = -1.0*y[30];
out[1887] = -1.0*y[3];
out[1890] = 1.0*y[2];
out[1914] = 1.0*y[34];
out[1915] = -1.0*y[31];
out[1941] = -1.0*y[5];
out[1944] = 1.0*y[4];

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = -p[27];
out[972] = -p[1];
out[977] = 1.0*p[0];
out[1026] = -p[1];
out[1031] = 1.0*p[0];
out[1080] = -p[1];
out[1085] = 1.0*p[0];
out[1134] = -p[3];
out[1139] = 1.0*p[2];
out[1188] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1193] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1237] = -1.0*p[0];
out[1242] = -1.0*p[1];
out[1291] = -1.0*p[0];
out[1296] = -1.0*p[1];
out[1345] = -1.0*p[0];
out[1350] = -1.0*p[1];
out[1399] = -1.0*p[2];
out[1404] = -1.0*p[3];
out[1453] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1458] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1992] = -p[1];
out[1995] = 1.0*p[0];
out[2046] = -p[1];
out[2049] = 1.0*p[0];
out[2100] = -p[1];
out[2103] = 1.0*p[0];
out[2151] = -p[0];
out[2154] = -1.0*p[1];
out[2205] = -p[0];
out[2208] = -1.0*p[1];
out[2259] = -p[0];
out[2262] = -1.0*p[1];
out[2322] = -p[20];
out[2326] = 1.0*p[19];
out[2376] = -p[20];
out[2380] = 1.0*p[19];
out[2430] = -p[20];
out[2434] = 1.0*p[19];
out[2484] = -p[22];
out[2488] = 1.0*p[21];
out[2534] = -1.0*p[19];
out[2538] = -1.0*p[20];
out[2588] = -1.0*p[19];
out[2592] = -1.0*p[20];
out[2642] = -1.0*p[19];
out[2646] = -1.0*p[20];
out[2696] = -1.0*p[21];
out[2700] = -1.0*p[22];
out[2757] = p[26];
out[2807] = -p[25];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[104] = -1.0;
out[108] = 184.75059629806526;
out[109] = 94.615102344455664;
out[110] = -69.368640085185305;
out[111] = -17.974903844364835;
out[112] = -43.675799641021079;
out[113] = -40.748687841669557;
out[114] = -69.368640085185291;
out[115] = -17.974903844364821;
out[116] = -184.75059629806526;
out[117] = -94.615102344455664;
out[118] = 69.368640085185305;
out[119] = 17.974903844364835;
out[120] = 43.675799641021079;
out[121] = 40.748687841669557;
out[122] = 69.368640085185291;
out[123] = 17.974903844364821;
out[124] = -1.0;
out[161] = -94.615102344455664;
out[162] = 184.75059629806526;
out[163] = 17.974903844364835;
out[164] = -69.368640085185305;
out[165] = 40.748687841669557;
out[166] = -43.675799641021079;
out[167] = 17.974903844364821;
out[168] = -69.368640085185291;
out[169] = 94.615102344455664;
out[170] = -184.75059629806526;
out[171] = -17.974903844364835;
out[172] = 69.368640085185305;
out[173] = -40.748687841669557;
out[174] = 43.675799641021079;
out[175] = -17.974903844364821;
out[176] = 69.368640085185291;
out[182] = -1.0;
out[214] = -69.368640085185291;
out[215] = -17.974903844364825;
out[216] = 184.7505962980652;
out[217] = 94.615102344455636;
out[218] = -69.368640085185319;
out[219] = -17.97490384436481;
out[220] = -43.675799641021079;
out[221] = -40.748687841669565;
out[222] = 69.368640085185291;
out[223] = 17.974903844364825;
out[224] = -184.7505962980652;
out[225] = -94.615102344455636;
out[226] = 69.368640085185319;
out[227] = 17.97490384436481;
out[228] = 43.675799641021079;
out[229] = 40.748687841669565;
out[231] = -1.0;
out[267] = 17.974903844364825;
out[268] = -69.368640085185291;
out[269] = -94.615102344455636;
out[270] = 184.7505962980652;
out[271] = 17.97490384436481;
out[272] = -69.368640085185319;
out[273] = 40.748687841669565;
out[274] = -43.675799641021079;
out[275] = -17.974903844364825;
out[276] = 69.368640085185291;
out[277] = 94.615102344455636;
out[278] = -184.7505962980652;
out[279] = -17.97490384436481;
out[280] = 69.368640085185319;
out[281] = -40.748687841669565;
out[282] = 43.675799641021079;
out[289] = -1.0;
out[320] = -43.675799641021101;
out[321] = -40.748687841669579;
out[322] = -69.368640085185305;
out[323] = -17.974903844364821;
out[324] = 184.75059629806526;
out[325] = 94.61510234445565;
out[326] = -69.368640085185305;
out[327] = -17.974903844364821;
out[328] = 43.675799641021101;
out[329] = 40.748687841669579;
out[330] = 69.368640085185305;
out[331] = 17.974903844364821;
out[332] = -184.75059629806526;
out[333] = -94.61510234445565;
out[334] = 69.368640085185305;
out[335] = 17.974903844364821;
out[338] = -1.0;
out[373] = 40.748687841669579;
out[374] = -43.675799641021101;
out[375] = 17.974903844364821;
out[376] = -69.368640085185305;
out[377] = -94.61510234445565;
out[378] = 184.75059629806526;
out[379] = 17.974903844364821;
out[380] = -69.368640085185305;
out[381] = -40.748687841669579;
out[382] = 43.675799641021101;
out[383] = -17.974903844364821;
out[384] = 69.368640085185305;
out[385] = 94.61510234445565;
out[386] = -184.75059629806526;
out[387] = -17.974903844364821;
out[388] = 69.368640085185305;
out[396] = -1.0;
out[426] = -69.368640085185305;
out[427] = -17.974903844364825;
out[428] = -43.675799641021079;
out[429] = -40.74868784166955;
out[430] = -69.368640085185291;
out[431] = -17.974903844364839;
out[432] = 184.7505962980652;
out[433] = 94.61510234445565;
out[434] = 69.368640085185305;
out[435] = 17.974903844364825;
out[436] = 43.675799641021079;
out[437] = 40.74868784166955;
out[438] = 69.368640085185291;
out[439] = 17.974903844364839;
out[440] = -184.7505962980652;
out[441] = -94.61510234445565;
out[445] = -1.0;
out[479] = 17.974903844364825;
out[480] = -69.368640085185305;
out[481] = 40.74868784166955;
out[482] = -43.675799641021079;
out[483] = 17.974903844364839;
out[484] = -69.368640085185291;
out[485] = -94.61510234445565;
out[486] = 184.7505962980652;
out[487] = -17.974903844364825;
out[488] = 69.368640085185305;
out[489] = -40.74868784166955;
out[490] = 43.675799641021079;
out[491] = -17.974903844364839;
out[492] = 69.368640085185291;
out[493] = 94.61510234445565;
out[494] = -184.7505962980652;
out[503] = -1.0;
out[532] = -184.75059629806526;
out[533] = -94.615102344455664;
out[534] = 69.368640085185305;
out[535] = 17.974903844364835;
out[536] = 43.675799641021079;
out[537] = 40.748687841669557;
out[538] = 69.368640085185291;
out[539] = 17.974903844364821;
out[540] = 184.75059629806526;
out[541] = 94.615102344455664;
out[542] = -69.368640085185305;
out[543] = -17.974903844364835;
out[544] = -43.675799641021079;
out[545] = -40.748687841669557;
out[546] = -69.368640085185291;
out[547] = -17.974903844364821;
out[573] = -1.0;
out[585] = 94.615102344455664;
out[586] = -184.75059629806526;
out[587] = -17.974903844364835;
out[588] = 69.368640085185305;
out[589] = -40.748687841669557;
out[590] = 43.675799641021079;
out[591] = -17.974903844364821;
out[592] = 69.368640085185291;
out[593] = -94.615102344455664;
out[594] = 184.75059629806526;
out[595] = 17.974903844364835;
out[596] = -69.368640085185305;
out[597] = 40.748687841669557;
out[598] = -43.675799641021079;
out[599] = 17.974903844364821;
out[600] = -69.368640085185291;
out[630] = -1.0;
out[638] = 69.368640085185291;
out[639] = 17.974903844364825;
out[640] = -184.7505962980652;
out[641] = -94.615102344455636;
out[642] = 69.368640085185319;
out[643] = 17.97490384436481;
out[644] = 43.675799641021079;
out[645] = 40.748687841669565;
out[646] = -69.368640085185291;
out[647] = -17.974903844364825;
out[648] = 184.7505962980652;
out[649] = 94.615102344455636;
out[650] = -69.368640085185319;
out[651] = -17.97490384436481;
out[652] = -43.675799641021079;
out[653] = -40.748687841669565;
out[680] = -1.0;
out[691] = -17.974903844364825;
out[692] = 69.368640085185291;
out[693] = 94.615102344455636;
out[694] = -184.7505962980652;
out[695] = -17.97490384436481;
out[696] = 69.368640085185319;
out[697] = -40.748687841669565;
out[698] = 43.675799641021079;
out[699] = 17.974903844364825;
out[700] = -69.368640085185291;
out[701] = -94.615102344455636;
out[702] = 184.7505962980652;
out[703] = 17.97490384436481;
out[704] = -69.368640085185319;
out[705] = 40.748687841669565;
out[706] = -43.675799641021079;
out[737] = -1.0;
out[744] = 43.675799641021101;
out[745] = 40.748687841669579;
out[746] = 69.368640085185305;
out[747] = 17.974903844364821;
out[748] = -184.75059629806526;
out[749] = -94.61510234445565;
out[750] = 69.368640085185305;
out[751] = 17.974903844364821;
out[752] = -43.675799641021101;
out[753] = -40.748687841669579;
out[754] = -69.368640085185305;
out[755] = -17.974903844364821;
out[756] = 184.75059629806526;
out[757] = 94.61510234445565;
out[758] = -69.368640085185305;
out[759] = -17.974903844364821;
out[787] = -1.0;
out[797] = -40.748687841669579;
out[798] = 43.675799641021101;
out[799] = -17.974903844364821;
out[800] = 69.368640085185305;
out[801] = 94.61510234445565;
out[802] = -184.75059629806526;
out[803] = -17.974903844364821;
out[804] = 69.368640085185305;
out[805] = 40.748687841669579;
out[806] = -43.675799641021101;
out[807] = 17.974903844364821;
out[808] = -69.368640085185305;
out[809] = -94.61510234445565;
out[810] = 184.75059629806526;
out[811] = 17.974903844364821;
out[812] = -69.368640085185305;
out[844] = -1.0;
out[850] = 69.368640085185305;
out[851] = 17.974903844364825;
out[852] = 43.675799641021079;
out[853] = 40.74868784166955;
out[854] = 69.368640085185291;
out[855] = 17.974903844364839;
out[856] = -184.7505962980652;
out[857] = -94.61510234445565;
out[858] = -69.368640085185305;
out[859] = -17.974903844364825;
out[860] = -43.675799641021079;
out[861] = -40.74868784166955;
out[862] = -69.368640085185291;
out[863] = -17.974903844364839;
out[864] = 184.7505962980652;
out[865] = 94.61510234445565;
out[894] = -1.0;
out[903] = -17.974903844364825;
out[904] = 69.368640085185305;
out[905] = -40.74868784166955;
out[906] = 43.675799641021079;
out[907] = -17.974903844364839;
out[908] = 69.368640085185291;
out[909] = 94.61510234445565;
out[910] = -184.7505962980652;
out[911] = 17.974903844364825;
out[912] = -69.368640085185305;
out[913] = 40.74868784166955;
out[914] = -43.675799641021079;
out[915] = 17.974903844364839;
out[916] = -69.368640085185291;
out[917] = -94.61510234445565;
out[918] = 184.7505962980652;
out[951] = -1.0;
out[956] = -1.0;
out[976] = 1.0;
out[991] = 1.0;
out[1011] = -1.0;
out[1029] = 1.0;
out[1045] = 1.0;
out[1066] = -1.0;
out[1082] = 1.0;
out[1099] = 1.0;
out[1121] = -1.0;
out[1135] = 1.0;
out[1184] = 1.0;
out[1185] = 1.0;
out[1186] = 1.0;
out[1187] = 1.0;
out[1222] = -1.0;
out[1246] = 1.0;
out[1259] = 1.0;
out[1277] = -1.0;
out[1299] = 1.0;
out[1313] = 1.0;
out[1332] = -1.0;
out[1352] = 1.0;
out[1367] = 1.0;
out[1387] = -1.0;
out[1405] = 1.0;
out[1454] = 1.0;
out[1455] = 1.0;
out[1456] = 1.0;
out[1457] = 1.0;
out[1512] = -1.0;
out[1620] = -1.0;
out[1673] = 0.33333333333333331;
out[1726] = 0.33333333333333331;
out[1779] = 0.33333333333333331;
out[1963] = -1.0;
out[1998] = 1.0;
out[2018] = -1.0;
out[2052] = 1.0;
out[2073] = -1.0;
out[2106] = 1.0;
out[2123] = -1.0;
out[2160] = 1.0;
out[2178] = -1.0;
out[2214] = 1.0;
out[2233] = -1.0;
out[2268] = 1.0;
out[2289] = -1.0;
out[2344] = -1.0;
out[2399] = -1.0;
out[2454] = -1.0;
out[2502] = -1.0;
out[2557] = -1.0;
out[2612] = -1.0;
out[2667] = -1.0;
out[2754] = -1.0;
out[2808] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8;
out[1] = -((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[326] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[327] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[328] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[329] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[330] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[331] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[332] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[333] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[335] = y[16];
out[336] = y[17];
out[337] = y[18];
out[338] = 1.0*y[21];
out[339] = 1.0*y[22];
out[340] = 1.0*y[23];
out[341] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[342] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[343] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[344] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[346] = -y[29];
out[347] = -1.0*y[32];
out[349] = -y[0];
out[350] = -1.0*y[1];
out[351] = -y[30];
out[352] = -1.0*y[33];
out[354] = -y[2];
out[355] = -1.0*y[3];
out[356] = -y[31];
out[357] = -1.0*y[34];
out[359] = -y[4];
out[360] = -1.0*y[5];
out[361] = 1.0*y[32];
out[362] = -1.0*y[29];
out[363] = -1.0*y[1];
out[364] = 1.0*y[0];
out[365] = 1.0*y[33];
out[366] = -1.0*y[30];
out[367] = -1.0*y[3];
out[368] = 1.0*y[2];
out[369] = 1.0*y[34];
out[370] = -1.0*y[31];
out[371] = -1.0*y[5];
out[372] = 1.0*y[4];

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = -p[27];
out[277] = -p[1];
out[279] = 1.0*p[0];
out[282] = -p[1];
out[284] = 1.0*p[0];
out[287] = -p[1];
out[289] = 1.0*p[0];
out[292] = -p[3];
out[294] = 1.0*p[2];
out[299] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[302] = -1.0*p[0];
out[303] = -1.0*p[1];
out[307] = -1.0*p[0];
out[308] = -1.0*p[1];
out[312] = -1.0*p[0];
out[313] = -1.0*p[1];
out[317] = -1.0*p[2];
out[318] = -1.0*p[3];
out[320] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[325] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = -p[1];
out[375] = 1.0*p[0];
out[378] = -p[1];
out[379] = 1.0*p[0];
out[382] = -p[1];
out[383] = 1.0*p[0];
out[386] = -p[0];
out[387] = -1.0*p[1];
out[390] = -p[0];
out[391] = -1.0*p[1];
out[394] = -p[0];
out[395] = -1.0*p[1];
out[398] = -p[20];
out[399] = 1.0*p[19];
out[401] = -p[20];
out[402] = 1.0*p[19];
out[404] = -p[20];
out[405] = 1.0*p[19];
out[407] = -p[22];
out[408] = 1.0*p[21];
out[410] = -1.0*p[19];
out[411] = -1.0*p[20];
out[413] = -1.0*p[19];
out[414] = -1.0*p[20];
out[416] = -1.0*p[19];
out[417] = -1.0*p[20];
out[419] = -1.0*p[21];
out[420] = -1.0*p[22];
out[422] = p[26];
out[423] = -p[25];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -1.0;
out[4] = 184.75059629806526;
out[5] = 94.615102344455664;
out[6] = -69.368640085185305;
out[7] = -17.974903844364835;
out[8] = -43.675799641021079;
out[9] = -40.748687841669557;
out[10] = -69.368640085185291;
out[11] = -17.974903844364821;
out[12] = -184.75059629806526;
out[13] = -94.615102344455664;
out[14] = 69.368640085185305;
out[15] = 17.974903844364835;
out[16] = 43.675799641021079;
out[17] = 40.748687841669557;
out[18] = 69.368640085185291;
out[19] = 17.974903844364821;
out[20] = -1.0;
out[21] = -94.615102344455664;
out[22] = 184.75059629806526;
out[23] = 17.974903844364835;
out[24] = -69.368640085185305;
out[25] = 40.748687841669557;
out[26] = -43.675799641021079;
out[27] = 17.974903844364821;
out[28] = -69.368640085185291;
out[29] = 94.615102344455664;
out[30] = -184.75059629806526;
out[31] = -17.974903844364835;
out[32] = 69.368640085185305;
out[33] = -40.748687841669557;
out[34] = 43.675799641021079;
out[35] = -17.974903844364821;
out[36] = 69.368640085185291;
out[37] = -1.0;
out[38] = -69.368640085185291;
out[39] = -17.974903844364825;
out[40] = 184.7505962980652;
out[41] = 94.615102344455636;
out[42] = -69.368640085185319;
out[43] = -17.97490384436481;
out[44] = -43.675799641021079;
out[45] = -40.748687841669565;
out[46] = 69.368640085185291;
out[47] = 17.974903844364825;
out[48] = -184.7505962980652;
out[49] = -94.615102344455636;
out[50] = 69.368640085185319;
out[51] = 17.97490384436481;
out[52] = 43.675799641021079;
out[53] = 40.748687841669565;
out[54] = -1.0;
out[55] = 17.974903844364825;
out[56] = -69.368640085185291;
out[57] = -94.615102344455636;
out[58] = 184.7505962980652;
out[59] = 17.97490384436481;
out[60] = -69.368640085185319;
out[61] = 40.748687841669565;
out[62] = -43.675799641021079;
out[63] = -17.974903844364825;
out[64] = 69.368640085185291;
out[65] = 94.615102344455636;
out[66] = -184.7505962980652;
out[67] = -17.97490384436481;
out[68] = 69.368640085185319;
out[69] = -40.748687841669565;
out[70] = 43.675799641021079;
out[71] = -1.0;
out[72] = -43.675799641021101;
out[73] = -40.748687841669579;
out[74] = -69.368640085185305;
out[75] = -17.974903844364821;
out[76] = 184.75059629806526;
out[77] = 94.61510234445565;
out[78] = -69.368640085185305;
out[79] = -17.974903844364821;
out[80] = 43.675799641021101;
out[81] = 40.748687841669579;
out[82] = 69.368640085185305;
out[83] = 17.974903844364821;
out[84] = -184.75059629806526;
out[85] = -94.61510234445565;
out[86] = 69.368640085185305;
out[87] = 17.974903844364821;
out[88] = -1.0;
out[89] = 40.748687841669579;
out[90] = -43.675799641021101;
out[91] = 17.974903844364821;
out[92] = -69.368640085185305;
out[93] = -94.61510234445565;
out[94] = 184.75059629806526;
out[95] = 17.974903844364821;
out[96] = -69.368640085185305;
out[97] = -40.748687841669579;
out[98] = 43.675799641021101;
out[99] = -17.974903844364821;
out[100] = 69.368640085185305;
out[101] = 94.61510234445565;
out[102] = -184.75059629806526;
out[103] = -17.974903844364821;
out[104] = 69.368640085185305;
out[105] = -1.0;
out[106] = -69.368640085185305;
out[107] = -17.974903844364825;
out[108] = -43.675799641021079;
out[109] = -40.74868784166955;
out[110] = -69.368640085185291;
out[111] = -17.974903844364839;
out[112] = 184.7505962980652;
out[113] = 94.61510234445565;
out[114] = 69.368640085185305;
out[115] = 17.974903844364825;
out[116] = 43.675799641021079;
out[117] = 40.74868784166955;
out[118] = 69.368640085185291;
out[119] = 17.974903844364839;
out[120] = -184.7505962980652;
out[121] = -94.61510234445565;
out[122] = -1.0;
out[123] = 17.974903844364825;
out[124] = -69.368640085185305;
out[125] = 40.74868784166955;
out[126] = -43.675799641021079;
out[127] = 17.974903844364839;
out[128] = -69.368640085185291;
out[129] = -94.61510234445565;
out[130] = 184.7505962980652;
out[131] = -17.974903844364825;
out[132] = 69.368640085185305;
out[133] = -40.74868784166955;
out[134] = 43.675799641021079;
out[135] = -17.974903844364839;
out[136] = 69.368640085185291;
out[137] = 94.61510234445565;
out[138] = -184.7505962980652;
out[139] = -1.0;
out[140] = -184.75059629806526;
out[141] = -94.615102344455664;
out[142] = 69.368640085185305;
out[143] = 17.974903844364835;
out[144] = 43.675799641021079;
out[145] = 40.748687841669557;
out[146] = 69.368640085185291;
out[147] = 17.974903844364821;
out[148] = 184.75059629806526;
out[149] = 94.615102344455664;
out[150] = -69.368640085185305;
out[151] = -17.974903844364835;
out[152] = -43.675799641021079;
out[153] = -40.748687841669557;
out[154] = -69.368640085185291;
out[155] = -17.974903844364821;
out[156] = -1.0;
out[157] = 94.615102344455664;
out[158] = -184.75059629806526;
out[159] = -17.974903844364835;
out[160] = 69.368640085185305;
out[161] = -40.748687841669557;
out[162] = 43.675799641021079;
out[163] = -17.974903844364821;
out[164] = 69.368640085185291;
out[165] = -94.615102344455664;
out[166] = 184.75059629806526;
out[167] = 17.974903844364835;
out[168] = -69.368640085185305;
out[169] = 40.748687841669557;
out[170] = -43.675799641021079;
out[171] = 17.974903844364821;
out[172] = -69.368640085185291;
out[173] = -1.0;
out[174] = 69.368640085185291;
out[175] = 17.974903844364825;
out[176] = -184.7505962980652;
out[177] = -94.615102344455636;
out[178] = 69.368640085185319;
out[179] = 17.97490384436481;
out[180] = 43.675799641021079;
out[181] = 40.748687841669565;
out[182] = -69.368640085185291;
out[183] = -17.974903844364825;
out[184] = 184.7505962980652;
out[185] = 94.615102344455636;
out[186] = -69.368640085185319;
out[187] = -17.97490384436481;
out[188] = -43.675799641021079;
out[189] = -40.748687841669565;
out[190] = -1.0;
out[191] = -17.974903844364825;
out[192] = 69.368640085185291;
out[193] = 94.615102344455636;
out[194] = -184.7505962980652;
out[195] = -17.97490384436481;
out[196] = 69.368640085185319;
out[197] = -40.748687841669565;
out[198] = 43.675799641021079;
out[199] = 17.974903844364825;
out[200] = -69.368640085185291;
out[201] = -94.615102344455636;
out[202] = 184.7505962980652;
out[203] = 17.97490384436481;
out[204] = -69.368640085185319;
out[205] = 40.748687841669565;
out[206] = -43.675799641021079;
out[207] = -1.0;
out[208] = 43.675799641021101;
out[209] = 40.748687841669579;
out[210] = 69.368640085185305;
out[211] = 17.974903844364821;
out[212] = -184.75059629806526;
out[213] = -94.61510234445565;
out[214] = 69.368640085185305;
out[215] = 17.974903844364821;
out[216] = -43.675799641021101;
out[217] = -40.748687841669579;
out[218] = -69.368640085185305;
out[219] = -17.974903844364821;
out[220] = 184.75059629806526;
out[221] = 94.61510234445565;
out[222] = -69.368640085185305;
out[223] = -17.974903844364821;
out[224] = -1.0;
out[225] = -40.748687841669579;
out[226] = 43.675799641021101;
out[227] = -17.974903844364821;
out[228] = 69.368640085185305;
out[229] = 94.61510234445565;
out[230] = -184.75059629806526;
out[231] = -17.974903844364821;
out[232] = 69.368640085185305;
out[233] = 40.748687841669579;
out[234] = -43.675799641021101;
out[235] = 17.974903844364821;
out[236] = -69.368640085185305;
out[237] = -94.61510234445565;
out[238] = 184.75059629806526;
out[239] = 17.974903844364821;
out[240] = -69.368640085185305;
out[241] = -1.0;
out[242] = 69.368640085185305;
out[243] = 17.974903844364825;
out[244] = 43.675799641021079;
out[245] = 40.74868784166955;
out[246] = 69.368640085185291;
out[247] = 17.974903844364839;
out[248] = -184.7505962980652;
out[249] = -94.61510234445565;
out[250] = -69.368640085185305;
out[251] = -17.974903844364825;
out[252] = -43.675799641021079;
out[253] = -40.74868784166955;
out[254] = -69.368640085185291;
out[255] = -17.974903844364839;
out[256] = 184.7505962980652;
out[257] = 94.61510234445565;
out[258] = -1.0;
out[259] = -17.974903844364825;
out[260] = 69.368640085185305;
out[261] = -40.74868784166955;
out[262] = 43.675799641021079;
out[263] = -17.974903844364839;
out[264] = 69.368640085185291;
out[265] = 94.61510234445565;
out[266] = -184.7505962980652;
out[267] = 17.974903844364825;
out[268] = -69.368640085185305;
out[269] = 40.74868784166955;
out[270] = -43.675799641021079;
out[271] = 17.974903844364839;
out[272] = -69.368640085185291;
out[273] = -94.61510234445565;
out[274] = 184.7505962980652;
out[275] = -1.0;
out[276] = -1.0;
out[278] = 1.0;
out[280] = 1.0;
out[281] = -1.0;
out[283] = 1.0;
out[285] = 1.0;
out[286] = -1.0;
out[288] = 1.0;
out[290] = 1.0;
out[291] = -1.0;
out[293] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[297] = 1.0;
out[298] = 1.0;
out[301] = -1.0;
out[304] = 1.0;
out[305] = 1.0;
out[306] = -1.0;
out[309] = 1.0;
out[310] = 1.0;
out[311] = -1.0;
out[314] = 1.0;
out[315] = 1.0;
out[316] = -1.0;
out[319] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[323] = 1.0;
out[324] = 1.0;
out[334] = -1.0;
out[345] = -1.0;
out[348] = 0.33333333333333331;
out[353] = 0.33333333333333331;
out[358] = 0.33333333333333331;
out[373] = -1.0;
out[376] = 1.0;
out[377] = -1.0;
out[380] = 1.0;
out[381] = -1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = -1.0;
out[392] = 1.0;
out[393] = -1.0;
out[396] = 1.0;
out[397] = -1.0;
out[400] = -1.0;
out[403] = -1.0;
out[406] = -1.0;
out[409] = -1.0;
out[412] = -1.0;
out[415] = -1.0;
out[418] = -1.0;
out[421] = -1.0;
out[424] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8;
out[28] = -((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1502] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1503] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1504] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1505] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1507] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1508] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1509] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1510] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1521] = y[16];
out[1522] = y[17];
out[1523] = y[18];
out[1524] = 1.0*y[21];
out[1525] = 1.0*y[22];
out[1526] = 1.0*y[23];
out[1565] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1566] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1590] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1618] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1645] = -y[29];
out[1646] = -1.0*y[32];
out[1674] = -y[0];
out[1677] = -1.0*y[1];
out[1700] = -y[30];
out[1701] = -1.0*y[33];
out[1728] = -y[2];
out[1731] = -1.0*y[3];
out[1755] = -y[31];
out[1756] = -1.0*y[34];
out[1782] = -y[4];
out[1785] = -1.0*y[5];
out[1804] = 1.0*y[32];
out[1805] = -1.0*y[29];
out[1833] = -1.0*y[1];
out[1836] = 1.0*y[0];
out[1859] = 1.0*y[33];
out[1860] = -1.0*y[30];
out[1887] = -1.0*y[3];
out[1890] = 1.0*y[2];
out[1914] = 1.0*y[34];
out[1915] = -1.0*y[31];
out[1941] = -1.0*y[5];
out[1944] = 1.0*y[4];

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = -p[27];
out[972] = -p[1];
out[977] = 1.0*p[0];
out[1026] = -p[1];
out[1031] = 1.0*p[0];
out[1080] = -p[1];
out[1085] = 1.0*p[0];
out[1134] = -p[3];
out[1139] = 1.0*p[2];
out[1188] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1193] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1237] = -1.0*p[0];
out[1242] = -1.0*p[1];
out[1291] = -1.0*p[0];
out[1296] = -1.0*p[1];
out[1345] = -1.0*p[0];
out[1350] = -1.0*p[1];
out[1399] = -1.0*p[2];
out[1404] = -1.0*p[3];
out[1453] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1458] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1992] = -p[1];
out[1995] = 1.0*p[0];
out[2046] = -p[1];
out[2049] = 1.0*p[0];
out[2100] = -p[1];
out[2103] = 1.0*p[0];
out[2151] = -p[0];
out[2154] = -1.0*p[1];
out[2205] = -p[0];
out[2208] = -1.0*p[1];
out[2259] = -p[0];
out[2262] = -1.0*p[1];
out[2322] = -p[20];
out[2326] = 1.0*p[19];
out[2376] = -p[20];
out[2380] = 1.0*p[19];
out[2430] = -p[20];
out[2434] = 1.0*p[19];
out[2484] = -p[22];
out[2488] = 1.0*p[21];
out[2534] = -1.0*p[19];
out[2538] = -1.0*p[20];
out[2588] = -1.0*p[19];
out[2592] = -1.0*p[20];
out[2642] = -1.0*p[19];
out[2646] = -1.0*p[20];
out[2696] = -1.0*p[21];
out[2700] = -1.0*p[22];
out[2757] = p[26];
out[2807] = -p[25];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[104] = -1.0;
out[108] = 184.75059629806526;
out[109] = 94.615102344455664;
out[110] = -69.368640085185305;
out[111] = -17.974903844364835;
out[112] = -43.675799641021079;
out[113] = -40.748687841669557;
out[114] = -69.368640085185291;
out[115] = -17.974903844364821;
out[116] = -184.75059629806526;
out[117] = -94.615102344455664;
out[118] = 69.368640085185305;
out[119] = 17.974903844364835;
out[120] = 43.675799641021079;
out[121] = 40.748687841669557;
out[122] = 69.368640085185291;
out[123] = 17.974903844364821;
out[124] = -1.0;
out[161] = -94.615102344455664;
out[162] = 184.75059629806526;
out[163] = 17.974903844364835;
out[164] = -69.368640085185305;
out[165] = 40.748687841669557;
out[166] = -43.675799641021079;
out[167] = 17.974903844364821;
out[168] = -69.368640085185291;
out[169] = 94.615102344455664;
out[170] = -184.75059629806526;
out[171] = -17.974903844364835;
out[172] = 69.368640085185305;
out[173] = -40.748687841669557;
out[174] = 43.675799641021079;
out[175] = -17.974903844364821;
out[176] = 69.368640085185291;
out[182] = -1.0;
out[214] = -69.368640085185291;
out[215] = -17.974903844364825;
out[216] = 184.7505962980652;
out[217] = 94.615102344455636;
out[218] = -69.368640085185319;
out[219] = -17.97490384436481;
out[220] = -43.675799641021079;
out[221] = -40.748687841669565;
out[222] = 69.368640085185291;
out[223] = 17.974903844364825;
out[224] = -184.7505962980652;
out[225] = -94.615102344455636;
out[226] = 69.368640085185319;
out[227] = 17.97490384436481;
out[228] = 43.675799641021079;
out[229] = 40.748687841669565;
out[231] = -1.0;
out[267] = 17.974903844364825;
out[268] = -69.368640085185291;
out[269] = -94.615102344455636;
out[270] = 184.7505962980652;
out[271] = 17.97490384436481;
out[272] = -69.368640085185319;
out[273] = 40.748687841669565;
out[274] = -43.675799641021079;
out[275] = -17.974903844364825;
out[276] = 69.368640085185291;
out[277] = 94.615102344455636;
out[278] = -184.7505962980652;
out[279] = -17.97490384436481;
out[280] = 69.368640085185319;
out[281] = -40.748687841669565;
out[282] = 43.675799641021079;
out[289] = -1.0;
out[320] = -43.675799641021101;
out[321] = -40.748687841669579;
out[322] = -69.368640085185305;
out[323] = -17.974903844364821;
out[324] = 184.75059629806526;
out[325] = 94.61510234445565;
out[326] = -69.368640085185305;
out[327] = -17.974903844364821;
out[328] = 43.675799641021101;
out[329] = 40.748687841669579;
out[330] = 69.368640085185305;
out[331] = 17.974903844364821;
out[332] = -184.75059629806526;
out[333] = -94.61510234445565;
out[334] = 69.368640085185305;
out[335] = 17.974903844364821;
out[338] = -1.0;
out[373] = 40.748687841669579;
out[374] = -43.675799641021101;
out[375] = 17.974903844364821;
out[376] = -69.368640085185305;
out[377] = -94.61510234445565;
out[378] = 184.75059629806526;
out[379] = 17.974903844364821;
out[380] = -69.368640085185305;
out[381] = -40.748687841669579;
out[382] = 43.675799641021101;
out[383] = -17.974903844364821;
out[384] = 69.368640085185305;
out[385] = 94.61510234445565;
out[386] = -184.75059629806526;
out[387] = -17.974903844364821;
out[388] = 69.368640085185305;
out[396] = -1.0;
out[426] = -69.368640085185305;
out[427] = -17.974903844364825;
out[428] = -43.675799641021079;
out[429] = -40.74868784166955;
out[430] = -69.368640085185291;
out[431] = -17.974903844364839;
out[432] = 184.7505962980652;
out[433] = 94.61510234445565;
out[434] = 69.368640085185305;
out[435] = 17.974903844364825;
out[436] = 43.675799641021079;
out[437] = 40.74868784166955;
out[438] = 69.368640085185291;
out[439] = 17.974903844364839;
out[440] = -184.7505962980652;
out[441] = -94.61510234445565;
out[445] = -1.0;
out[479] = 17.974903844364825;
out[480] = -69.368640085185305;
out[481] = 40.74868784166955;
out[482] = -43.675799641021079;
out[483] = 17.974903844364839;
out[484] = -69.368640085185291;
out[485] = -94.61510234445565;
out[486] = 184.7505962980652;
out[487] = -17.974903844364825;
out[488] = 69.368640085185305;
out[489] = -40.74868784166955;
out[490] = 43.675799641021079;
out[491] = -17.974903844364839;
out[492] = 69.368640085185291;
out[493] = 94.61510234445565;
out[494] = -184.7505962980652;
out[503] = -1.0;
out[532] = -184.75059629806526;
out[533] = -94.615102344455664;
out[534] = 69.368640085185305;
out[535] = 17.974903844364835;
out[536] = 43.675799641021079;
out[537] = 40.748687841669557;
out[538] = 69.368640085185291;
out[539] = 17.974903844364821;
out[540] = 184.75059629806526;
out[541] = 94.615102344455664;
out[542] = -69.368640085185305;
out[543] = -17.974903844364835;
out[544] = -43.675799641021079;
out[545] = -40.748687841669557;
out[546] = -69.368640085185291;
out[547] = -17.974903844364821;
out[573] = -1.0;
out[585] = 94.615102344455664;
out[586] = -184.75059629806526;
out[587] = -17.974903844364835;
out[588] = 69.368640085185305;
out[589] = -40.748687841669557;
out[590] = 43.675799641021079;
out[591] = -17.974903844364821;
out[592] = 69.368640085185291;
out[593] = -94.615102344455664;
out[594] = 184.75059629806526;
out[595] = 17.974903844364835;
out[596] = -69.368640085185305;
out[597] = 40.748687841669557;
out[598] = -43.675799641021079;
out[599] = 17.974903844364821;
out[600] = -69.368640085185291;
out[630] = -1.0;
out[638] = 69.368640085185291;
out[639] = 17.974903844364825;
out[640] = -184.7505962980652;
out[641] = -94.615102344455636;
out[642] = 69.368640085185319;
out[643] = 17.97490384436481;
out[644] = 43.675799641021079;
out[645] = 40.748687841669565;
out[646] = -69.368640085185291;
out[647] = -17.974903844364825;
out[648] = 184.7505962980652;
out[649] = 94.615102344455636;
out[650] = -69.368640085185319;
out[651] = -17.97490384436481;
out[652] = -43.675799641021079;
out[653] = -40.748687841669565;
out[680] = -1.0;
out[691] = -17.974903844364825;
out[692] = 69.368640085185291;
out[693] = 94.615102344455636;
out[694] = -184.7505962980652;
out[695] = -17.97490384436481;
out[696] = 69.368640085185319;
out[697] = -40.748687841669565;
out[698] = 43.675799641021079;
out[699] = 17.974903844364825;
out[700] = -69.368640085185291;
out[701] = -94.615102344455636;
out[702] = 184.7505962980652;
out[703] = 17.97490384436481;
out[704] = -69.368640085185319;
out[705] = 40.748687841669565;
out[706] = -43.675799641021079;
out[737] = -1.0;
out[744] = 43.675799641021101;
out[745] = 40.748687841669579;
out[746] = 69.368640085185305;
out[747] = 17.974903844364821;
out[748] = -184.75059629806526;
out[749] = -94.61510234445565;
out[750] = 69.368640085185305;
out[751] = 17.974903844364821;
out[752] = -43.675799641021101;
out[753] = -40.748687841669579;
out[754] = -69.368640085185305;
out[755] = -17.974903844364821;
out[756] = 184.75059629806526;
out[757] = 94.61510234445565;
out[758] = -69.368640085185305;
out[759] = -17.974903844364821;
out[787] = -1.0;
out[797] = -40.748687841669579;
out[798] = 43.675799641021101;
out[799] = -17.974903844364821;
out[800] = 69.368640085185305;
out[801] = 94.61510234445565;
out[802] = -184.75059629806526;
out[803] = -17.974903844364821;
out[804] = 69.368640085185305;
out[805] = 40.748687841669579;
out[806] = -43.675799641021101;
out[807] = 17.974903844364821;
out[808] = -69.368640085185305;
out[809] = -94.61510234445565;
out[810] = 184.75059629806526;
out[811] = 17.974903844364821;
out[812] = -69.368640085185305;
out[844] = -1.0;
out[850] = 69.368640085185305;
out[851] = 17.974903844364825;
out[852] = 43.675799641021079;
out[853] = 40.74868784166955;
out[854] = 69.368640085185291;
out[855] = 17.974903844364839;
out[856] = -184.7505962980652;
out[857] = -94.61510234445565;
out[858] = -69.368640085185305;
out[859] = -17.974903844364825;
out[860] = -43.675799641021079;
out[861] = -40.74868784166955;
out[862] = -69.368640085185291;
out[863] = -17.974903844364839;
out[864] = 184.7505962980652;
out[865] = 94.61510234445565;
out[894] = -1.0;
out[903] = -17.974903844364825;
out[904] = 69.368640085185305;
out[905] = -40.74868784166955;
out[906] = 43.675799641021079;
out[907] = -17.974903844364839;
out[908] = 69.368640085185291;
out[909] = 94.61510234445565;
out[910] = -184.7505962980652;
out[911] = 17.974903844364825;
out[912] = -69.368640085185305;
out[913] = 40.74868784166955;
out[914] = -43.675799641021079;
out[915] = 17.974903844364839;
out[916] = -69.368640085185291;
out[917] = -94.61510234445565;
out[918] = 184.7505962980652;
out[951] = -1.0;
out[956] = -1.0;
out[976] = 1.0;
out[991] = 1.0;
out[1011] = -1.0;
out[1029] = 1.0;
out[1045] = 1.0;
out[1066] = -1.0;
out[1082] = 1.0;
out[1099] = 1.0;
out[1121] = -1.0;
out[1135] = 1.0;
out[1184] = 1.0;
out[1185] = 1.0;
out[1186] = 1.0;
out[1187] = 1.0;
out[1222] = -1.0;
out[1246] = 1.0;
out[1259] = 1.0;
out[1277] = -1.0;
out[1299] = 1.0;
out[1313] = 1.0;
out[1332] = -1.0;
out[1352] = 1.0;
out[1367] = 1.0;
out[1387] = -1.0;
out[1405] = 1.0;
out[1454] = 1.0;
out[1455] = 1.0;
out[1456] = 1.0;
out[1457] = 1.0;
out[1512] = -1.0;
out[1620] = -1.0;
out[1673] = 0.33333333333333331;
out[1726] = 0.33333333333333331;
out[1779] = 0.33333333333333331;
out[1963] = -1.0;
out[1998] = 1.0;
out[2018] = -1.0;
out[2052] = 1.0;
out[2073] = -1.0;
out[2106] = 1.0;
out[2123] = -1.0;
out[2160] = 1.0;
out[2178] = -1.0;
out[2214] = 1.0;
out[2233] = -1.0;
out[2268] = 1.0;
out[2289] = -1.0;
out[2344] = -1.0;
out[2399] = -1.0;
out[2454] = -1.0;
out[2502] = -1.0;
out[2557] = -1.0;
out[2612] = -1.0;
out[2667] = -1.0;
out[2754] = -1.0;
out[2808] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8;
out[1] = -((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[326] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[327] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[328] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[329] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[330] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[331] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[332] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[333] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[335] = y[16];
out[336] = y[17];
out[337] = y[18];
out[338] = 1.0*y[21];
out[339] = 1.0*y[22];
out[340] = 1.0*y[23];
out[341] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[342] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[343] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[344] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[346] = -y[29];
out[347] = -1.0*y[32];
out[349] = -y[0];
out[350] = -1.0*y[1];
out[351] = -y[30];
out[352] = -1.0*y[33];
out[354] = -y[2];
out[355] = -1.0*y[3];
out[356] = -y[31];
out[357] = -1.0*y[34];
out[359] = -y[4];
out[360] = -1.0*y[5];
out[361] = 1.0*y[32];
out[362] = -1.0*y[29];
out[363] = -1.0*y[1];
out[364] = 1.0*y[0];
out[365] = 1.0*y[33];
out[366] = -1.0*y[30];
out[367] = -1.0*y[3];
out[368] = 1.0*y[2];
out[369] = 1.0*y[34];
out[370] = -1.0*y[31];
out[371] = -1.0*y[5];
out[372] = 1.0*y[4];

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = -p[27];
out[277] = -p[1];
out[279] = 1.0*p[0];
out[282] = -p[1];
out[284] = 1.0*p[0];
out[287] = -p[1];
out[289] = 1.0*p[0];
out[292] = -p[3];
out[294] = 1.0*p[2];
out[299] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[302] = -1.0*p[0];
out[303] = -1.0*p[1];
out[307] = -1.0*p[0];
out[308] = -1.0*p[1];
out[312] = -1.0*p[0];
out[313] = -1.0*p[1];
out[317] = -1.0*p[2];
out[318] = -1.0*p[3];
out[320] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[325] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = -p[1];
out[375] = 1.0*p[0];
out[378] = -p[1];
out[379] = 1.0*p[0];
out[382] = -p[1];
out[383] = 1.0*p[0];
out[386] = -p[0];
out[387] = -1.0*p[1];
out[390] = -p[0];
out[391] = -1.0*p[1];
out[394] = -p[0];
out[395] = -1.0*p[1];
out[398] = -p[20];
out[399] = 1.0*p[19];
out[401] = -p[20];
out[402] = 1.0*p[19];
out[404] = -p[20];
out[405] = 1.0*p[19];
out[407] = -p[22];
out[408] = 1.0*p[21];
out[410] = -1.0*p[19];
out[411] = -1.0*p[20];
out[413] = -1.0*p[19];
out[414] = -1.0*p[20];
out[416] = -1.0*p[19];
out[417] = -1.0*p[20];
out[419] = -1.0*p[21];
out[420] = -1.0*p[22];
out[422] = p[26];
out[423] = -p[25];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -1.0;
out[4] = 184.75059629806526;
out[5] = 94.615102344455664;
out[6] = -69.368640085185305;
out[7] = -17.974903844364835;
out[8] = -43.675799641021079;
out[9] = -40.748687841669557;
out[10] = -69.368640085185291;
out[11] = -17.974903844364821;
out[12] = -184.75059629806526;
out[13] = -94.615102344455664;
out[14] = 69.368640085185305;
out[15] = 17.974903844364835;
out[16] = 43.675799641021079;
out[17] = 40.748687841669557;
out[18] = 69.368640085185291;
out[19] = 17.974903844364821;
out[20] = -1.0;
out[21] = -94.615102344455664;
out[22] = 184.75059629806526;
out[23] = 17.974903844364835;
out[24] = -69.368640085185305;
out[25] = 40.748687841669557;
out[26] = -43.675799641021079;
out[27] = 17.974903844364821;
out[28] = -69.368640085185291;
out[29] = 94.615102344455664;
out[30] = -184.75059629806526;
out[31] = -17.974903844364835;
out[32] = 69.368640085185305;
out[33] = -40.748687841669557;
out[34] = 43.675799641021079;
out[35] = -17.974903844364821;
out[36] = 69.368640085185291;
out[37] = -1.0;
out[38] = -69.368640085185291;
out[39] = -17.974903844364825;
out[40] = 184.7505962980652;
out[41] = 94.615102344455636;
out[42] = -69.368640085185319;
out[43] = -17.97490384436481;
out[44] = -43.675799641021079;
out[45] = -40.748687841669565;
out[46] = 69.368640085185291;
out[47] = 17.974903844364825;
out[48] = -184.7505962980652;
out[49] = -94.615102344455636;
out[50] = 69.368640085185319;
out[51] = 17.97490384436481;
out[52] = 43.675799641021079;
out[53] = 40.748687841669565;
out[54] = -1.0;
out[55] = 17.974903844364825;
out[56] = -69.368640085185291;
out[57] = -94.615102344455636;
out[58] = 184.7505962980652;
out[59] = 17.97490384436481;
out[60] = -69.368640085185319;
out[61] = 40.748687841669565;
out[62] = -43.675799641021079;
out[63] = -17.974903844364825;
out[64] = 69.368640085185291;
out[65] = 94.615102344455636;
out[66] = -184.7505962980652;
out[67] = -17.97490384436481;
out[68] = 69.368640085185319;
out[69] = -40.748687841669565;
out[70] = 43.675799641021079;
out[71] = -1.0;
out[72] = -43.675799641021101;
out[73] = -40.748687841669579;
out[74] = -69.368640085185305;
out[75] = -17.974903844364821;
out[76] = 184.75059629806526;
out[77] = 94.61510234445565;
out[78] = -69.368640085185305;
out[79] = -17.974903844364821;
out[80] = 43.675799641021101;
out[81] = 40.748687841669579;
out[82] = 69.368640085185305;
out[83] = 17.974903844364821;
out[84] = -184.75059629806526;
out[85] = -94.61510234445565;
out[86] = 69.368640085185305;
out[87] = 17.974903844364821;
out[88] = -1.0;
out[89] = 40.748687841669579;
out[90] = -43.675799641021101;
out[91] = 17.974903844364821;
out[92] = -69.368640085185305;
out[93] = -94.61510234445565;
out[94] = 184.75059629806526;
out[95] = 17.974903844364821;
out[96] = -69.368640085185305;
out[97] = -40.748687841669579;
out[98] = 43.675799641021101;
out[99] = -17.974903844364821;
out[100] = 69.368640085185305;
out[101] = 94.61510234445565;
out[102] = -184.75059629806526;
out[103] = -17.974903844364821;
out[104] = 69.368640085185305;
out[105] = -1.0;
out[106] = -69.368640085185305;
out[107] = -17.974903844364825;
out[108] = -43.675799641021079;
out[109] = -40.74868784166955;
out[110] = -69.368640085185291;
out[111] = -17.974903844364839;
out[112] = 184.7505962980652;
out[113] = 94.61510234445565;
out[114] = 69.368640085185305;
out[115] = 17.974903844364825;
out[116] = 43.675799641021079;
out[117] = 40.74868784166955;
out[118] = 69.368640085185291;
out[119] = 17.974903844364839;
out[120] = -184.7505962980652;
out[121] = -94.61510234445565;
out[122] = -1.0;
out[123] = 17.974903844364825;
out[124] = -69.368640085185305;
out[125] = 40.74868784166955;
out[126] = -43.675799641021079;
out[127] = 17.974903844364839;
out[128] = -69.368640085185291;
out[129] = -94.61510234445565;
out[130] = 184.7505962980652;
out[131] = -17.974903844364825;
out[132] = 69.368640085185305;
out[133] = -40.74868784166955;
out[134] = 43.675799641021079;
out[135] = -17.974903844364839;
out[136] = 69.368640085185291;
out[137] = 94.61510234445565;
out[138] = -184.7505962980652;
out[139] = -1.0;
out[140] = -184.75059629806526;
out[141] = -94.615102344455664;
out[142] = 69.368640085185305;
out[143] = 17.974903844364835;
out[144] = 43.675799641021079;
out[145] = 40.748687841669557;
out[146] = 69.368640085185291;
out[147] = 17.974903844364821;
out[148] = 184.75059629806526;
out[149] = 94.615102344455664;
out[150] = -69.368640085185305;
out[151] = -17.974903844364835;
out[152] = -43.675799641021079;
out[153] = -40.748687841669557;
out[154] = -69.368640085185291;
out[155] = -17.974903844364821;
out[156] = -1.0;
out[157] = 94.615102344455664;
out[158] = -184.75059629806526;
out[159] = -17.974903844364835;
out[160] = 69.368640085185305;
out[161] = -40.748687841669557;
out[162] = 43.675799641021079;
out[163] = -17.974903844364821;
out[164] = 69.368640085185291;
out[165] = -94.615102344455664;
out[166] = 184.75059629806526;
out[167] = 17.974903844364835;
out[168] = -69.368640085185305;
out[169] = 40.748687841669557;
out[170] = -43.675799641021079;
out[171] = 17.974903844364821;
out[172] = -69.368640085185291;
out[173] = -1.0;
out[174] = 69.368640085185291;
out[175] = 17.974903844364825;
out[176] = -184.7505962980652;
out[177] = -94.615102344455636;
out[178] = 69.368640085185319;
out[179] = 17.97490384436481;
out[180] = 43.675799641021079;
out[181] = 40.748687841669565;
out[182] = -69.368640085185291;
out[183] = -17.974903844364825;
out[184] = 184.7505962980652;
out[185] = 94.615102344455636;
out[186] = -69.368640085185319;
out[187] = -17.97490384436481;
out[188] = -43.675799641021079;
out[189] = -40.748687841669565;
out[190] = -1.0;
out[191] = -17.974903844364825;
out[192] = 69.368640085185291;
out[193] = 94.615102344455636;
out[194] = -184.7505962980652;
out[195] = -17.97490384436481;
out[196] = 69.368640085185319;
out[197] = -40.748687841669565;
out[198] = 43.675799641021079;
out[199] = 17.974903844364825;
out[200] = -69.368640085185291;
out[201] = -94.615102344455636;
out[202] = 184.7505962980652;
out[203] = 17.97490384436481;
out[204] = -69.368640085185319;
out[205] = 40.748687841669565;
out[206] = -43.675799641021079;
out[207] = -1.0;
out[208] = 43.675799641021101;
out[209] = 40.748687841669579;
out[210] = 69.368640085185305;
out[211] = 17.974903844364821;
out[212] = -184.75059629806526;
out[213] = -94.61510234445565;
out[214] = 69.368640085185305;
out[215] = 17.974903844364821;
out[216] = -43.675799641021101;
out[217] = -40.748687841669579;
out[218] = -69.368640085185305;
out[219] = -17.974903844364821;
out[220] = 184.75059629806526;
out[221] = 94.61510234445565;
out[222] = -69.368640085185305;
out[223] = -17.974903844364821;
out[224] = -1.0;
out[225] = -40.748687841669579;
out[226] = 43.675799641021101;
out[227] = -17.974903844364821;
out[228] = 69.368640085185305;
out[229] = 94.61510234445565;
out[230] = -184.75059629806526;
out[231] = -17.974903844364821;
out[232] = 69.368640085185305;
out[233] = 40.748687841669579;
out[234] = -43.675799641021101;
out[235] = 17.974903844364821;
out[236] = -69.368640085185305;
out[237] = -94.61510234445565;
out[238] = 184.75059629806526;
out[239] = 17.974903844364821;
out[240] = -69.368640085185305;
out[241] = -1.0;
out[242] = 69.368640085185305;
out[243] = 17.974903844364825;
out[244] = 43.675799641021079;
out[245] = 40.74868784166955;
out[246] = 69.368640085185291;
out[247] = 17.974903844364839;
out[248] = -184.7505962980652;
out[249] = -94.61510234445565;
out[250] = -69.368640085185305;
out[251] = -17.974903844364825;
out[252] = -43.675799641021079;
out[253] = -40.74868784166955;
out[254] = -69.368640085185291;
out[255] = -17.974903844364839;
out[256] = 184.7505962980652;
out[257] = 94.61510234445565;
out[258] = -1.0;
out[259] = -17.974903844364825;
out[260] = 69.368640085185305;
out[261] = -40.74868784166955;
out[262] = 43.675799641021079;
out[263] = -17.974903844364839;
out[264] = 69.368640085185291;
out[265] = 94.61510234445565;
out[266] = -184.7505962980652;
out[267] = 17.974903844364825;
out[268] = -69.368640085185305;
out[269] = 40.74868784166955;
out[270] = -43.675799641021079;
out[271] = 17.974903844364839;
out[272] = -69.368640085185291;
out[273] = -94.61510234445565;
out[274] = 184.7505962980652;
out[275] = -1.0;
out[276] = -1.0;
out[278] = 1.0;
out[280] = 1.0;
out[281] = -1.0;
out[283] = 1.0;
out[285] = 1.0;
out[286] = -1.0;
out[288] = 1.0;
out[290] = 1.0;
out[291] = -1.0;
out[293] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[297] = 1.0;
out[298] = 1.0;
out[301] = -1.0;
out[304] = 1.0;
out[305] = 1.0;
out[306] = -1.0;
out[309] = 1.0;
out[310] = 1.0;
out[311] = -1.0;
out[314] = 1.0;
out[315] = 1.0;
out[316] = -1.0;
out[319] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[323] = 1.0;
out[324] = 1.0;
out[334] = -1.0;
out[345] = -1.0;
out[348] = 0.33333333333333331;
out[353] = 0.33333333333333331;
out[358] = 0.33333333333333331;
out[373] = -1.0;
out[376] = 1.0;
out[377] = -1.0;
out[380] = 1.0;
out[381] = -1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = -1.0;
out[392] = 1.0;
out[393] = -1.0;
out[396] = 1.0;
out[397] = -1.0;
out[400] = -1.0;
out[403] = -1.0;
out[406] = -1.0;
out[409] = -1.0;
out[412] = -1.0;
out[415] = -1.0;
out[418] = -1.0;
out[421] = -1.0;
out[424] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -0.5*Dt*(1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8) + 1.0;
out[28] = 0.5*Dt*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1502] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1503] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1504] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1505] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1507] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1508] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1509] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1510] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1521] = y[16];
out[1522] = y[17];
out[1523] = y[18];
out[1524] = 1.0*y[21];
out[1525] = 1.0*y[22];
out[1526] = 1.0*y[23];
out[1565] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1566] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[1590] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1618] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1645] = -y[29];
out[1646] = -1.0*y[32];
out[1674] = -y[0];
out[1677] = -1.0*y[1];
out[1700] = -y[30];
out[1701] = -1.0*y[33];
out[1728] = -y[2];
out[1731] = -1.0*y[3];
out[1755] = -y[31];
out[1756] = -1.0*y[34];
out[1782] = -y[4];
out[1785] = -1.0*y[5];
out[1804] = 1.0*y[32];
out[1805] = -1.0*y[29];
out[1833] = -1.0*y[1];
out[1836] = 1.0*y[0];
out[1859] = 1.0*y[33];
out[1860] = -1.0*y[30];
out[1887] = -1.0*y[3];
out[1890] = 1.0*y[2];
out[1914] = 1.0*y[34];
out[1915] = -1.0*y[31];
out[1941] = -1.0*y[5];
out[1944] = 1.0*y[4];

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = 0.5*Dt*p[27] + 1.0;
out[104] = 0.5*Dt;
out[972] = -p[1];
out[977] = 1.0*p[0];
out[1026] = -p[1];
out[1031] = 1.0*p[0];
out[1080] = -p[1];
out[1085] = 1.0*p[0];
out[1134] = -p[3];
out[1139] = 1.0*p[2];
out[1188] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1193] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1237] = -1.0*p[0];
out[1242] = -1.0*p[1];
out[1291] = -1.0*p[0];
out[1296] = -1.0*p[1];
out[1345] = -1.0*p[0];
out[1350] = -1.0*p[1];
out[1399] = -1.0*p[2];
out[1404] = -1.0*p[3];
out[1453] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1458] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1992] = -p[1];
out[1995] = 1.0*p[0];
out[2046] = -p[1];
out[2049] = 1.0*p[0];
out[2100] = -p[1];
out[2103] = 1.0*p[0];
out[2151] = -p[0];
out[2154] = -1.0*p[1];
out[2205] = -p[0];
out[2208] = -1.0*p[1];
out[2259] = -p[0];
out[2262] = -1.0*p[1];
out[2322] = -p[20];
out[2326] = 1.0*p[19];
out[2376] = -p[20];
out[2380] = 1.0*p[19];
out[2430] = -p[20];
out[2434] = 1.0*p[19];
out[2484] = -p[22];
out[2488] = 1.0*p[21];
out[2534] = -1.0*p[19];
out[2538] = -1.0*p[20];
out[2588] = -1.0*p[19];
out[2592] = -1.0*p[20];
out[2642] = -1.0*p[19];
out[2646] = -1.0*p[20];
out[2696] = -1.0*p[21];
out[2700] = -1.0*p[22];
out[2757] = p[26];
out[2807] = -p[25];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[108] = 184.75059629806526;
out[109] = 94.615102344455664;
out[110] = -69.368640085185305;
out[111] = -17.974903844364835;
out[112] = -43.675799641021079;
out[113] = -40.748687841669557;
out[114] = -69.368640085185291;
out[115] = -17.974903844364821;
out[116] = -184.75059629806526;
out[117] = -94.615102344455664;
out[118] = 69.368640085185305;
out[119] = 17.974903844364835;
out[120] = 43.675799641021079;
out[121] = 40.748687841669557;
out[122] = 69.368640085185291;
out[123] = 17.974903844364821;
out[124] = -1.0;
out[161] = -94.615102344455664;
out[162] = 184.75059629806526;
out[163] = 17.974903844364835;
out[164] = -69.368640085185305;
out[165] = 40.748687841669557;
out[166] = -43.675799641021079;
out[167] = 17.974903844364821;
out[168] = -69.368640085185291;
out[169] = 94.615102344455664;
out[170] = -184.75059629806526;
out[171] = -17.974903844364835;
out[172] = 69.368640085185305;
out[173] = -40.748687841669557;
out[174] = 43.675799641021079;
out[175] = -17.974903844364821;
out[176] = 69.368640085185291;
out[182] = -1.0;
out[214] = -69.368640085185291;
out[215] = -17.974903844364825;
out[216] = 184.7505962980652;
out[217] = 94.615102344455636;
out[218] = -69.368640085185319;
out[219] = -17.97490384436481;
out[220] = -43.675799641021079;
out[221] = -40.748687841669565;
out[222] = 69.368640085185291;
out[223] = 17.974903844364825;
out[224] = -184.7505962980652;
out[225] = -94.615102344455636;
out[226] = 69.368640085185319;
out[227] = 17.97490384436481;
out[228] = 43.675799641021079;
out[229] = 40.748687841669565;
out[231] = -1.0;
out[267] = 17.974903844364825;
out[268] = -69.368640085185291;
out[269] = -94.615102344455636;
out[270] = 184.7505962980652;
out[271] = 17.97490384436481;
out[272] = -69.368640085185319;
out[273] = 40.748687841669565;
out[274] = -43.675799641021079;
out[275] = -17.974903844364825;
out[276] = 69.368640085185291;
out[277] = 94.615102344455636;
out[278] = -184.7505962980652;
out[279] = -17.97490384436481;
out[280] = 69.368640085185319;
out[281] = -40.748687841669565;
out[282] = 43.675799641021079;
out[289] = -1.0;
out[320] = -43.675799641021101;
out[321] = -40.748687841669579;
out[322] = -69.368640085185305;
out[323] = -17.974903844364821;
out[324] = 184.75059629806526;
out[325] = 94.61510234445565;
out[326] = -69.368640085185305;
out[327] = -17.974903844364821;
out[328] = 43.675799641021101;
out[329] = 40.748687841669579;
out[330] = 69.368640085185305;
out[331] = 17.974903844364821;
out[332] = -184.75059629806526;
out[333] = -94.61510234445565;
out[334] = 69.368640085185305;
out[335] = 17.974903844364821;
out[338] = -1.0;
out[373] = 40.748687841669579;
out[374] = -43.675799641021101;
out[375] = 17.974903844364821;
out[376] = -69.368640085185305;
out[377] = -94.61510234445565;
out[378] = 184.75059629806526;
out[379] = 17.974903844364821;
out[380] = -69.368640085185305;
out[381] = -40.748687841669579;
out[382] = 43.675799641021101;
out[383] = -17.974903844364821;
out[384] = 69.368640085185305;
out[385] = 94.61510234445565;
out[386] = -184.75059629806526;
out[387] = -17.974903844364821;
out[388] = 69.368640085185305;
out[396] = -1.0;
out[426] = -69.368640085185305;
out[427] = -17.974903844364825;
out[428] = -43.675799641021079;
out[429] = -40.74868784166955;
out[430] = -69.368640085185291;
out[431] = -17.974903844364839;
out[432] = 184.7505962980652;
out[433] = 94.61510234445565;
out[434] = 69.368640085185305;
out[435] = 17.974903844364825;
out[436] = 43.675799641021079;
out[437] = 40.74868784166955;
out[438] = 69.368640085185291;
out[439] = 17.974903844364839;
out[440] = -184.7505962980652;
out[441] = -94.61510234445565;
out[445] = -1.0;
out[479] = 17.974903844364825;
out[480] = -69.368640085185305;
out[481] = 40.74868784166955;
out[482] = -43.675799641021079;
out[483] = 17.974903844364839;
out[484] = -69.368640085185291;
out[485] = -94.61510234445565;
out[486] = 184.7505962980652;
out[487] = -17.974903844364825;
out[488] = 69.368640085185305;
out[489] = -40.74868784166955;
out[490] = 43.675799641021079;
out[491] = -17.974903844364839;
out[492] = 69.368640085185291;
out[493] = 94.61510234445565;
out[494] = -184.7505962980652;
out[503] = -1.0;
out[532] = -184.75059629806526;
out[533] = -94.615102344455664;
out[534] = 69.368640085185305;
out[535] = 17.974903844364835;
out[536] = 43.675799641021079;
out[537] = 40.748687841669557;
out[538] = 69.368640085185291;
out[539] = 17.974903844364821;
out[540] = 184.75059629806526;
out[541] = 94.615102344455664;
out[542] = -69.368640085185305;
out[543] = -17.974903844364835;
out[544] = -43.675799641021079;
out[545] = -40.748687841669557;
out[546] = -69.368640085185291;
out[547] = -17.974903844364821;
out[573] = -1.0;
out[585] = 94.615102344455664;
out[586] = -184.75059629806526;
out[587] = -17.974903844364835;
out[588] = 69.368640085185305;
out[589] = -40.748687841669557;
out[590] = 43.675799641021079;
out[591] = -17.974903844364821;
out[592] = 69.368640085185291;
out[593] = -94.615102344455664;
out[594] = 184.75059629806526;
out[595] = 17.974903844364835;
out[596] = -69.368640085185305;
out[597] = 40.748687841669557;
out[598] = -43.675799641021079;
out[599] = 17.974903844364821;
out[600] = -69.368640085185291;
out[630] = -1.0;
out[638] = 69.368640085185291;
out[639] = 17.974903844364825;
out[640] = -184.7505962980652;
out[641] = -94.615102344455636;
out[642] = 69.368640085185319;
out[643] = 17.97490384436481;
out[644] = 43.675799641021079;
out[645] = 40.748687841669565;
out[646] = -69.368640085185291;
out[647] = -17.974903844364825;
out[648] = 184.7505962980652;
out[649] = 94.615102344455636;
out[650] = -69.368640085185319;
out[651] = -17.97490384436481;
out[652] = -43.675799641021079;
out[653] = -40.748687841669565;
out[680] = -1.0;
out[691] = -17.974903844364825;
out[692] = 69.368640085185291;
out[693] = 94.615102344455636;
out[694] = -184.7505962980652;
out[695] = -17.97490384436481;
out[696] = 69.368640085185319;
out[697] = -40.748687841669565;
out[698] = 43.675799641021079;
out[699] = 17.974903844364825;
out[700] = -69.368640085185291;
out[701] = -94.615102344455636;
out[702] = 184.7505962980652;
out[703] = 17.97490384436481;
out[704] = -69.368640085185319;
out[705] = 40.748687841669565;
out[706] = -43.675799641021079;
out[737] = -1.0;
out[744] = 43.675799641021101;
out[745] = 40.748687841669579;
out[746] = 69.368640085185305;
out[747] = 17.974903844364821;
out[748] = -184.75059629806526;
out[749] = -94.61510234445565;
out[750] = 69.368640085185305;
out[751] = 17.974903844364821;
out[752] = -43.675799641021101;
out[753] = -40.748687841669579;
out[754] = -69.368640085185305;
out[755] = -17.974903844364821;
out[756] = 184.75059629806526;
out[757] = 94.61510234445565;
out[758] = -69.368640085185305;
out[759] = -17.974903844364821;
out[787] = -1.0;
out[797] = -40.748687841669579;
out[798] = 43.675799641021101;
out[799] = -17.974903844364821;
out[800] = 69.368640085185305;
out[801] = 94.61510234445565;
out[802] = -184.75059629806526;
out[803] = -17.974903844364821;
out[804] = 69.368640085185305;
out[805] = 40.748687841669579;
out[806] = -43.675799641021101;
out[807] = 17.974903844364821;
out[808] = -69.368640085185305;
out[809] = -94.61510234445565;
out[810] = 184.75059629806526;
out[811] = 17.974903844364821;
out[812] = -69.368640085185305;
out[844] = -1.0;
out[850] = 69.368640085185305;
out[851] = 17.974903844364825;
out[852] = 43.675799641021079;
out[853] = 40.74868784166955;
out[854] = 69.368640085185291;
out[855] = 17.974903844364839;
out[856] = -184.7505962980652;
out[857] = -94.61510234445565;
out[858] = -69.368640085185305;
out[859] = -17.974903844364825;
out[860] = -43.675799641021079;
out[861] = -40.74868784166955;
out[862] = -69.368640085185291;
out[863] = -17.974903844364839;
out[864] = 184.7505962980652;
out[865] = 94.61510234445565;
out[894] = -1.0;
out[903] = -17.974903844364825;
out[904] = 69.368640085185305;
out[905] = -40.74868784166955;
out[906] = 43.675799641021079;
out[907] = -17.974903844364839;
out[908] = 69.368640085185291;
out[909] = 94.61510234445565;
out[910] = -184.7505962980652;
out[911] = 17.974903844364825;
out[912] = -69.368640085185305;
out[913] = 40.74868784166955;
out[914] = -43.675799641021079;
out[915] = 17.974903844364839;
out[916] = -69.368640085185291;
out[917] = -94.61510234445565;
out[918] = 184.7505962980652;
out[951] = -1.0;
out[956] = -1.0;
out[976] = 1.0;
out[991] = 1.0;
out[1011] = -1.0;
out[1029] = 1.0;
out[1045] = 1.0;
out[1066] = -1.0;
out[1082] = 1.0;
out[1099] = 1.0;
out[1121] = -1.0;
out[1135] = 1.0;
out[1184] = 1.0;
out[1185] = 1.0;
out[1186] = 1.0;
out[1187] = 1.0;
out[1222] = -1.0;
out[1246] = 1.0;
out[1259] = 1.0;
out[1277] = -1.0;
out[1299] = 1.0;
out[1313] = 1.0;
out[1332] = -1.0;
out[1352] = 1.0;
out[1367] = 1.0;
out[1387] = -1.0;
out[1405] = 1.0;
out[1454] = 1.0;
out[1455] = 1.0;
out[1456] = 1.0;
out[1457] = 1.0;
out[1512] = -1.0;
out[1620] = -1.0;
out[1673] = 0.33333333333333331;
out[1726] = 0.33333333333333331;
out[1779] = 0.33333333333333331;
out[1963] = -1.0;
out[1998] = 1.0;
out[2018] = -1.0;
out[2052] = 1.0;
out[2073] = -1.0;
out[2106] = 1.0;
out[2123] = -1.0;
out[2160] = 1.0;
out[2178] = -1.0;
out[2214] = 1.0;
out[2233] = -1.0;
out[2268] = 1.0;
out[2289] = -1.0;
out[2344] = -1.0;
out[2399] = -1.0;
out[2454] = -1.0;
out[2502] = -1.0;
out[2557] = -1.0;
out[2612] = -1.0;
out[2667] = -1.0;
out[2754] = -1.0;
out[2808] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -0.5*Dt*(1.0e-8*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
)) - 1.0e-8) + 1.0;
out[1] = 0.5*Dt*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[326] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[327] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[328] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[329] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[330] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[331] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[332] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[333] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[335] = y[16];
out[336] = y[17];
out[337] = y[18];
out[338] = 1.0*y[21];
out[339] = 1.0*y[22];
out[340] = 1.0*y[23];
out[341] = 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*y[27]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[342] = -1.0 - 1000.0*y[26]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(p[10]*p[16]*u[2]*pow(y[27], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[343] = p[18]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[344] = -p[17]*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[346] = -y[29];
out[347] = -1.0*y[32];
out[349] = -y[0];
out[350] = -1.0*y[1];
out[351] = -y[30];
out[352] = -1.0*y[33];
out[354] = -y[2];
out[355] = -1.0*y[3];
out[356] = -y[31];
out[357] = -1.0*y[34];
out[359] = -y[4];
out[360] = -1.0*y[5];
out[361] = 1.0*y[32];
out[362] = -1.0*y[29];
out[363] = -1.0*y[1];
out[364] = 1.0*y[0];
out[365] = 1.0*y[33];
out[366] = -1.0*y[30];
out[367] = -1.0*y[3];
out[368] = 1.0*y[2];
out[369] = 1.0*y[34];
out[370] = -1.0*y[31];
out[371] = -1.0*y[5];
out[372] = 1.0*y[4];

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = 0.5*Dt*p[27] + 1.0;
out[3] = 0.5*Dt;
out[277] = -p[1];
out[279] = 1.0*p[0];
out[282] = -p[1];
out[284] = 1.0*p[0];
out[287] = -p[1];
out[289] = 1.0*p[0];
out[292] = -p[3];
out[294] = 1.0*p[2];
out[299] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[302] = -1.0*p[0];
out[303] = -1.0*p[1];
out[307] = -1.0*p[0];
out[308] = -1.0*p[1];
out[312] = -1.0*p[0];
out[313] = -1.0*p[1];
out[317] = -1.0*p[2];
out[318] = -1.0*p[3];
out[320] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[325] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = -p[1];
out[375] = 1.0*p[0];
out[378] = -p[1];
out[379] = 1.0*p[0];
out[382] = -p[1];
out[383] = 1.0*p[0];
out[386] = -p[0];
out[387] = -1.0*p[1];
out[390] = -p[0];
out[391] = -1.0*p[1];
out[394] = -p[0];
out[395] = -1.0*p[1];
out[398] = -p[20];
out[399] = 1.0*p[19];
out[401] = -p[20];
out[402] = 1.0*p[19];
out[404] = -p[20];
out[405] = 1.0*p[19];
out[407] = -p[22];
out[408] = 1.0*p[21];
out[410] = -1.0*p[19];
out[411] = -1.0*p[20];
out[413] = -1.0*p[19];
out[414] = -1.0*p[20];
out[416] = -1.0*p[19];
out[417] = -1.0*p[20];
out[419] = -1.0*p[21];
out[420] = -1.0*p[22];
out[422] = p[26];
out[423] = -p[25];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 184.75059629806526;
out[5] = 94.615102344455664;
out[6] = -69.368640085185305;
out[7] = -17.974903844364835;
out[8] = -43.675799641021079;
out[9] = -40.748687841669557;
out[10] = -69.368640085185291;
out[11] = -17.974903844364821;
out[12] = -184.75059629806526;
out[13] = -94.615102344455664;
out[14] = 69.368640085185305;
out[15] = 17.974903844364835;
out[16] = 43.675799641021079;
out[17] = 40.748687841669557;
out[18] = 69.368640085185291;
out[19] = 17.974903844364821;
out[20] = -1.0;
out[21] = -94.615102344455664;
out[22] = 184.75059629806526;
out[23] = 17.974903844364835;
out[24] = -69.368640085185305;
out[25] = 40.748687841669557;
out[26] = -43.675799641021079;
out[27] = 17.974903844364821;
out[28] = -69.368640085185291;
out[29] = 94.615102344455664;
out[30] = -184.75059629806526;
out[31] = -17.974903844364835;
out[32] = 69.368640085185305;
out[33] = -40.748687841669557;
out[34] = 43.675799641021079;
out[35] = -17.974903844364821;
out[36] = 69.368640085185291;
out[37] = -1.0;
out[38] = -69.368640085185291;
out[39] = -17.974903844364825;
out[40] = 184.7505962980652;
out[41] = 94.615102344455636;
out[42] = -69.368640085185319;
out[43] = -17.97490384436481;
out[44] = -43.675799641021079;
out[45] = -40.748687841669565;
out[46] = 69.368640085185291;
out[47] = 17.974903844364825;
out[48] = -184.7505962980652;
out[49] = -94.615102344455636;
out[50] = 69.368640085185319;
out[51] = 17.97490384436481;
out[52] = 43.675799641021079;
out[53] = 40.748687841669565;
out[54] = -1.0;
out[55] = 17.974903844364825;
out[56] = -69.368640085185291;
out[57] = -94.615102344455636;
out[58] = 184.7505962980652;
out[59] = 17.97490384436481;
out[60] = -69.368640085185319;
out[61] = 40.748687841669565;
out[62] = -43.675799641021079;
out[63] = -17.974903844364825;
out[64] = 69.368640085185291;
out[65] = 94.615102344455636;
out[66] = -184.7505962980652;
out[67] = -17.97490384436481;
out[68] = 69.368640085185319;
out[69] = -40.748687841669565;
out[70] = 43.675799641021079;
out[71] = -1.0;
out[72] = -43.675799641021101;
out[73] = -40.748687841669579;
out[74] = -69.368640085185305;
out[75] = -17.974903844364821;
out[76] = 184.75059629806526;
out[77] = 94.61510234445565;
out[78] = -69.368640085185305;
out[79] = -17.974903844364821;
out[80] = 43.675799641021101;
out[81] = 40.748687841669579;
out[82] = 69.368640085185305;
out[83] = 17.974903844364821;
out[84] = -184.75059629806526;
out[85] = -94.61510234445565;
out[86] = 69.368640085185305;
out[87] = 17.974903844364821;
out[88] = -1.0;
out[89] = 40.748687841669579;
out[90] = -43.675799641021101;
out[91] = 17.974903844364821;
out[92] = -69.368640085185305;
out[93] = -94.61510234445565;
out[94] = 184.75059629806526;
out[95] = 17.974903844364821;
out[96] = -69.368640085185305;
out[97] = -40.748687841669579;
out[98] = 43.675799641021101;
out[99] = -17.974903844364821;
out[100] = 69.368640085185305;
out[101] = 94.61510234445565;
out[102] = -184.75059629806526;
out[103] = -17.974903844364821;
out[104] = 69.368640085185305;
out[105] = -1.0;
out[106] = -69.368640085185305;
out[107] = -17.974903844364825;
out[108] = -43.675799641021079;
out[109] = -40.74868784166955;
out[110] = -69.368640085185291;
out[111] = -17.974903844364839;
out[112] = 184.7505962980652;
out[113] = 94.61510234445565;
out[114] = 69.368640085185305;
out[115] = 17.974903844364825;
out[116] = 43.675799641021079;
out[117] = 40.74868784166955;
out[118] = 69.368640085185291;
out[119] = 17.974903844364839;
out[120] = -184.7505962980652;
out[121] = -94.61510234445565;
out[122] = -1.0;
out[123] = 17.974903844364825;
out[124] = -69.368640085185305;
out[125] = 40.74868784166955;
out[126] = -43.675799641021079;
out[127] = 17.974903844364839;
out[128] = -69.368640085185291;
out[129] = -94.61510234445565;
out[130] = 184.7505962980652;
out[131] = -17.974903844364825;
out[132] = 69.368640085185305;
out[133] = -40.74868784166955;
out[134] = 43.675799641021079;
out[135] = -17.974903844364839;
out[136] = 69.368640085185291;
out[137] = 94.61510234445565;
out[138] = -184.7505962980652;
out[139] = -1.0;
out[140] = -184.75059629806526;
out[141] = -94.615102344455664;
out[142] = 69.368640085185305;
out[143] = 17.974903844364835;
out[144] = 43.675799641021079;
out[145] = 40.748687841669557;
out[146] = 69.368640085185291;
out[147] = 17.974903844364821;
out[148] = 184.75059629806526;
out[149] = 94.615102344455664;
out[150] = -69.368640085185305;
out[151] = -17.974903844364835;
out[152] = -43.675799641021079;
out[153] = -40.748687841669557;
out[154] = -69.368640085185291;
out[155] = -17.974903844364821;
out[156] = -1.0;
out[157] = 94.615102344455664;
out[158] = -184.75059629806526;
out[159] = -17.974903844364835;
out[160] = 69.368640085185305;
out[161] = -40.748687841669557;
out[162] = 43.675799641021079;
out[163] = -17.974903844364821;
out[164] = 69.368640085185291;
out[165] = -94.615102344455664;
out[166] = 184.75059629806526;
out[167] = 17.974903844364835;
out[168] = -69.368640085185305;
out[169] = 40.748687841669557;
out[170] = -43.675799641021079;
out[171] = 17.974903844364821;
out[172] = -69.368640085185291;
out[173] = -1.0;
out[174] = 69.368640085185291;
out[175] = 17.974903844364825;
out[176] = -184.7505962980652;
out[177] = -94.615102344455636;
out[178] = 69.368640085185319;
out[179] = 17.97490384436481;
out[180] = 43.675799641021079;
out[181] = 40.748687841669565;
out[182] = -69.368640085185291;
out[183] = -17.974903844364825;
out[184] = 184.7505962980652;
out[185] = 94.615102344455636;
out[186] = -69.368640085185319;
out[187] = -17.97490384436481;
out[188] = -43.675799641021079;
out[189] = -40.748687841669565;
out[190] = -1.0;
out[191] = -17.974903844364825;
out[192] = 69.368640085185291;
out[193] = 94.615102344455636;
out[194] = -184.7505962980652;
out[195] = -17.97490384436481;
out[196] = 69.368640085185319;
out[197] = -40.748687841669565;
out[198] = 43.675799641021079;
out[199] = 17.974903844364825;
out[200] = -69.368640085185291;
out[201] = -94.615102344455636;
out[202] = 184.7505962980652;
out[203] = 17.97490384436481;
out[204] = -69.368640085185319;
out[205] = 40.748687841669565;
out[206] = -43.675799641021079;
out[207] = -1.0;
out[208] = 43.675799641021101;
out[209] = 40.748687841669579;
out[210] = 69.368640085185305;
out[211] = 17.974903844364821;
out[212] = -184.75059629806526;
out[213] = -94.61510234445565;
out[214] = 69.368640085185305;
out[215] = 17.974903844364821;
out[216] = -43.675799641021101;
out[217] = -40.748687841669579;
out[218] = -69.368640085185305;
out[219] = -17.974903844364821;
out[220] = 184.75059629806526;
out[221] = 94.61510234445565;
out[222] = -69.368640085185305;
out[223] = -17.974903844364821;
out[224] = -1.0;
out[225] = -40.748687841669579;
out[226] = 43.675799641021101;
out[227] = -17.974903844364821;
out[228] = 69.368640085185305;
out[229] = 94.61510234445565;
out[230] = -184.75059629806526;
out[231] = -17.974903844364821;
out[232] = 69.368640085185305;
out[233] = 40.748687841669579;
out[234] = -43.675799641021101;
out[235] = 17.974903844364821;
out[236] = -69.368640085185305;
out[237] = -94.61510234445565;
out[238] = 184.75059629806526;
out[239] = 17.974903844364821;
out[240] = -69.368640085185305;
out[241] = -1.0;
out[242] = 69.368640085185305;
out[243] = 17.974903844364825;
out[244] = 43.675799641021079;
out[245] = 40.74868784166955;
out[246] = 69.368640085185291;
out[247] = 17.974903844364839;
out[248] = -184.7505962980652;
out[249] = -94.61510234445565;
out[250] = -69.368640085185305;
out[251] = -17.974903844364825;
out[252] = -43.675799641021079;
out[253] = -40.74868784166955;
out[254] = -69.368640085185291;
out[255] = -17.974903844364839;
out[256] = 184.7505962980652;
out[257] = 94.61510234445565;
out[258] = -1.0;
out[259] = -17.974903844364825;
out[260] = 69.368640085185305;
out[261] = -40.74868784166955;
out[262] = 43.675799641021079;
out[263] = -17.974903844364839;
out[264] = 69.368640085185291;
out[265] = 94.61510234445565;
out[266] = -184.7505962980652;
out[267] = 17.974903844364825;
out[268] = -69.368640085185305;
out[269] = 40.74868784166955;
out[270] = -43.675799641021079;
out[271] = 17.974903844364839;
out[272] = -69.368640085185291;
out[273] = -94.61510234445565;
out[274] = 184.7505962980652;
out[275] = -1.0;
out[276] = -1.0;
out[278] = 1.0;
out[280] = 1.0;
out[281] = -1.0;
out[283] = 1.0;
out[285] = 1.0;
out[286] = -1.0;
out[288] = 1.0;
out[290] = 1.0;
out[291] = -1.0;
out[293] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[297] = 1.0;
out[298] = 1.0;
out[301] = -1.0;
out[304] = 1.0;
out[305] = 1.0;
out[306] = -1.0;
out[309] = 1.0;
out[310] = 1.0;
out[311] = -1.0;
out[314] = 1.0;
out[315] = 1.0;
out[316] = -1.0;
out[319] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[323] = 1.0;
out[324] = 1.0;
out[334] = -1.0;
out[345] = -1.0;
out[348] = 0.33333333333333331;
out[353] = 0.33333333333333331;
out[358] = 0.33333333333333331;
out[373] = -1.0;
out[376] = 1.0;
out[377] = -1.0;
out[380] = 1.0;
out[381] = -1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = -1.0;
out[392] = 1.0;
out[393] = -1.0;
out[396] = 1.0;
out[397] = -1.0;
out[400] = -1.0;
out[403] = -1.0;
out[406] = -1.0;
out[409] = -1.0;
out[412] = -1.0;
out[415] = -1.0;
out[418] = -1.0;
out[421] = -1.0;
out[424] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0)*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[3] = (1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));

}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[37] = 1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[494] = y[18];
out[495] = 1.0*y[23];
out[515] = -1.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/u[2] + 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*pow(u[2], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[516] = -0.01*p[14]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(0.01*p[14]*(u[3] - 25.0) + 1.0) + 0.01*p[13]*p[15]*p[11] + 10.0*p[14]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*u[2]*pow(0.01*p[14]*(u[3] - 25.0) + 1.0, 2)) - 1000.0*(0.01*p[13]*p[15]*p[11] - 0.01*p[13]*p[15]*p[12])*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[534] = (0.001*p[10]*p[17]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[535] = (1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) + p[17]*(1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0)))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[536] = 1.0 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[792] = cos(u[17]);
out[796] = -u[13]*sin(u[17]);
out[812] = cos(u[17] - 2.0943951023931953);
out[815] = -u[14]*sin(u[17] - 2.0943951023931953);
out[832] = cos(u[17] - 4.1887902047863905);
out[834] = -u[15]*sin(u[17] - 4.1887902047863905);
out[868] = 1.0*sin(u[17]);
out[872] = 1.0*u[13]*cos(u[17]);
out[888] = 1.0*sin(u[17] - 2.0943951023931953);
out[891] = 1.0*u[14]*cos(u[17] - 2.0943951023931953);
out[908] = 1.0*sin(u[17] - 4.1887902047863905);
out[910] = 1.0*u[15]*cos(u[17] - 4.1887902047863905);

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[361] = 1.0;
out[457] = 1.0;
out[556] = 1.0;
out[559] = 0.33333333333333331;
out[576] = 1.0;
out[578] = 0.33333333333333331;
out[596] = 1.0;
out[597] = 0.33333333333333331;
out[617] = 1.0;
out[620] = 0.33333333333333331;
out[637] = 1.0;
out[639] = 0.33333333333333331;
out[657] = 1.0;
out[658] = 0.33333333333333331;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[53] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[424] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[429] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[476] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[481] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[528] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[533] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[580] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[585] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[612] = y[16];
out[613] = 1.0*y[21];
out[628] = y[0];
out[633] = 1.0*y[1];
out[663] = -1.0*y[21];
out[664] = 1.0*y[16];
out[679] = 1.0*y[1];
out[684] = -1.0*y[0];
out[716] = y[17];
out[717] = 1.0*y[22];
out[731] = y[2];
out[736] = 1.0*y[3];
out[767] = -1.0*y[22];
out[768] = 1.0*y[17];
out[782] = 1.0*y[3];
out[787] = -1.0*y[2];
out[820] = y[18];
out[821] = 1.0*y[23];
out[834] = y[4];
out[839] = 1.0*y[5];
out[871] = -1.0*y[23];
out[872] = 1.0*y[18];
out[885] = 1.0*y[5];
out[890] = -1.0*y[4];
out[1061] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1065] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1113] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1117] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1165] = y[43]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[1169] = 1.0*y[47]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[1217] = y[44]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[1221] = 1.0*y[48]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[1232] = y[41];
out[1233] = 1.0*y[45];
out[1234] = y[42];
out[1235] = 1.0*y[46];
out[1236] = y[43];
out[1237] = 1.0*y[47];
out[1265] = y[8];
out[1266] = y[10];
out[1267] = y[12];
out[1269] = 1.0*y[9];
out[1270] = 1.0*y[11];
out[1271] = 1.0*y[13];
out[1283] = -1.0*y[45];
out[1284] = 1.0*y[41];
out[1285] = -1.0*y[46];
out[1286] = 1.0*y[42];
out[1287] = -1.0*y[47];
out[1288] = 1.0*y[43];
out[1316] = 1.0*y[9];
out[1317] = 1.0*y[11];
out[1318] = 1.0*y[13];
out[1320] = -1.0*y[8];
out[1321] = -1.0*y[10];
out[1322] = -1.0*y[12];

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[51] = -94.615102344455664;
out[52] = 184.75059629806526;
out[53] = 17.974903844364835;
out[54] = -69.368640085185305;
out[55] = 40.748687841669557;
out[56] = -43.675799641021079;
out[57] = 17.974903844364821;
out[58] = -69.368640085185291;
out[59] = 94.615102344455664;
out[60] = -184.75059629806526;
out[61] = -17.974903844364835;
out[62] = 69.368640085185305;
out[63] = -40.748687841669557;
out[64] = 43.675799641021079;
out[65] = -17.974903844364821;
out[66] = 69.368640085185291;
out[102] = -69.368640085185291;
out[103] = -17.974903844364825;
out[104] = 184.7505962980652;
out[105] = 94.615102344455636;
out[106] = -69.368640085185319;
out[107] = -17.97490384436481;
out[108] = -43.675799641021079;
out[109] = -40.748687841669565;
out[110] = 69.368640085185291;
out[111] = 17.974903844364825;
out[112] = -184.7505962980652;
out[113] = -94.615102344455636;
out[114] = 69.368640085185319;
out[115] = 17.97490384436481;
out[116] = 43.675799641021079;
out[117] = 40.748687841669565;
out[153] = 17.974903844364825;
out[154] = -69.368640085185291;
out[155] = -94.615102344455636;
out[156] = 184.7505962980652;
out[157] = 17.97490384436481;
out[158] = -69.368640085185319;
out[159] = 40.748687841669565;
out[160] = -43.675799641021079;
out[161] = -17.974903844364825;
out[162] = 69.368640085185291;
out[163] = 94.615102344455636;
out[164] = -184.7505962980652;
out[165] = -17.97490384436481;
out[166] = 69.368640085185319;
out[167] = -40.748687841669565;
out[168] = 43.675799641021079;
out[204] = -43.675799641021101;
out[205] = -40.748687841669579;
out[206] = -69.368640085185305;
out[207] = -17.974903844364821;
out[208] = 184.75059629806526;
out[209] = 94.61510234445565;
out[210] = -69.368640085185305;
out[211] = -17.974903844364821;
out[212] = 43.675799641021101;
out[213] = 40.748687841669579;
out[214] = 69.368640085185305;
out[215] = 17.974903844364821;
out[216] = -184.75059629806526;
out[217] = -94.61510234445565;
out[218] = 69.368640085185305;
out[219] = 17.974903844364821;
out[255] = 40.748687841669579;
out[256] = -43.675799641021101;
out[257] = 17.974903844364821;
out[258] = -69.368640085185305;
out[259] = -94.61510234445565;
out[260] = 184.75059629806526;
out[261] = 17.974903844364821;
out[262] = -69.368640085185305;
out[263] = -40.748687841669579;
out[264] = 43.675799641021101;
out[265] = -17.974903844364821;
out[266] = 69.368640085185305;
out[267] = 94.61510234445565;
out[268] = -184.75059629806526;
out[269] = -17.974903844364821;
out[270] = 69.368640085185305;
out[306] = -69.368640085185305;
out[307] = -17.974903844364825;
out[308] = -43.675799641021079;
out[309] = -40.74868784166955;
out[310] = -69.368640085185291;
out[311] = -17.974903844364839;
out[312] = 184.7505962980652;
out[313] = 94.61510234445565;
out[314] = 69.368640085185305;
out[315] = 17.974903844364825;
out[316] = 43.675799641021079;
out[317] = 40.74868784166955;
out[318] = 69.368640085185291;
out[319] = 17.974903844364839;
out[320] = -184.7505962980652;
out[321] = -94.61510234445565;
out[357] = 17.974903844364825;
out[358] = -69.368640085185305;
out[359] = 40.74868784166955;
out[360] = -43.675799641021079;
out[361] = 17.974903844364839;
out[362] = -69.368640085185291;
out[363] = -94.61510234445565;
out[364] = 184.7505962980652;
out[365] = -17.974903844364825;
out[366] = 69.368640085185305;
out[367] = -40.74868784166955;
out[368] = 43.675799641021079;
out[369] = -17.974903844364839;
out[370] = 69.368640085185291;
out[371] = 94.61510234445565;
out[372] = -184.7505962980652;
out[997] = 1.0;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[344] = 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0);
out[345] = 1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0);

}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[531] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0)*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[1] = (1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));

}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = 1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = y[18];
out[3] = 1.0*y[23];
out[4] = -1.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/u[2] + 1000.0*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*pow(u[2], 2)*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[5] = -0.01*p[14]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))/(0.01*p[14]*(u[3] - 25.0) + 1.0) + 0.01*p[13]*p[15]*p[11] + 10.0*p[14]*(p[15]*p[11]*(0.01*p[13]*(u[3] - 25.0) + 1.0) - p[15]*p[12]*(0.01*p[13]*(u[3] - 25.0) + 1.0))*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*u[2]*pow(0.01*p[14]*(u[3] - 25.0) + 1.0, 2)) - 1000.0*(0.01*p[13]*p[15]*p[11] - 0.01*p[13]*p[15]*p[12])*(0.001*p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) - y[26]/y[27])/(p[10]*p[16]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0));
out[6] = (0.001*p[10]*p[17]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[7] = (1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0) + p[17]*(1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0)))*((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));
out[8] = 1.0 - ((u[4] < 0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) + p[18]*x[0] + p[17]*(0.001*p[10]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1)*(0.01*p[13]*(u[3] - 25.0) + 1) - y[26])) ? (
   0
)
: (
   1.0
));

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[21] = cos(u[17]);
out[22] = -u[13]*sin(u[17]);
out[23] = cos(u[17] - 2.0943951023931953);
out[24] = -u[14]*sin(u[17] - 2.0943951023931953);
out[25] = cos(u[17] - 4.1887902047863905);
out[26] = -u[15]*sin(u[17] - 4.1887902047863905);
out[27] = 1.0*sin(u[17]);
out[28] = 1.0*u[13]*cos(u[17]);
out[29] = 1.0*sin(u[17] - 2.0943951023931953);
out[30] = 1.0*u[14]*cos(u[17] - 2.0943951023931953);
out[31] = 1.0*sin(u[17] - 4.1887902047863905);
out[32] = 1.0*u[15]*cos(u[17] - 4.1887902047863905);

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[9] = 1.0;
out[10] = 0.33333333333333331;
out[11] = 1.0;
out[12] = 0.33333333333333331;
out[13] = 1.0;
out[14] = 0.33333333333333331;
out[15] = 1.0;
out[16] = 0.33333333333333331;
out[17] = 1.0;
out[18] = 0.33333333333333331;
out[19] = 1.0;
out[20] = 0.33333333333333331;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[128] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[129] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[130] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[131] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[132] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[133] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[134] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[135] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[136] = y[16];
out[137] = 1.0*y[21];
out[138] = y[0];
out[139] = 1.0*y[1];
out[140] = -1.0*y[21];
out[141] = 1.0*y[16];
out[142] = 1.0*y[1];
out[143] = -1.0*y[0];
out[144] = y[17];
out[145] = 1.0*y[22];
out[146] = y[2];
out[147] = 1.0*y[3];
out[148] = -1.0*y[22];
out[149] = 1.0*y[17];
out[150] = 1.0*y[3];
out[151] = -1.0*y[2];
out[152] = y[18];
out[153] = 1.0*y[23];
out[154] = y[4];
out[155] = 1.0*y[5];
out[156] = -1.0*y[23];
out[157] = 1.0*y[18];
out[158] = 1.0*y[5];
out[159] = -1.0*y[4];
out[161] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[162] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[163] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[164] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[165] = y[43]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[166] = 1.0*y[47]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[167] = y[44]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[168] = 1.0*y[48]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[169] = y[41];
out[170] = 1.0*y[45];
out[171] = y[42];
out[172] = 1.0*y[46];
out[173] = y[43];
out[174] = 1.0*y[47];
out[175] = y[8];
out[176] = y[10];
out[177] = y[12];
out[178] = 1.0*y[9];
out[179] = 1.0*y[11];
out[180] = 1.0*y[13];
out[181] = -1.0*y[45];
out[182] = 1.0*y[41];
out[183] = -1.0*y[46];
out[184] = 1.0*y[42];
out[185] = -1.0*y[47];
out[186] = 1.0*y[43];
out[187] = 1.0*y[9];
out[188] = 1.0*y[11];
out[189] = 1.0*y[13];
out[190] = -1.0*y[8];
out[191] = -1.0*y[10];
out[192] = -1.0*y[12];

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[16] = -94.615102344455664;
out[17] = 184.75059629806526;
out[18] = 17.974903844364835;
out[19] = -69.368640085185305;
out[20] = 40.748687841669557;
out[21] = -43.675799641021079;
out[22] = 17.974903844364821;
out[23] = -69.368640085185291;
out[24] = 94.615102344455664;
out[25] = -184.75059629806526;
out[26] = -17.974903844364835;
out[27] = 69.368640085185305;
out[28] = -40.748687841669557;
out[29] = 43.675799641021079;
out[30] = -17.974903844364821;
out[31] = 69.368640085185291;
out[32] = -69.368640085185291;
out[33] = -17.974903844364825;
out[34] = 184.7505962980652;
out[35] = 94.615102344455636;
out[36] = -69.368640085185319;
out[37] = -17.97490384436481;
out[38] = -43.675799641021079;
out[39] = -40.748687841669565;
out[40] = 69.368640085185291;
out[41] = 17.974903844364825;
out[42] = -184.7505962980652;
out[43] = -94.615102344455636;
out[44] = 69.368640085185319;
out[45] = 17.97490384436481;
out[46] = 43.675799641021079;
out[47] = 40.748687841669565;
out[48] = 17.974903844364825;
out[49] = -69.368640085185291;
out[50] = -94.615102344455636;
out[51] = 184.7505962980652;
out[52] = 17.97490384436481;
out[53] = -69.368640085185319;
out[54] = 40.748687841669565;
out[55] = -43.675799641021079;
out[56] = -17.974903844364825;
out[57] = 69.368640085185291;
out[58] = 94.615102344455636;
out[59] = -184.7505962980652;
out[60] = -17.97490384436481;
out[61] = 69.368640085185319;
out[62] = -40.748687841669565;
out[63] = 43.675799641021079;
out[64] = -43.675799641021101;
out[65] = -40.748687841669579;
out[66] = -69.368640085185305;
out[67] = -17.974903844364821;
out[68] = 184.75059629806526;
out[69] = 94.61510234445565;
out[70] = -69.368640085185305;
out[71] = -17.974903844364821;
out[72] = 43.675799641021101;
out[73] = 40.748687841669579;
out[74] = 69.368640085185305;
out[75] = 17.974903844364821;
out[76] = -184.75059629806526;
out[77] = -94.61510234445565;
out[78] = 69.368640085185305;
out[79] = 17.974903844364821;
out[80] = 40.748687841669579;
out[81] = -43.675799641021101;
out[82] = 17.974903844364821;
out[83] = -69.368640085185305;
out[84] = -94.61510234445565;
out[85] = 184.75059629806526;
out[86] = 17.974903844364821;
out[87] = -69.368640085185305;
out[88] = -40.748687841669579;
out[89] = 43.675799641021101;
out[90] = -17.974903844364821;
out[91] = 69.368640085185305;
out[92] = 94.61510234445565;
out[93] = -184.75059629806526;
out[94] = -17.974903844364821;
out[95] = 69.368640085185305;
out[96] = -69.368640085185305;
out[97] = -17.974903844364825;
out[98] = -43.675799641021079;
out[99] = -40.74868784166955;
out[100] = -69.368640085185291;
out[101] = -17.974903844364839;
out[102] = 184.7505962980652;
out[103] = 94.61510234445565;
out[104] = 69.368640085185305;
out[105] = 17.974903844364825;
out[106] = 43.675799641021079;
out[107] = 40.74868784166955;
out[108] = 69.368640085185291;
out[109] = 17.974903844364839;
out[110] = -184.7505962980652;
out[111] = -94.61510234445565;
out[112] = 17.974903844364825;
out[113] = -69.368640085185305;
out[114] = 40.74868784166955;
out[115] = -43.675799641021079;
out[116] = 17.974903844364839;
out[117] = -69.368640085185291;
out[118] = -94.61510234445565;
out[119] = 184.7505962980652;
out[120] = -17.974903844364825;
out[121] = 69.368640085185305;
out[122] = -40.74868784166955;
out[123] = 43.675799641021079;
out[124] = -17.974903844364839;
out[125] = 69.368640085185291;
out[126] = 94.61510234445565;
out[127] = -184.7505962980652;
out[160] = 1.0;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.001*p[10]*p[16]*p[15]*p[11]*(0.01*p[14]*(u[3] - 25.0) + 1.0)*(0.01*p[13]*(u[3] - 25.0) + 1.0);
out[1] = 1.0000000000000001e-5*p[10]*p[14]*p[16]*p[15]*p[11]*u[2]*(0.01*p[13]*(u[3] - 25.0) + 1.0) + 1.0000000000000001e-5*p[10]*p[13]*p[16]*p[15]*p[11]*u[2]*(0.01*p[14]*(u[3] - 25.0) + 1.0);

}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_temp_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_temp_cffi(void) { return NULL; }
#  else
     inittemp_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_temp_cffi(void)
{
  return _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inittemp_cffi(void)
{
  _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
