#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20]*x[0] + 314.15926535897933*x[1] - 314.15926535897933*y[42];
out[1] = (1.0/2.0)*(-p[18]*(x[1] - 1.0) - x[3] + y[27])/p[17];
out[2] = -x[2]*(1 - ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1
))) - 9.9999999999999995e-7*x[2] + (u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1
));
out[3] = (-x[3] + (0.33333333333333331*y[1]*y[21] - y[1]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) - y[1]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333331*y[0]*y[16] + y[0]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[0]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) + 0.33333333333333326*y[3]*y[22] - 0.16666666666666652*y[3]*y[23] + 0.28867513459481281*y[3]*y[18] + 0.33333333333333326*y[2]*y[17] - 0.28867513459481281*y[2]*y[23] - 0.16666666666666652*y[2]*y[18] - 0.16666666666666652*y[5]*y[22] - 0.28867513459481281*y[5]*y[17] + 0.33333333333333326*y[5]*y[23] + 0.28867513459481281*y[4]*y[22] - 0.16666666666666652*y[4]*y[17] + 0.33333333333333326*y[4]*y[18] + 1.0*y[21]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[21]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]) + 1.0*y[16]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) + 1.0*y[16]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]))/p[11])/p[13];
out[4] = (u[14] - x[4])/p[14];
out[5] = (-x[5] + u[6] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[6] = (-x[6] + u[7] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[7] = (-x[7] + u[8] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[8] = (-x[8] + u[9])/p[15];
out[9] = -p[32]*x[9] - y[42] + u[24] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455565*y[1] + 184.75059629806532*y[0] - 17.974903844364775*y[3] - 69.368640085185334*y[2] - 40.74868784166955*y[5] - 43.675799641021136*y[4] - 17.974903844364817*y[7] - 69.368640085185348*y[6] - 94.615102344455565*y[9] - 184.75059629806532*y[8] + 17.974903844364775*y[11] + 69.368640085185334*y[10] + 40.74868784166955*y[13] + 43.675799641021136*y[12] + 17.974903844364817*y[15] + 69.368640085185348*y[14] - y[16];
out[1] = 184.75059629806532*y[1] - 94.615102344455565*y[0] - 69.368640085185334*y[3] + 17.974903844364775*y[2] - 43.675799641021136*y[5] + 40.74868784166955*y[4] - 69.368640085185348*y[7] + 17.974903844364817*y[6] - 184.75059629806532*y[9] + 94.615102344455565*y[8] + 69.368640085185334*y[11] - 17.974903844364775*y[10] + 43.675799641021136*y[13] - 40.74868784166955*y[12] + 69.368640085185348*y[15] - 17.974903844364817*y[14] - y[21];
out[2] = -17.974903844364796*y[1] - 69.368640085185319*y[0] + 94.615102344455607*y[3] + 184.75059629806523*y[2] - 17.974903844364814*y[5] - 69.368640085185291*y[4] - 40.748687841669586*y[7] - 43.675799641021079*y[6] + 17.974903844364796*y[9] + 69.368640085185319*y[8] - 94.615102344455607*y[11] - 184.75059629806523*y[10] + 17.974903844364814*y[13] + 69.368640085185291*y[12] + 40.748687841669586*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185319*y[1] + 17.974903844364796*y[0] + 184.75059629806523*y[3] - 94.615102344455607*y[2] - 69.368640085185291*y[5] + 17.974903844364814*y[4] - 43.675799641021079*y[7] + 40.748687841669586*y[6] + 69.368640085185319*y[9] - 17.974903844364796*y[8] - 184.75059629806523*y[11] + 94.615102344455607*y[10] + 69.368640085185291*y[13] - 17.974903844364814*y[12] + 43.675799641021079*y[15] - 40.748687841669586*y[14] - y[22];
out[4] = -40.748687841669557*y[1] - 43.675799641021122*y[0] - 17.97490384436481*y[3] - 69.368640085185277*y[2] + 94.615102344455636*y[5] + 184.75059629806526*y[4] - 17.974903844364817*y[7] - 69.368640085185277*y[6] + 40.748687841669557*y[9] + 43.675799641021122*y[8] + 17.97490384436481*y[11] + 69.368640085185277*y[10] - 94.615102344455636*y[13] - 184.75059629806526*y[12] + 17.974903844364817*y[15] + 69.368640085185277*y[14] - y[18];
out[5] = -43.675799641021122*y[1] + 40.748687841669557*y[0] - 69.368640085185277*y[3] + 17.97490384436481*y[2] + 184.75059629806526*y[5] - 94.615102344455636*y[4] - 69.368640085185277*y[7] + 17.974903844364817*y[6] + 43.675799641021122*y[9] - 40.748687841669557*y[8] + 69.368640085185277*y[11] - 17.97490384436481*y[10] - 184.75059629806526*y[13] + 94.615102344455636*y[12] + 69.368640085185277*y[15] - 17.974903844364817*y[14] - y[23];
out[6] = -17.9749038443648*y[1] - 69.368640085185334*y[0] - 40.748687841669586*y[3] - 43.675799641021086*y[2] - 17.974903844364821*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.75059629806523*y[6] + 17.9749038443648*y[9] + 69.368640085185334*y[8] + 40.748687841669586*y[11] + 43.675799641021086*y[10] + 17.974903844364821*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.75059629806523*y[14] - y[19];
out[7] = -69.368640085185334*y[1] + 17.9749038443648*y[0] - 43.675799641021086*y[3] + 40.748687841669586*y[2] - 69.368640085185291*y[5] + 17.974903844364821*y[4] + 184.75059629806523*y[7] - 94.61510234445565*y[6] + 69.368640085185334*y[9] - 17.9749038443648*y[8] + 43.675799641021086*y[11] - 40.748687841669586*y[10] + 69.368640085185291*y[13] - 17.974903844364821*y[12] - 184.75059629806523*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455565*y[1] - 184.75059629806532*y[0] + 17.974903844364775*y[3] + 69.368640085185334*y[2] + 40.74868784166955*y[5] + 43.675799641021136*y[4] + 17.974903844364817*y[7] + 69.368640085185348*y[6] + 94.615102344455565*y[9] + 184.75059629806532*y[8] - 17.974903844364775*y[11] - 69.368640085185334*y[10] - 40.74868784166955*y[13] - 43.675799641021136*y[12] - 17.974903844364817*y[15] - 69.368640085185348*y[14] - y[34];
out[9] = -184.75059629806532*y[1] + 94.615102344455565*y[0] + 69.368640085185334*y[3] - 17.974903844364775*y[2] + 43.675799641021136*y[5] - 40.74868784166955*y[4] + 69.368640085185348*y[7] - 17.974903844364817*y[6] + 184.75059629806532*y[9] - 94.615102344455565*y[8] - 69.368640085185334*y[11] + 17.974903844364775*y[10] - 43.675799641021136*y[13] + 40.74868784166955*y[12] - 69.368640085185348*y[15] + 17.974903844364817*y[14] - y[38];
out[10] = 17.974903844364796*y[1] + 69.368640085185319*y[0] - 94.615102344455607*y[3] - 184.75059629806523*y[2] + 17.974903844364814*y[5] + 69.368640085185291*y[4] + 40.748687841669586*y[7] + 43.675799641021079*y[6] - 17.974903844364796*y[9] - 69.368640085185319*y[8] + 94.615102344455607*y[11] + 184.75059629806523*y[10] - 17.974903844364814*y[13] - 69.368640085185291*y[12] - 40.748687841669586*y[15] - 43.675799641021079*y[14] - y[35];
out[11] = 69.368640085185319*y[1] - 17.974903844364796*y[0] - 184.75059629806523*y[3] + 94.615102344455607*y[2] + 69.368640085185291*y[5] - 17.974903844364814*y[4] + 43.675799641021079*y[7] - 40.748687841669586*y[6] - 69.368640085185319*y[9] + 17.974903844364796*y[8] + 184.75059629806523*y[11] - 94.615102344455607*y[10] - 69.368640085185291*y[13] + 17.974903844364814*y[12] - 43.675799641021079*y[15] + 40.748687841669586*y[14] - y[39];
out[12] = 40.748687841669557*y[1] + 43.675799641021122*y[0] + 17.97490384436481*y[3] + 69.368640085185277*y[2] - 94.615102344455636*y[5] - 184.75059629806526*y[4] + 17.974903844364817*y[7] + 69.368640085185277*y[6] - 40.748687841669557*y[9] - 43.675799641021122*y[8] - 17.97490384436481*y[11] - 69.368640085185277*y[10] + 94.615102344455636*y[13] + 184.75059629806526*y[12] - 17.974903844364817*y[15] - 69.368640085185277*y[14] - y[36];
out[13] = 43.675799641021122*y[1] - 40.748687841669557*y[0] + 69.368640085185277*y[3] - 17.97490384436481*y[2] - 184.75059629806526*y[5] + 94.615102344455636*y[4] + 69.368640085185277*y[7] - 17.974903844364817*y[6] - 43.675799641021122*y[9] + 40.748687841669557*y[8] - 69.368640085185277*y[11] + 17.97490384436481*y[10] + 184.75059629806526*y[13] - 94.615102344455636*y[12] - 69.368640085185277*y[15] + 17.974903844364817*y[14] - y[40];
out[14] = 17.9749038443648*y[1] + 69.368640085185334*y[0] + 40.748687841669586*y[3] + 43.675799641021086*y[2] + 17.974903844364821*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.75059629806523*y[6] - 17.9749038443648*y[9] - 69.368640085185334*y[8] - 40.748687841669586*y[11] - 43.675799641021086*y[10] - 17.974903844364821*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.75059629806523*y[14] - y[37];
out[15] = 69.368640085185334*y[1] - 17.9749038443648*y[0] + 43.675799641021086*y[3] - 40.748687841669586*y[2] + 69.368640085185291*y[5] - 17.974903844364821*y[4] - 184.75059629806523*y[7] + 94.61510234445565*y[6] - 69.368640085185334*y[9] + 17.9749038443648*y[8] - 43.675799641021086*y[11] + 40.748687841669586*y[10] - 69.368640085185291*y[13] + 17.974903844364821*y[12] + 184.75059629806523*y[15] - 94.61510234445565*y[14] - y[41];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[28];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[29];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[30];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[31];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[32];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[33];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[31] + y[16]*y[28] + 1.0*y[22]*y[32] + y[17]*y[29] + 1.0*y[23]*y[33] + 1.0*y[23]*u[1] + y[18]*y[30] + y[18]*u[0] - y[26];
out[27] = p[19]*x[9] + p[23]*u[17] + x[4] - y[27] - (x[1] - u[15])/p[16];
out[28] = -p[10]*y[16] + 1.0*p[9]*y[21] - y[28] + (x[5] + u[2])*cos(x[0] + u[10]);
out[29] = -p[10]*y[17] + 1.0*p[9]*y[22] - y[29] + (x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[30] = -p[10]*y[18] + 1.0*p[9]*y[23] - y[30] + (x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[31] = -1.0*p[10]*y[21] - 1.0*p[9]*y[16] - 1.0*y[31] + 1.0*(x[5] + u[2])*sin(x[0] + u[10]);
out[32] = -1.0*p[10]*y[22] - 1.0*p[9]*y[17] - 1.0*y[32] + 1.0*(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[33] = -1.0*p[10]*y[23] - 1.0*p[9]*y[18] - 1.0*y[33] + 1.0*(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[34] = -p[25]*y[34] - y[8] + 1.0*p[24]*y[38] + u[19]*cos(u[23]);
out[35] = -p[25]*y[35] - y[10] + 1.0*p[24]*y[39] + u[20]*cos(u[23] - 2.0943951023931953);
out[36] = -p[25]*y[36] - y[12] + 1.0*p[24]*y[40] + u[21]*cos(u[23] - 4.1887902047863905);
out[37] = -p[27]*y[37] - y[14] + 1.0*p[26]*y[41];
out[38] = -1.0*p[25]*y[38] - 1.0*y[9] - 1.0*p[24]*y[34] + 1.0*u[19]*sin(u[23]);
out[39] = -1.0*p[25]*y[39] - 1.0*y[11] - 1.0*p[24]*y[35] + 1.0*u[20]*sin(u[23] - 2.0943951023931953);
out[40] = -1.0*p[25]*y[40] - 1.0*y[13] - 1.0*p[24]*y[36] + 1.0*u[21]*sin(u[23] - 4.1887902047863905);
out[41] = -1.0*p[27]*y[41] - 1.0*y[15] - 1.0*p[26]*y[37];
out[42] = -y[42] + (p[11]*x[1] + 1000.0)/(p[11] + 1000.0);
out[43] = p[31]*x[9] + p[30]*(1 - y[42]) - y[43];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20]*x[0] + 314.15926535897933*x[1] - 314.15926535897933*y[42];
out[1] = (1.0/2.0)*(-p[18]*(x[1] - 1.0) - x[3] + y[27])/p[17];
out[2] = -x[2]*(1 - ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1
))) - 9.9999999999999995e-7*x[2] + (u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1
));
out[3] = (-x[3] + (0.33333333333333331*y[1]*y[21] - y[1]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) - y[1]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333331*y[0]*y[16] + y[0]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[0]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) + 0.33333333333333326*y[3]*y[22] - 0.16666666666666652*y[3]*y[23] + 0.28867513459481281*y[3]*y[18] + 0.33333333333333326*y[2]*y[17] - 0.28867513459481281*y[2]*y[23] - 0.16666666666666652*y[2]*y[18] - 0.16666666666666652*y[5]*y[22] - 0.28867513459481281*y[5]*y[17] + 0.33333333333333326*y[5]*y[23] + 0.28867513459481281*y[4]*y[22] - 0.16666666666666652*y[4]*y[17] + 0.33333333333333326*y[4]*y[18] + 1.0*y[21]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[21]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]) + 1.0*y[16]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) + 1.0*y[16]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]))/p[11])/p[13];
out[4] = (u[14] - x[4])/p[14];
out[5] = (-x[5] + u[6] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[6] = (-x[6] + u[7] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[7] = (-x[7] + u[8] + ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   -0.050000000000000003*p[12]
)
: ((0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0.050000000000000003*p[12]
)
: (
   p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])
))))/p[15];
out[8] = (-x[8] + u[9])/p[15];
out[9] = -p[32]*x[9] - y[42] + u[24] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455565*y[1] + 184.75059629806532*y[0] - 17.974903844364775*y[3] - 69.368640085185334*y[2] - 40.74868784166955*y[5] - 43.675799641021136*y[4] - 17.974903844364817*y[7] - 69.368640085185348*y[6] - 94.615102344455565*y[9] - 184.75059629806532*y[8] + 17.974903844364775*y[11] + 69.368640085185334*y[10] + 40.74868784166955*y[13] + 43.675799641021136*y[12] + 17.974903844364817*y[15] + 69.368640085185348*y[14] - y[16];
out[1] = 184.75059629806532*y[1] - 94.615102344455565*y[0] - 69.368640085185334*y[3] + 17.974903844364775*y[2] - 43.675799641021136*y[5] + 40.74868784166955*y[4] - 69.368640085185348*y[7] + 17.974903844364817*y[6] - 184.75059629806532*y[9] + 94.615102344455565*y[8] + 69.368640085185334*y[11] - 17.974903844364775*y[10] + 43.675799641021136*y[13] - 40.74868784166955*y[12] + 69.368640085185348*y[15] - 17.974903844364817*y[14] - y[21];
out[2] = -17.974903844364796*y[1] - 69.368640085185319*y[0] + 94.615102344455607*y[3] + 184.75059629806523*y[2] - 17.974903844364814*y[5] - 69.368640085185291*y[4] - 40.748687841669586*y[7] - 43.675799641021079*y[6] + 17.974903844364796*y[9] + 69.368640085185319*y[8] - 94.615102344455607*y[11] - 184.75059629806523*y[10] + 17.974903844364814*y[13] + 69.368640085185291*y[12] + 40.748687841669586*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185319*y[1] + 17.974903844364796*y[0] + 184.75059629806523*y[3] - 94.615102344455607*y[2] - 69.368640085185291*y[5] + 17.974903844364814*y[4] - 43.675799641021079*y[7] + 40.748687841669586*y[6] + 69.368640085185319*y[9] - 17.974903844364796*y[8] - 184.75059629806523*y[11] + 94.615102344455607*y[10] + 69.368640085185291*y[13] - 17.974903844364814*y[12] + 43.675799641021079*y[15] - 40.748687841669586*y[14] - y[22];
out[4] = -40.748687841669557*y[1] - 43.675799641021122*y[0] - 17.97490384436481*y[3] - 69.368640085185277*y[2] + 94.615102344455636*y[5] + 184.75059629806526*y[4] - 17.974903844364817*y[7] - 69.368640085185277*y[6] + 40.748687841669557*y[9] + 43.675799641021122*y[8] + 17.97490384436481*y[11] + 69.368640085185277*y[10] - 94.615102344455636*y[13] - 184.75059629806526*y[12] + 17.974903844364817*y[15] + 69.368640085185277*y[14] - y[18];
out[5] = -43.675799641021122*y[1] + 40.748687841669557*y[0] - 69.368640085185277*y[3] + 17.97490384436481*y[2] + 184.75059629806526*y[5] - 94.615102344455636*y[4] - 69.368640085185277*y[7] + 17.974903844364817*y[6] + 43.675799641021122*y[9] - 40.748687841669557*y[8] + 69.368640085185277*y[11] - 17.97490384436481*y[10] - 184.75059629806526*y[13] + 94.615102344455636*y[12] + 69.368640085185277*y[15] - 17.974903844364817*y[14] - y[23];
out[6] = -17.9749038443648*y[1] - 69.368640085185334*y[0] - 40.748687841669586*y[3] - 43.675799641021086*y[2] - 17.974903844364821*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.75059629806523*y[6] + 17.9749038443648*y[9] + 69.368640085185334*y[8] + 40.748687841669586*y[11] + 43.675799641021086*y[10] + 17.974903844364821*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.75059629806523*y[14] - y[19];
out[7] = -69.368640085185334*y[1] + 17.9749038443648*y[0] - 43.675799641021086*y[3] + 40.748687841669586*y[2] - 69.368640085185291*y[5] + 17.974903844364821*y[4] + 184.75059629806523*y[7] - 94.61510234445565*y[6] + 69.368640085185334*y[9] - 17.9749038443648*y[8] + 43.675799641021086*y[11] - 40.748687841669586*y[10] + 69.368640085185291*y[13] - 17.974903844364821*y[12] - 184.75059629806523*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455565*y[1] - 184.75059629806532*y[0] + 17.974903844364775*y[3] + 69.368640085185334*y[2] + 40.74868784166955*y[5] + 43.675799641021136*y[4] + 17.974903844364817*y[7] + 69.368640085185348*y[6] + 94.615102344455565*y[9] + 184.75059629806532*y[8] - 17.974903844364775*y[11] - 69.368640085185334*y[10] - 40.74868784166955*y[13] - 43.675799641021136*y[12] - 17.974903844364817*y[15] - 69.368640085185348*y[14] - y[34];
out[9] = -184.75059629806532*y[1] + 94.615102344455565*y[0] + 69.368640085185334*y[3] - 17.974903844364775*y[2] + 43.675799641021136*y[5] - 40.74868784166955*y[4] + 69.368640085185348*y[7] - 17.974903844364817*y[6] + 184.75059629806532*y[9] - 94.615102344455565*y[8] - 69.368640085185334*y[11] + 17.974903844364775*y[10] - 43.675799641021136*y[13] + 40.74868784166955*y[12] - 69.368640085185348*y[15] + 17.974903844364817*y[14] - y[38];
out[10] = 17.974903844364796*y[1] + 69.368640085185319*y[0] - 94.615102344455607*y[3] - 184.75059629806523*y[2] + 17.974903844364814*y[5] + 69.368640085185291*y[4] + 40.748687841669586*y[7] + 43.675799641021079*y[6] - 17.974903844364796*y[9] - 69.368640085185319*y[8] + 94.615102344455607*y[11] + 184.75059629806523*y[10] - 17.974903844364814*y[13] - 69.368640085185291*y[12] - 40.748687841669586*y[15] - 43.675799641021079*y[14] - y[35];
out[11] = 69.368640085185319*y[1] - 17.974903844364796*y[0] - 184.75059629806523*y[3] + 94.615102344455607*y[2] + 69.368640085185291*y[5] - 17.974903844364814*y[4] + 43.675799641021079*y[7] - 40.748687841669586*y[6] - 69.368640085185319*y[9] + 17.974903844364796*y[8] + 184.75059629806523*y[11] - 94.615102344455607*y[10] - 69.368640085185291*y[13] + 17.974903844364814*y[12] - 43.675799641021079*y[15] + 40.748687841669586*y[14] - y[39];
out[12] = 40.748687841669557*y[1] + 43.675799641021122*y[0] + 17.97490384436481*y[3] + 69.368640085185277*y[2] - 94.615102344455636*y[5] - 184.75059629806526*y[4] + 17.974903844364817*y[7] + 69.368640085185277*y[6] - 40.748687841669557*y[9] - 43.675799641021122*y[8] - 17.97490384436481*y[11] - 69.368640085185277*y[10] + 94.615102344455636*y[13] + 184.75059629806526*y[12] - 17.974903844364817*y[15] - 69.368640085185277*y[14] - y[36];
out[13] = 43.675799641021122*y[1] - 40.748687841669557*y[0] + 69.368640085185277*y[3] - 17.97490384436481*y[2] - 184.75059629806526*y[5] + 94.615102344455636*y[4] + 69.368640085185277*y[7] - 17.974903844364817*y[6] - 43.675799641021122*y[9] + 40.748687841669557*y[8] - 69.368640085185277*y[11] + 17.97490384436481*y[10] + 184.75059629806526*y[13] - 94.615102344455636*y[12] - 69.368640085185277*y[15] + 17.974903844364817*y[14] - y[40];
out[14] = 17.9749038443648*y[1] + 69.368640085185334*y[0] + 40.748687841669586*y[3] + 43.675799641021086*y[2] + 17.974903844364821*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.75059629806523*y[6] - 17.9749038443648*y[9] - 69.368640085185334*y[8] - 40.748687841669586*y[11] - 43.675799641021086*y[10] - 17.974903844364821*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.75059629806523*y[14] - y[37];
out[15] = 69.368640085185334*y[1] - 17.9749038443648*y[0] + 43.675799641021086*y[3] - 40.748687841669586*y[2] + 69.368640085185291*y[5] - 17.974903844364821*y[4] - 184.75059629806523*y[7] + 94.61510234445565*y[6] - 69.368640085185334*y[9] + 17.9749038443648*y[8] - 43.675799641021086*y[11] + 40.748687841669586*y[10] - 69.368640085185291*y[13] + 17.974903844364821*y[12] + 184.75059629806523*y[15] - 94.61510234445565*y[14] - y[41];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[28];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[29];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[30];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[31];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[32];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[33];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[31] + y[16]*y[28] + 1.0*y[22]*y[32] + y[17]*y[29] + 1.0*y[23]*y[33] + 1.0*y[23]*u[1] + y[18]*y[30] + y[18]*u[0] - y[26];
out[27] = p[19]*x[9] + p[23]*u[17] + x[4] - y[27] - (x[1] - u[15])/p[16];
out[28] = -p[10]*y[16] + 1.0*p[9]*y[21] - y[28] + (x[5] + u[2])*cos(x[0] + u[10]);
out[29] = -p[10]*y[17] + 1.0*p[9]*y[22] - y[29] + (x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[30] = -p[10]*y[18] + 1.0*p[9]*y[23] - y[30] + (x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[31] = -1.0*p[10]*y[21] - 1.0*p[9]*y[16] - 1.0*y[31] + 1.0*(x[5] + u[2])*sin(x[0] + u[10]);
out[32] = -1.0*p[10]*y[22] - 1.0*p[9]*y[17] - 1.0*y[32] + 1.0*(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[33] = -1.0*p[10]*y[23] - 1.0*p[9]*y[18] - 1.0*y[33] + 1.0*(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[34] = -p[25]*y[34] - y[8] + 1.0*p[24]*y[38] + u[19]*cos(u[23]);
out[35] = -p[25]*y[35] - y[10] + 1.0*p[24]*y[39] + u[20]*cos(u[23] - 2.0943951023931953);
out[36] = -p[25]*y[36] - y[12] + 1.0*p[24]*y[40] + u[21]*cos(u[23] - 4.1887902047863905);
out[37] = -p[27]*y[37] - y[14] + 1.0*p[26]*y[41];
out[38] = -1.0*p[25]*y[38] - 1.0*y[9] - 1.0*p[24]*y[34] + 1.0*u[19]*sin(u[23]);
out[39] = -1.0*p[25]*y[39] - 1.0*y[11] - 1.0*p[24]*y[35] + 1.0*u[20]*sin(u[23] - 2.0943951023931953);
out[40] = -1.0*p[25]*y[40] - 1.0*y[13] - 1.0*p[24]*y[36] + 1.0*u[21]*sin(u[23] - 4.1887902047863905);
out[41] = -1.0*p[27]*y[41] - 1.0*y[15] - 1.0*p[26]*y[37];
out[42] = -y[42] + (p[11]*x[1] + 1000.0)/(p[11] + 1000.0);
out[43] = p[31]*x[9] + p[30]*(1 - y[42]) - y[43];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455565*y[1] + 184.75059629806532*y[0] - 17.974903844364775*y[3] - 69.368640085185334*y[2] - 40.74868784166955*y[5] - 43.675799641021136*y[4] - 17.974903844364817*y[7] - 69.368640085185348*y[6] - 94.615102344455565*y[9] - 184.75059629806532*y[8] + 17.974903844364775*y[11] + 69.368640085185334*y[10] + 40.74868784166955*y[13] + 43.675799641021136*y[12] + 17.974903844364817*y[15] + 69.368640085185348*y[14];
out[1] = 184.75059629806532*y[1] - 94.615102344455565*y[0] - 69.368640085185334*y[3] + 17.974903844364775*y[2] - 43.675799641021136*y[5] + 40.74868784166955*y[4] - 69.368640085185348*y[7] + 17.974903844364817*y[6] - 184.75059629806532*y[9] + 94.615102344455565*y[8] + 69.368640085185334*y[11] - 17.974903844364775*y[10] + 43.675799641021136*y[13] - 40.74868784166955*y[12] + 69.368640085185348*y[15] - 17.974903844364817*y[14];
out[2] = -17.974903844364796*y[1] - 69.368640085185319*y[0] + 94.615102344455607*y[3] + 184.75059629806523*y[2] - 17.974903844364814*y[5] - 69.368640085185291*y[4] - 40.748687841669586*y[7] - 43.675799641021079*y[6] + 17.974903844364796*y[9] + 69.368640085185319*y[8] - 94.615102344455607*y[11] - 184.75059629806523*y[10] + 17.974903844364814*y[13] + 69.368640085185291*y[12] + 40.748687841669586*y[15] + 43.675799641021079*y[14];
out[3] = -69.368640085185319*y[1] + 17.974903844364796*y[0] + 184.75059629806523*y[3] - 94.615102344455607*y[2] - 69.368640085185291*y[5] + 17.974903844364814*y[4] - 43.675799641021079*y[7] + 40.748687841669586*y[6] + 69.368640085185319*y[9] - 17.974903844364796*y[8] - 184.75059629806523*y[11] + 94.615102344455607*y[10] + 69.368640085185291*y[13] - 17.974903844364814*y[12] + 43.675799641021079*y[15] - 40.748687841669586*y[14];
out[4] = -40.748687841669557*y[1] - 43.675799641021122*y[0] - 17.97490384436481*y[3] - 69.368640085185277*y[2] + 94.615102344455636*y[5] + 184.75059629806526*y[4] - 17.974903844364817*y[7] - 69.368640085185277*y[6] + 40.748687841669557*y[9] + 43.675799641021122*y[8] + 17.97490384436481*y[11] + 69.368640085185277*y[10] - 94.615102344455636*y[13] - 184.75059629806526*y[12] + 17.974903844364817*y[15] + 69.368640085185277*y[14];
out[5] = -43.675799641021122*y[1] + 40.748687841669557*y[0] - 69.368640085185277*y[3] + 17.97490384436481*y[2] + 184.75059629806526*y[5] - 94.615102344455636*y[4] - 69.368640085185277*y[7] + 17.974903844364817*y[6] + 43.675799641021122*y[9] - 40.748687841669557*y[8] + 69.368640085185277*y[11] - 17.97490384436481*y[10] - 184.75059629806526*y[13] + 94.615102344455636*y[12] + 69.368640085185277*y[15] - 17.974903844364817*y[14];
out[6] = -17.9749038443648*y[1] - 69.368640085185334*y[0] - 40.748687841669586*y[3] - 43.675799641021086*y[2] - 17.974903844364821*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.75059629806523*y[6] + 17.9749038443648*y[9] + 69.368640085185334*y[8] + 40.748687841669586*y[11] + 43.675799641021086*y[10] + 17.974903844364821*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.75059629806523*y[14];
out[7] = -69.368640085185334*y[1] + 17.9749038443648*y[0] - 43.675799641021086*y[3] + 40.748687841669586*y[2] - 69.368640085185291*y[5] + 17.974903844364821*y[4] + 184.75059629806523*y[7] - 94.61510234445565*y[6] + 69.368640085185334*y[9] - 17.9749038443648*y[8] + 43.675799641021086*y[11] - 40.748687841669586*y[10] + 69.368640085185291*y[13] - 17.974903844364821*y[12] - 184.75059629806523*y[15] + 94.61510234445565*y[14];
out[8] = sqrt(1.0*pow(y[21], 2) + pow(y[16], 2));
out[9] = sqrt(1.0*pow(y[22], 2) + pow(y[17], 2));
out[10] = sqrt(1.0*pow(y[23], 2) + pow(y[18], 2));
out[11] = sqrt(1.0*pow(y[24], 2) + pow(y[19], 2));
out[12] = 1.0*y[1]*y[21] + y[0]*y[16];
out[13] = 1.0*y[1]*y[16] - 1.0*y[0]*y[21];
out[14] = 1.0*y[3]*y[22] + y[2]*y[17];
out[15] = 1.0*y[3]*y[17] - 1.0*y[2]*y[22];
out[16] = 1.0*y[5]*y[23] + y[4]*y[18];
out[17] = 1.0*y[5]*y[18] - 1.0*y[4]*y[23];
out[18] = 0.33333333333333331*y[1]*y[21] - y[1]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) - y[1]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333331*y[0]*y[16] + y[0]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[0]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) + 0.33333333333333326*y[3]*y[22] - 0.16666666666666652*y[3]*y[23] + 0.28867513459481281*y[3]*y[18] + 0.33333333333333326*y[2]*y[17] - 0.28867513459481281*y[2]*y[23] - 0.16666666666666652*y[2]*y[18] - 0.16666666666666652*y[5]*y[22] - 0.28867513459481281*y[5]*y[17] + 0.33333333333333326*y[5]*y[23] + 0.28867513459481281*y[4]*y[22] - 0.16666666666666652*y[4]*y[17] + 0.33333333333333326*y[4]*y[18] + 1.0*y[21]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[21]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]) + 1.0*y[16]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) + 1.0*y[16]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]);
out[19] = 0.33333333333333331*y[1]*y[21] - y[1]*(0.16666666666666677*y[22] + 0.28867513459481275*y[17]) - y[1]*(0.16666666666666657*y[23] - 0.28867513459481287*y[18]) + 0.33333333333333331*y[0]*y[16] + y[0]*(0.28867513459481275*y[22] - 0.16666666666666677*y[17]) + y[0]*(-0.28867513459481287*y[23] - 0.16666666666666657*y[18]) + 0.33333333333333326*y[3]*y[22] - 0.16666666666666652*y[3]*y[23] - 0.28867513459481281*y[3]*y[18] + 0.33333333333333326*y[2]*y[17] + 0.28867513459481281*y[2]*y[23] - 0.16666666666666652*y[2]*y[18] - 0.16666666666666652*y[5]*y[22] + 0.28867513459481281*y[5]*y[17] + 0.33333333333333326*y[5]*y[23] - 0.28867513459481281*y[4]*y[22] - 0.16666666666666652*y[4]*y[17] + 0.33333333333333326*y[4]*y[18] + 1.0*y[21]*(-0.16666666666666677*y[3] - 0.28867513459481275*y[2]) + 1.0*y[21]*(-0.16666666666666657*y[5] + 0.28867513459481287*y[4]) + 1.0*y[16]*(0.28867513459481275*y[3] - 0.16666666666666677*y[2]) + 1.0*y[16]*(-0.28867513459481287*y[5] - 0.16666666666666657*y[4]);
out[20] = 0.33333333333333331*y[1]*y[21] + 0.33333333333333331*y[1]*y[22] + 0.33333333333333331*y[1]*y[23] + 0.33333333333333331*y[0]*y[16] + 0.33333333333333331*y[0]*y[17] + 0.33333333333333331*y[0]*y[18] + 0.33333333333333331*y[3]*y[21] + 0.33333333333333331*y[3]*y[22] + 0.33333333333333331*y[3]*y[23] + 0.33333333333333331*y[2]*y[16] + 0.33333333333333331*y[2]*y[17] + 0.33333333333333331*y[2]*y[18] + 0.33333333333333331*y[5]*y[21] + 0.33333333333333331*y[5]*y[22] + 0.33333333333333331*y[5]*y[23] + 0.33333333333333331*y[4]*y[16] + 0.33333333333333331*y[4]*y[17] + 0.33333333333333331*y[4]*y[18];
out[21] = 0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]);
out[22] = u[2];
out[23] = u[3];
out[24] = u[4];
out[25] = u[6];
out[26] = u[7];
out[27] = u[8];
out[28] = u[14];
out[29] = u[15];
out[30] = x[0];
out[31] = sqrt(1.0*pow(y[38], 2) + pow(y[34], 2));
out[32] = sqrt(1.0*pow(y[39], 2) + pow(y[35], 2));
out[33] = sqrt(1.0*pow(y[40], 2) + pow(y[36], 2));
out[34] = sqrt(1.0*pow(y[41], 2) + pow(y[37], 2));
out[35] = 1.0*y[9]*y[38] + y[8]*y[34] + 1.0*y[11]*y[39] + y[10]*y[35] + 1.0*y[13]*y[40] + y[12]*y[36];
out[36] = 1.0*y[9]*y[34] - 1.0*y[8]*y[38] + 1.0*y[11]*y[35] - 1.0*y[10]*y[39] + 1.0*y[13]*y[36] - 1.0*y[12]*y[40];
out[37] = x[9];
out[38] = u[24];

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[110] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999;
out[118] = -(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[119] = -(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[120] = -(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[121] = -(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[122] = -(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[123] = -(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[134] = -(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[135] = -(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[136] = -(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[139] = -(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[140] = -(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[141] = -(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[172] = (0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[173] = (0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[174] = (0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[175] = (-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[176] = (-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[177] = (-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[188] = (0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[189] = (0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[190] = (-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[193] = (0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[194] = (-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[195] = (-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[272] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[280] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[281] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[282] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[283] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[284] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[285] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[296] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[297] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[298] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[301] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[302] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[303] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[326] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[334] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[335] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[336] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[337] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[338] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[339] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[350] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[351] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[352] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[355] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[356] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[357] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[380] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[388] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[389] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[390] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[391] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[392] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[393] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[404] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[405] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[406] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[409] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[410] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[411] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[1970] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[1971] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[1972] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[1973] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1975] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[1976] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[1977] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[1978] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1982] = y[16];
out[1983] = y[17];
out[1984] = y[18];
out[1985] = 1.0*y[21];
out[1986] = 1.0*y[22];
out[1987] = 1.0*y[23];
out[2052] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[2057] = cos(x[0] + u[10]);
out[2106] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[2112] = cos(x[0] + u[11] - 2.0943951023931953);
out[2160] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[2167] = cos(x[0] + u[12] - 4.1887902047863905);
out[2214] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[2219] = 1.0*sin(x[0] + u[10]);
out[2268] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[2274] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[2322] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[2329] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20];
out[55] = -0.5*p[18]/p[17];
out[57] = -0.5/p[17];
out[91] = 0.5/p[17];
out[165] = -1/p[13];
out[220] = -1/p[14];
out[275] = -1/p[15];
out[330] = -1/p[15];
out[385] = -1/p[15];
out[440] = -1/p[15];
out[495] = -p[32];
out[1430] = -p[1];
out[1435] = 1.0*p[0];
out[1485] = -p[1];
out[1490] = 1.0*p[0];
out[1540] = -p[1];
out[1545] = 1.0*p[0];
out[1595] = -p[3];
out[1600] = 1.0*p[2];
out[1650] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1655] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1700] = -1.0*p[0];
out[1705] = -1.0*p[1];
out[1755] = -1.0*p[0];
out[1760] = -1.0*p[1];
out[1810] = -1.0*p[0];
out[1815] = -1.0*p[1];
out[1865] = -1.0*p[2];
out[1870] = -1.0*p[3];
out[1920] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1925] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1999] = -1/p[16];
out[2007] = p[19];
out[2078] = -p[10];
out[2083] = 1.0*p[9];
out[2133] = -p[10];
out[2138] = 1.0*p[9];
out[2188] = -p[10];
out[2193] = 1.0*p[9];
out[2240] = -1.0*p[9];
out[2245] = -1.0*p[10];
out[2295] = -1.0*p[9];
out[2300] = -1.0*p[10];
out[2350] = -1.0*p[9];
out[2355] = -1.0*p[10];
out[2420] = -p[25];
out[2424] = 1.0*p[24];
out[2475] = -p[25];
out[2479] = 1.0*p[24];
out[2530] = -p[25];
out[2534] = 1.0*p[24];
out[2585] = -p[27];
out[2589] = 1.0*p[26];
out[2636] = -1.0*p[24];
out[2640] = -1.0*p[25];
out[2691] = -1.0*p[24];
out[2695] = -1.0*p[25];
out[2746] = -1.0*p[24];
out[2750] = -1.0*p[25];
out[2801] = -1.0*p[26];
out[2805] = -1.0*p[27];
out[2809] = p[11]/(p[11] + 1000.0);
out[2871] = p[31];
out[2914] = -p[30];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 314.15926535897933;
out[52] = -314.15926535897933;
out[538] = -1.0;
out[550] = 184.75059629806532;
out[551] = 94.615102344455565;
out[552] = -69.368640085185334;
out[553] = -17.974903844364775;
out[554] = -43.675799641021136;
out[555] = -40.74868784166955;
out[556] = -69.368640085185348;
out[557] = -17.974903844364817;
out[558] = -184.75059629806532;
out[559] = -94.615102344455565;
out[560] = 69.368640085185334;
out[561] = 17.974903844364775;
out[562] = 43.675799641021136;
out[563] = 40.74868784166955;
out[564] = 69.368640085185348;
out[565] = 17.974903844364817;
out[566] = -1.0;
out[604] = -94.615102344455565;
out[605] = 184.75059629806532;
out[606] = 17.974903844364775;
out[607] = -69.368640085185334;
out[608] = 40.74868784166955;
out[609] = -43.675799641021136;
out[610] = 17.974903844364817;
out[611] = -69.368640085185348;
out[612] = 94.615102344455565;
out[613] = -184.75059629806532;
out[614] = -17.974903844364775;
out[615] = 69.368640085185334;
out[616] = -40.74868784166955;
out[617] = 43.675799641021136;
out[618] = -17.974903844364817;
out[619] = 69.368640085185348;
out[625] = -1.0;
out[658] = -69.368640085185319;
out[659] = -17.974903844364796;
out[660] = 184.75059629806523;
out[661] = 94.615102344455607;
out[662] = -69.368640085185291;
out[663] = -17.974903844364814;
out[664] = -43.675799641021079;
out[665] = -40.748687841669586;
out[666] = 69.368640085185319;
out[667] = 17.974903844364796;
out[668] = -184.75059629806523;
out[669] = -94.615102344455607;
out[670] = 69.368640085185291;
out[671] = 17.974903844364814;
out[672] = 43.675799641021079;
out[673] = 40.748687841669586;
out[675] = -1.0;
out[712] = 17.974903844364796;
out[713] = -69.368640085185319;
out[714] = -94.615102344455607;
out[715] = 184.75059629806523;
out[716] = 17.974903844364814;
out[717] = -69.368640085185291;
out[718] = 40.748687841669586;
out[719] = -43.675799641021079;
out[720] = -17.974903844364796;
out[721] = 69.368640085185319;
out[722] = 94.615102344455607;
out[723] = -184.75059629806523;
out[724] = -17.974903844364814;
out[725] = 69.368640085185291;
out[726] = -40.748687841669586;
out[727] = 43.675799641021079;
out[734] = -1.0;
out[766] = -43.675799641021122;
out[767] = -40.748687841669557;
out[768] = -69.368640085185277;
out[769] = -17.97490384436481;
out[770] = 184.75059629806526;
out[771] = 94.615102344455636;
out[772] = -69.368640085185277;
out[773] = -17.974903844364817;
out[774] = 43.675799641021122;
out[775] = 40.748687841669557;
out[776] = 69.368640085185277;
out[777] = 17.97490384436481;
out[778] = -184.75059629806526;
out[779] = -94.615102344455636;
out[780] = 69.368640085185277;
out[781] = 17.974903844364817;
out[784] = -1.0;
out[820] = 40.748687841669557;
out[821] = -43.675799641021122;
out[822] = 17.97490384436481;
out[823] = -69.368640085185277;
out[824] = -94.615102344455636;
out[825] = 184.75059629806526;
out[826] = 17.974903844364817;
out[827] = -69.368640085185277;
out[828] = -40.748687841669557;
out[829] = 43.675799641021122;
out[830] = -17.97490384436481;
out[831] = 69.368640085185277;
out[832] = 94.615102344455636;
out[833] = -184.75059629806526;
out[834] = -17.974903844364817;
out[835] = 69.368640085185277;
out[843] = -1.0;
out[874] = -69.368640085185334;
out[875] = -17.9749038443648;
out[876] = -43.675799641021086;
out[877] = -40.748687841669586;
out[878] = -69.368640085185291;
out[879] = -17.974903844364821;
out[880] = 184.75059629806523;
out[881] = 94.61510234445565;
out[882] = 69.368640085185334;
out[883] = 17.9749038443648;
out[884] = 43.675799641021086;
out[885] = 40.748687841669586;
out[886] = 69.368640085185291;
out[887] = 17.974903844364821;
out[888] = -184.75059629806523;
out[889] = -94.61510234445565;
out[893] = -1.0;
out[928] = 17.9749038443648;
out[929] = -69.368640085185334;
out[930] = 40.748687841669586;
out[931] = -43.675799641021086;
out[932] = 17.974903844364821;
out[933] = -69.368640085185291;
out[934] = -94.61510234445565;
out[935] = 184.75059629806523;
out[936] = -17.9749038443648;
out[937] = 69.368640085185334;
out[938] = -40.748687841669586;
out[939] = 43.675799641021086;
out[940] = -17.974903844364821;
out[941] = 69.368640085185291;
out[942] = 94.61510234445565;
out[943] = -184.75059629806523;
out[952] = -1.0;
out[982] = -184.75059629806532;
out[983] = -94.615102344455565;
out[984] = 69.368640085185334;
out[985] = 17.974903844364775;
out[986] = 43.675799641021136;
out[987] = 40.74868784166955;
out[988] = 69.368640085185348;
out[989] = 17.974903844364817;
out[990] = 184.75059629806532;
out[991] = 94.615102344455565;
out[992] = -69.368640085185334;
out[993] = -17.974903844364775;
out[994] = -43.675799641021136;
out[995] = -40.74868784166955;
out[996] = -69.368640085185348;
out[997] = -17.974903844364817;
out[1016] = -1.0;
out[1036] = 94.615102344455565;
out[1037] = -184.75059629806532;
out[1038] = -17.974903844364775;
out[1039] = 69.368640085185334;
out[1040] = -40.74868784166955;
out[1041] = 43.675799641021136;
out[1042] = -17.974903844364817;
out[1043] = 69.368640085185348;
out[1044] = -94.615102344455565;
out[1045] = 184.75059629806532;
out[1046] = 17.974903844364775;
out[1047] = -69.368640085185334;
out[1048] = 40.74868784166955;
out[1049] = -43.675799641021136;
out[1050] = 17.974903844364817;
out[1051] = -69.368640085185348;
out[1074] = -1.0;
out[1090] = 69.368640085185319;
out[1091] = 17.974903844364796;
out[1092] = -184.75059629806523;
out[1093] = -94.615102344455607;
out[1094] = 69.368640085185291;
out[1095] = 17.974903844364814;
out[1096] = 43.675799641021079;
out[1097] = 40.748687841669586;
out[1098] = -69.368640085185319;
out[1099] = -17.974903844364796;
out[1100] = 184.75059629806523;
out[1101] = 94.615102344455607;
out[1102] = -69.368640085185291;
out[1103] = -17.974903844364814;
out[1104] = -43.675799641021079;
out[1105] = -40.748687841669586;
out[1125] = -1.0;
out[1144] = -17.974903844364796;
out[1145] = 69.368640085185319;
out[1146] = 94.615102344455607;
out[1147] = -184.75059629806523;
out[1148] = -17.974903844364814;
out[1149] = 69.368640085185291;
out[1150] = -40.748687841669586;
out[1151] = 43.675799641021079;
out[1152] = 17.974903844364796;
out[1153] = -69.368640085185319;
out[1154] = -94.615102344455607;
out[1155] = 184.75059629806523;
out[1156] = 17.974903844364814;
out[1157] = -69.368640085185291;
out[1158] = 40.748687841669586;
out[1159] = -43.675799641021079;
out[1183] = -1.0;
out[1198] = 43.675799641021122;
out[1199] = 40.748687841669557;
out[1200] = 69.368640085185277;
out[1201] = 17.97490384436481;
out[1202] = -184.75059629806526;
out[1203] = -94.615102344455636;
out[1204] = 69.368640085185277;
out[1205] = 17.974903844364817;
out[1206] = -43.675799641021122;
out[1207] = -40.748687841669557;
out[1208] = -69.368640085185277;
out[1209] = -17.97490384436481;
out[1210] = 184.75059629806526;
out[1211] = 94.615102344455636;
out[1212] = -69.368640085185277;
out[1213] = -17.974903844364817;
out[1234] = -1.0;
out[1252] = -40.748687841669557;
out[1253] = 43.675799641021122;
out[1254] = -17.97490384436481;
out[1255] = 69.368640085185277;
out[1256] = 94.615102344455636;
out[1257] = -184.75059629806526;
out[1258] = -17.974903844364817;
out[1259] = 69.368640085185277;
out[1260] = 40.748687841669557;
out[1261] = -43.675799641021122;
out[1262] = 17.97490384436481;
out[1263] = -69.368640085185277;
out[1264] = -94.615102344455636;
out[1265] = 184.75059629806526;
out[1266] = 17.974903844364817;
out[1267] = -69.368640085185277;
out[1292] = -1.0;
out[1306] = 69.368640085185334;
out[1307] = 17.9749038443648;
out[1308] = 43.675799641021086;
out[1309] = 40.748687841669586;
out[1310] = 69.368640085185291;
out[1311] = 17.974903844364821;
out[1312] = -184.75059629806523;
out[1313] = -94.61510234445565;
out[1314] = -69.368640085185334;
out[1315] = -17.9749038443648;
out[1316] = -43.675799641021086;
out[1317] = -40.748687841669586;
out[1318] = -69.368640085185291;
out[1319] = -17.974903844364821;
out[1320] = 184.75059629806523;
out[1321] = 94.61510234445565;
out[1343] = -1.0;
out[1360] = -17.9749038443648;
out[1361] = 69.368640085185334;
out[1362] = -40.748687841669586;
out[1363] = 43.675799641021086;
out[1364] = -17.974903844364821;
out[1365] = 69.368640085185291;
out[1366] = 94.61510234445565;
out[1367] = -184.75059629806523;
out[1368] = 17.9749038443648;
out[1369] = -69.368640085185334;
out[1370] = 40.748687841669586;
out[1371] = -43.675799641021086;
out[1372] = 17.974903844364821;
out[1373] = -69.368640085185291;
out[1374] = -94.61510234445565;
out[1375] = 184.75059629806523;
out[1401] = -1.0;
out[1414] = -1.0;
out[1434] = 1.0;
out[1442] = 1.0;
out[1470] = -1.0;
out[1488] = 1.0;
out[1497] = 1.0;
out[1526] = -1.0;
out[1542] = 1.0;
out[1552] = 1.0;
out[1582] = -1.0;
out[1596] = 1.0;
out[1646] = 1.0;
out[1647] = 1.0;
out[1648] = 1.0;
out[1649] = 1.0;
out[1685] = -1.0;
out[1709] = 1.0;
out[1715] = 1.0;
out[1741] = -1.0;
out[1763] = 1.0;
out[1770] = 1.0;
out[1797] = -1.0;
out[1817] = 1.0;
out[1825] = 1.0;
out[1853] = -1.0;
out[1871] = 1.0;
out[1921] = 1.0;
out[1922] = 1.0;
out[1923] = 1.0;
out[1924] = 1.0;
out[1980] = -1.0;
out[2002] = 1.0;
out[2035] = -1.0;
out[2090] = -1.0;
out[2145] = -1.0;
out[2200] = -1.0;
out[2255] = -1.0;
out[2310] = -1.0;
out[2365] = -1.0;
out[2394] = -1.0;
out[2450] = -1.0;
out[2506] = -1.0;
out[2562] = -1.0;
out[2611] = -1.0;
out[2667] = -1.0;
out[2723] = -1.0;
out[2779] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[6] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999;
out[7] = -(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[8] = -(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[9] = -(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[10] = -(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[11] = -(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[12] = -(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[13] = -(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[14] = -(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[15] = -(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[16] = -(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[17] = -(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[18] = -(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[20] = (0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[21] = (0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[22] = (0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[23] = (-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[24] = (-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[25] = (-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[26] = (0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[27] = (0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[28] = (-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[29] = (0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[30] = (-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[31] = (-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[33] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[35] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[36] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[37] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[38] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[39] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[40] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[41] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[42] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[43] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[44] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[45] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[46] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[47] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[49] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[50] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[51] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[52] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[53] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[54] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[55] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[56] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[57] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[58] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[59] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[60] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[61] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[63] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[64] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[65] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[66] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[67] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[68] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[69] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[70] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[71] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[72] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[73] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[74] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[400] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[401] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[402] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[403] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[404] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[405] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[406] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[407] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[409] = y[16];
out[410] = y[17];
out[411] = y[18];
out[412] = 1.0*y[21];
out[413] = 1.0*y[22];
out[414] = 1.0*y[23];
out[419] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[420] = cos(x[0] + u[10]);
out[424] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[425] = cos(x[0] + u[11] - 2.0943951023931953);
out[429] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[430] = cos(x[0] + u[12] - 4.1887902047863905);
out[434] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[435] = 1.0*sin(x[0] + u[10]);
out[439] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[440] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[444] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[445] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20];
out[3] = -0.5*p[18]/p[17];
out[4] = -0.5/p[17];
out[5] = 0.5/p[17];
out[19] = -1/p[13];
out[32] = -1/p[14];
out[34] = -1/p[15];
out[48] = -1/p[15];
out[62] = -1/p[15];
out[75] = -1/p[15];
out[76] = -p[32];
out[351] = -p[1];
out[353] = 1.0*p[0];
out[356] = -p[1];
out[358] = 1.0*p[0];
out[361] = -p[1];
out[363] = 1.0*p[0];
out[366] = -p[3];
out[368] = 1.0*p[2];
out[373] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[376] = -1.0*p[0];
out[377] = -1.0*p[1];
out[381] = -1.0*p[0];
out[382] = -1.0*p[1];
out[386] = -1.0*p[0];
out[387] = -1.0*p[1];
out[391] = -1.0*p[2];
out[392] = -1.0*p[3];
out[394] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[399] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[415] = -1/p[16];
out[417] = p[19];
out[421] = -p[10];
out[422] = 1.0*p[9];
out[426] = -p[10];
out[427] = 1.0*p[9];
out[431] = -p[10];
out[432] = 1.0*p[9];
out[436] = -1.0*p[9];
out[437] = -1.0*p[10];
out[441] = -1.0*p[9];
out[442] = -1.0*p[10];
out[446] = -1.0*p[9];
out[447] = -1.0*p[10];
out[450] = -p[25];
out[451] = 1.0*p[24];
out[453] = -p[25];
out[454] = 1.0*p[24];
out[456] = -p[25];
out[457] = 1.0*p[24];
out[459] = -p[27];
out[460] = 1.0*p[26];
out[462] = -1.0*p[24];
out[463] = -1.0*p[25];
out[465] = -1.0*p[24];
out[466] = -1.0*p[25];
out[468] = -1.0*p[24];
out[469] = -1.0*p[25];
out[471] = -1.0*p[26];
out[472] = -1.0*p[27];
out[473] = p[11]/(p[11] + 1000.0);
out[475] = p[31];
out[476] = -p[30];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 314.15926535897933;
out[2] = -314.15926535897933;
out[77] = -1.0;
out[78] = 184.75059629806532;
out[79] = 94.615102344455565;
out[80] = -69.368640085185334;
out[81] = -17.974903844364775;
out[82] = -43.675799641021136;
out[83] = -40.74868784166955;
out[84] = -69.368640085185348;
out[85] = -17.974903844364817;
out[86] = -184.75059629806532;
out[87] = -94.615102344455565;
out[88] = 69.368640085185334;
out[89] = 17.974903844364775;
out[90] = 43.675799641021136;
out[91] = 40.74868784166955;
out[92] = 69.368640085185348;
out[93] = 17.974903844364817;
out[94] = -1.0;
out[95] = -94.615102344455565;
out[96] = 184.75059629806532;
out[97] = 17.974903844364775;
out[98] = -69.368640085185334;
out[99] = 40.74868784166955;
out[100] = -43.675799641021136;
out[101] = 17.974903844364817;
out[102] = -69.368640085185348;
out[103] = 94.615102344455565;
out[104] = -184.75059629806532;
out[105] = -17.974903844364775;
out[106] = 69.368640085185334;
out[107] = -40.74868784166955;
out[108] = 43.675799641021136;
out[109] = -17.974903844364817;
out[110] = 69.368640085185348;
out[111] = -1.0;
out[112] = -69.368640085185319;
out[113] = -17.974903844364796;
out[114] = 184.75059629806523;
out[115] = 94.615102344455607;
out[116] = -69.368640085185291;
out[117] = -17.974903844364814;
out[118] = -43.675799641021079;
out[119] = -40.748687841669586;
out[120] = 69.368640085185319;
out[121] = 17.974903844364796;
out[122] = -184.75059629806523;
out[123] = -94.615102344455607;
out[124] = 69.368640085185291;
out[125] = 17.974903844364814;
out[126] = 43.675799641021079;
out[127] = 40.748687841669586;
out[128] = -1.0;
out[129] = 17.974903844364796;
out[130] = -69.368640085185319;
out[131] = -94.615102344455607;
out[132] = 184.75059629806523;
out[133] = 17.974903844364814;
out[134] = -69.368640085185291;
out[135] = 40.748687841669586;
out[136] = -43.675799641021079;
out[137] = -17.974903844364796;
out[138] = 69.368640085185319;
out[139] = 94.615102344455607;
out[140] = -184.75059629806523;
out[141] = -17.974903844364814;
out[142] = 69.368640085185291;
out[143] = -40.748687841669586;
out[144] = 43.675799641021079;
out[145] = -1.0;
out[146] = -43.675799641021122;
out[147] = -40.748687841669557;
out[148] = -69.368640085185277;
out[149] = -17.97490384436481;
out[150] = 184.75059629806526;
out[151] = 94.615102344455636;
out[152] = -69.368640085185277;
out[153] = -17.974903844364817;
out[154] = 43.675799641021122;
out[155] = 40.748687841669557;
out[156] = 69.368640085185277;
out[157] = 17.97490384436481;
out[158] = -184.75059629806526;
out[159] = -94.615102344455636;
out[160] = 69.368640085185277;
out[161] = 17.974903844364817;
out[162] = -1.0;
out[163] = 40.748687841669557;
out[164] = -43.675799641021122;
out[165] = 17.97490384436481;
out[166] = -69.368640085185277;
out[167] = -94.615102344455636;
out[168] = 184.75059629806526;
out[169] = 17.974903844364817;
out[170] = -69.368640085185277;
out[171] = -40.748687841669557;
out[172] = 43.675799641021122;
out[173] = -17.97490384436481;
out[174] = 69.368640085185277;
out[175] = 94.615102344455636;
out[176] = -184.75059629806526;
out[177] = -17.974903844364817;
out[178] = 69.368640085185277;
out[179] = -1.0;
out[180] = -69.368640085185334;
out[181] = -17.9749038443648;
out[182] = -43.675799641021086;
out[183] = -40.748687841669586;
out[184] = -69.368640085185291;
out[185] = -17.974903844364821;
out[186] = 184.75059629806523;
out[187] = 94.61510234445565;
out[188] = 69.368640085185334;
out[189] = 17.9749038443648;
out[190] = 43.675799641021086;
out[191] = 40.748687841669586;
out[192] = 69.368640085185291;
out[193] = 17.974903844364821;
out[194] = -184.75059629806523;
out[195] = -94.61510234445565;
out[196] = -1.0;
out[197] = 17.9749038443648;
out[198] = -69.368640085185334;
out[199] = 40.748687841669586;
out[200] = -43.675799641021086;
out[201] = 17.974903844364821;
out[202] = -69.368640085185291;
out[203] = -94.61510234445565;
out[204] = 184.75059629806523;
out[205] = -17.9749038443648;
out[206] = 69.368640085185334;
out[207] = -40.748687841669586;
out[208] = 43.675799641021086;
out[209] = -17.974903844364821;
out[210] = 69.368640085185291;
out[211] = 94.61510234445565;
out[212] = -184.75059629806523;
out[213] = -1.0;
out[214] = -184.75059629806532;
out[215] = -94.615102344455565;
out[216] = 69.368640085185334;
out[217] = 17.974903844364775;
out[218] = 43.675799641021136;
out[219] = 40.74868784166955;
out[220] = 69.368640085185348;
out[221] = 17.974903844364817;
out[222] = 184.75059629806532;
out[223] = 94.615102344455565;
out[224] = -69.368640085185334;
out[225] = -17.974903844364775;
out[226] = -43.675799641021136;
out[227] = -40.74868784166955;
out[228] = -69.368640085185348;
out[229] = -17.974903844364817;
out[230] = -1.0;
out[231] = 94.615102344455565;
out[232] = -184.75059629806532;
out[233] = -17.974903844364775;
out[234] = 69.368640085185334;
out[235] = -40.74868784166955;
out[236] = 43.675799641021136;
out[237] = -17.974903844364817;
out[238] = 69.368640085185348;
out[239] = -94.615102344455565;
out[240] = 184.75059629806532;
out[241] = 17.974903844364775;
out[242] = -69.368640085185334;
out[243] = 40.74868784166955;
out[244] = -43.675799641021136;
out[245] = 17.974903844364817;
out[246] = -69.368640085185348;
out[247] = -1.0;
out[248] = 69.368640085185319;
out[249] = 17.974903844364796;
out[250] = -184.75059629806523;
out[251] = -94.615102344455607;
out[252] = 69.368640085185291;
out[253] = 17.974903844364814;
out[254] = 43.675799641021079;
out[255] = 40.748687841669586;
out[256] = -69.368640085185319;
out[257] = -17.974903844364796;
out[258] = 184.75059629806523;
out[259] = 94.615102344455607;
out[260] = -69.368640085185291;
out[261] = -17.974903844364814;
out[262] = -43.675799641021079;
out[263] = -40.748687841669586;
out[264] = -1.0;
out[265] = -17.974903844364796;
out[266] = 69.368640085185319;
out[267] = 94.615102344455607;
out[268] = -184.75059629806523;
out[269] = -17.974903844364814;
out[270] = 69.368640085185291;
out[271] = -40.748687841669586;
out[272] = 43.675799641021079;
out[273] = 17.974903844364796;
out[274] = -69.368640085185319;
out[275] = -94.615102344455607;
out[276] = 184.75059629806523;
out[277] = 17.974903844364814;
out[278] = -69.368640085185291;
out[279] = 40.748687841669586;
out[280] = -43.675799641021079;
out[281] = -1.0;
out[282] = 43.675799641021122;
out[283] = 40.748687841669557;
out[284] = 69.368640085185277;
out[285] = 17.97490384436481;
out[286] = -184.75059629806526;
out[287] = -94.615102344455636;
out[288] = 69.368640085185277;
out[289] = 17.974903844364817;
out[290] = -43.675799641021122;
out[291] = -40.748687841669557;
out[292] = -69.368640085185277;
out[293] = -17.97490384436481;
out[294] = 184.75059629806526;
out[295] = 94.615102344455636;
out[296] = -69.368640085185277;
out[297] = -17.974903844364817;
out[298] = -1.0;
out[299] = -40.748687841669557;
out[300] = 43.675799641021122;
out[301] = -17.97490384436481;
out[302] = 69.368640085185277;
out[303] = 94.615102344455636;
out[304] = -184.75059629806526;
out[305] = -17.974903844364817;
out[306] = 69.368640085185277;
out[307] = 40.748687841669557;
out[308] = -43.675799641021122;
out[309] = 17.97490384436481;
out[310] = -69.368640085185277;
out[311] = -94.615102344455636;
out[312] = 184.75059629806526;
out[313] = 17.974903844364817;
out[314] = -69.368640085185277;
out[315] = -1.0;
out[316] = 69.368640085185334;
out[317] = 17.9749038443648;
out[318] = 43.675799641021086;
out[319] = 40.748687841669586;
out[320] = 69.368640085185291;
out[321] = 17.974903844364821;
out[322] = -184.75059629806523;
out[323] = -94.61510234445565;
out[324] = -69.368640085185334;
out[325] = -17.9749038443648;
out[326] = -43.675799641021086;
out[327] = -40.748687841669586;
out[328] = -69.368640085185291;
out[329] = -17.974903844364821;
out[330] = 184.75059629806523;
out[331] = 94.61510234445565;
out[332] = -1.0;
out[333] = -17.9749038443648;
out[334] = 69.368640085185334;
out[335] = -40.748687841669586;
out[336] = 43.675799641021086;
out[337] = -17.974903844364821;
out[338] = 69.368640085185291;
out[339] = 94.61510234445565;
out[340] = -184.75059629806523;
out[341] = 17.9749038443648;
out[342] = -69.368640085185334;
out[343] = 40.748687841669586;
out[344] = -43.675799641021086;
out[345] = 17.974903844364821;
out[346] = -69.368640085185291;
out[347] = -94.61510234445565;
out[348] = 184.75059629806523;
out[349] = -1.0;
out[350] = -1.0;
out[352] = 1.0;
out[354] = 1.0;
out[355] = -1.0;
out[357] = 1.0;
out[359] = 1.0;
out[360] = -1.0;
out[362] = 1.0;
out[364] = 1.0;
out[365] = -1.0;
out[367] = 1.0;
out[369] = 1.0;
out[370] = 1.0;
out[371] = 1.0;
out[372] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = 1.0;
out[380] = -1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = 1.0;
out[390] = -1.0;
out[393] = 1.0;
out[395] = 1.0;
out[396] = 1.0;
out[397] = 1.0;
out[398] = 1.0;
out[408] = -1.0;
out[416] = 1.0;
out[418] = -1.0;
out[423] = -1.0;
out[428] = -1.0;
out[433] = -1.0;
out[438] = -1.0;
out[443] = -1.0;
out[448] = -1.0;
out[449] = -1.0;
out[452] = -1.0;
out[455] = -1.0;
out[458] = -1.0;
out[461] = -1.0;
out[464] = -1.0;
out[467] = -1.0;
out[470] = -1.0;
out[474] = -1.0;
out[477] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[110] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999;
out[118] = -(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[119] = -(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[120] = -(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[121] = -(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[122] = -(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[123] = -(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[134] = -(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[135] = -(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[136] = -(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[139] = -(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[140] = -(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[141] = -(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[172] = (0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[173] = (0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[174] = (0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[175] = (-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[176] = (-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[177] = (-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[188] = (0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[189] = (0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[190] = (-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[193] = (0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[194] = (-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[195] = (-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[272] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[280] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[281] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[282] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[283] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[284] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[285] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[296] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[297] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[298] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[301] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[302] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[303] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[326] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[334] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[335] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[336] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[337] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[338] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[339] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[350] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[351] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[352] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[355] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[356] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[357] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[380] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[388] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[389] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[390] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[391] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[392] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[393] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[404] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[405] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[406] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[409] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[410] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[411] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[1970] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[1971] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[1972] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[1973] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1975] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[1976] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[1977] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[1978] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1982] = y[16];
out[1983] = y[17];
out[1984] = y[18];
out[1985] = 1.0*y[21];
out[1986] = 1.0*y[22];
out[1987] = 1.0*y[23];
out[2052] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[2057] = cos(x[0] + u[10]);
out[2106] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[2112] = cos(x[0] + u[11] - 2.0943951023931953);
out[2160] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[2167] = cos(x[0] + u[12] - 4.1887902047863905);
out[2214] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[2219] = 1.0*sin(x[0] + u[10]);
out[2268] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[2274] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[2322] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[2329] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20];
out[55] = -0.5*p[18]/p[17];
out[57] = -0.5/p[17];
out[91] = 0.5/p[17];
out[165] = -1/p[13];
out[220] = -1/p[14];
out[275] = -1/p[15];
out[330] = -1/p[15];
out[385] = -1/p[15];
out[440] = -1/p[15];
out[495] = -p[32];
out[1430] = -p[1];
out[1435] = 1.0*p[0];
out[1485] = -p[1];
out[1490] = 1.0*p[0];
out[1540] = -p[1];
out[1545] = 1.0*p[0];
out[1595] = -p[3];
out[1600] = 1.0*p[2];
out[1650] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1655] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1700] = -1.0*p[0];
out[1705] = -1.0*p[1];
out[1755] = -1.0*p[0];
out[1760] = -1.0*p[1];
out[1810] = -1.0*p[0];
out[1815] = -1.0*p[1];
out[1865] = -1.0*p[2];
out[1870] = -1.0*p[3];
out[1920] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1925] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1999] = -1/p[16];
out[2007] = p[19];
out[2078] = -p[10];
out[2083] = 1.0*p[9];
out[2133] = -p[10];
out[2138] = 1.0*p[9];
out[2188] = -p[10];
out[2193] = 1.0*p[9];
out[2240] = -1.0*p[9];
out[2245] = -1.0*p[10];
out[2295] = -1.0*p[9];
out[2300] = -1.0*p[10];
out[2350] = -1.0*p[9];
out[2355] = -1.0*p[10];
out[2420] = -p[25];
out[2424] = 1.0*p[24];
out[2475] = -p[25];
out[2479] = 1.0*p[24];
out[2530] = -p[25];
out[2534] = 1.0*p[24];
out[2585] = -p[27];
out[2589] = 1.0*p[26];
out[2636] = -1.0*p[24];
out[2640] = -1.0*p[25];
out[2691] = -1.0*p[24];
out[2695] = -1.0*p[25];
out[2746] = -1.0*p[24];
out[2750] = -1.0*p[25];
out[2801] = -1.0*p[26];
out[2805] = -1.0*p[27];
out[2809] = p[11]/(p[11] + 1000.0);
out[2871] = p[31];
out[2914] = -p[30];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 314.15926535897933;
out[52] = -314.15926535897933;
out[538] = -1.0;
out[550] = 184.75059629806532;
out[551] = 94.615102344455565;
out[552] = -69.368640085185334;
out[553] = -17.974903844364775;
out[554] = -43.675799641021136;
out[555] = -40.74868784166955;
out[556] = -69.368640085185348;
out[557] = -17.974903844364817;
out[558] = -184.75059629806532;
out[559] = -94.615102344455565;
out[560] = 69.368640085185334;
out[561] = 17.974903844364775;
out[562] = 43.675799641021136;
out[563] = 40.74868784166955;
out[564] = 69.368640085185348;
out[565] = 17.974903844364817;
out[566] = -1.0;
out[604] = -94.615102344455565;
out[605] = 184.75059629806532;
out[606] = 17.974903844364775;
out[607] = -69.368640085185334;
out[608] = 40.74868784166955;
out[609] = -43.675799641021136;
out[610] = 17.974903844364817;
out[611] = -69.368640085185348;
out[612] = 94.615102344455565;
out[613] = -184.75059629806532;
out[614] = -17.974903844364775;
out[615] = 69.368640085185334;
out[616] = -40.74868784166955;
out[617] = 43.675799641021136;
out[618] = -17.974903844364817;
out[619] = 69.368640085185348;
out[625] = -1.0;
out[658] = -69.368640085185319;
out[659] = -17.974903844364796;
out[660] = 184.75059629806523;
out[661] = 94.615102344455607;
out[662] = -69.368640085185291;
out[663] = -17.974903844364814;
out[664] = -43.675799641021079;
out[665] = -40.748687841669586;
out[666] = 69.368640085185319;
out[667] = 17.974903844364796;
out[668] = -184.75059629806523;
out[669] = -94.615102344455607;
out[670] = 69.368640085185291;
out[671] = 17.974903844364814;
out[672] = 43.675799641021079;
out[673] = 40.748687841669586;
out[675] = -1.0;
out[712] = 17.974903844364796;
out[713] = -69.368640085185319;
out[714] = -94.615102344455607;
out[715] = 184.75059629806523;
out[716] = 17.974903844364814;
out[717] = -69.368640085185291;
out[718] = 40.748687841669586;
out[719] = -43.675799641021079;
out[720] = -17.974903844364796;
out[721] = 69.368640085185319;
out[722] = 94.615102344455607;
out[723] = -184.75059629806523;
out[724] = -17.974903844364814;
out[725] = 69.368640085185291;
out[726] = -40.748687841669586;
out[727] = 43.675799641021079;
out[734] = -1.0;
out[766] = -43.675799641021122;
out[767] = -40.748687841669557;
out[768] = -69.368640085185277;
out[769] = -17.97490384436481;
out[770] = 184.75059629806526;
out[771] = 94.615102344455636;
out[772] = -69.368640085185277;
out[773] = -17.974903844364817;
out[774] = 43.675799641021122;
out[775] = 40.748687841669557;
out[776] = 69.368640085185277;
out[777] = 17.97490384436481;
out[778] = -184.75059629806526;
out[779] = -94.615102344455636;
out[780] = 69.368640085185277;
out[781] = 17.974903844364817;
out[784] = -1.0;
out[820] = 40.748687841669557;
out[821] = -43.675799641021122;
out[822] = 17.97490384436481;
out[823] = -69.368640085185277;
out[824] = -94.615102344455636;
out[825] = 184.75059629806526;
out[826] = 17.974903844364817;
out[827] = -69.368640085185277;
out[828] = -40.748687841669557;
out[829] = 43.675799641021122;
out[830] = -17.97490384436481;
out[831] = 69.368640085185277;
out[832] = 94.615102344455636;
out[833] = -184.75059629806526;
out[834] = -17.974903844364817;
out[835] = 69.368640085185277;
out[843] = -1.0;
out[874] = -69.368640085185334;
out[875] = -17.9749038443648;
out[876] = -43.675799641021086;
out[877] = -40.748687841669586;
out[878] = -69.368640085185291;
out[879] = -17.974903844364821;
out[880] = 184.75059629806523;
out[881] = 94.61510234445565;
out[882] = 69.368640085185334;
out[883] = 17.9749038443648;
out[884] = 43.675799641021086;
out[885] = 40.748687841669586;
out[886] = 69.368640085185291;
out[887] = 17.974903844364821;
out[888] = -184.75059629806523;
out[889] = -94.61510234445565;
out[893] = -1.0;
out[928] = 17.9749038443648;
out[929] = -69.368640085185334;
out[930] = 40.748687841669586;
out[931] = -43.675799641021086;
out[932] = 17.974903844364821;
out[933] = -69.368640085185291;
out[934] = -94.61510234445565;
out[935] = 184.75059629806523;
out[936] = -17.9749038443648;
out[937] = 69.368640085185334;
out[938] = -40.748687841669586;
out[939] = 43.675799641021086;
out[940] = -17.974903844364821;
out[941] = 69.368640085185291;
out[942] = 94.61510234445565;
out[943] = -184.75059629806523;
out[952] = -1.0;
out[982] = -184.75059629806532;
out[983] = -94.615102344455565;
out[984] = 69.368640085185334;
out[985] = 17.974903844364775;
out[986] = 43.675799641021136;
out[987] = 40.74868784166955;
out[988] = 69.368640085185348;
out[989] = 17.974903844364817;
out[990] = 184.75059629806532;
out[991] = 94.615102344455565;
out[992] = -69.368640085185334;
out[993] = -17.974903844364775;
out[994] = -43.675799641021136;
out[995] = -40.74868784166955;
out[996] = -69.368640085185348;
out[997] = -17.974903844364817;
out[1016] = -1.0;
out[1036] = 94.615102344455565;
out[1037] = -184.75059629806532;
out[1038] = -17.974903844364775;
out[1039] = 69.368640085185334;
out[1040] = -40.74868784166955;
out[1041] = 43.675799641021136;
out[1042] = -17.974903844364817;
out[1043] = 69.368640085185348;
out[1044] = -94.615102344455565;
out[1045] = 184.75059629806532;
out[1046] = 17.974903844364775;
out[1047] = -69.368640085185334;
out[1048] = 40.74868784166955;
out[1049] = -43.675799641021136;
out[1050] = 17.974903844364817;
out[1051] = -69.368640085185348;
out[1074] = -1.0;
out[1090] = 69.368640085185319;
out[1091] = 17.974903844364796;
out[1092] = -184.75059629806523;
out[1093] = -94.615102344455607;
out[1094] = 69.368640085185291;
out[1095] = 17.974903844364814;
out[1096] = 43.675799641021079;
out[1097] = 40.748687841669586;
out[1098] = -69.368640085185319;
out[1099] = -17.974903844364796;
out[1100] = 184.75059629806523;
out[1101] = 94.615102344455607;
out[1102] = -69.368640085185291;
out[1103] = -17.974903844364814;
out[1104] = -43.675799641021079;
out[1105] = -40.748687841669586;
out[1125] = -1.0;
out[1144] = -17.974903844364796;
out[1145] = 69.368640085185319;
out[1146] = 94.615102344455607;
out[1147] = -184.75059629806523;
out[1148] = -17.974903844364814;
out[1149] = 69.368640085185291;
out[1150] = -40.748687841669586;
out[1151] = 43.675799641021079;
out[1152] = 17.974903844364796;
out[1153] = -69.368640085185319;
out[1154] = -94.615102344455607;
out[1155] = 184.75059629806523;
out[1156] = 17.974903844364814;
out[1157] = -69.368640085185291;
out[1158] = 40.748687841669586;
out[1159] = -43.675799641021079;
out[1183] = -1.0;
out[1198] = 43.675799641021122;
out[1199] = 40.748687841669557;
out[1200] = 69.368640085185277;
out[1201] = 17.97490384436481;
out[1202] = -184.75059629806526;
out[1203] = -94.615102344455636;
out[1204] = 69.368640085185277;
out[1205] = 17.974903844364817;
out[1206] = -43.675799641021122;
out[1207] = -40.748687841669557;
out[1208] = -69.368640085185277;
out[1209] = -17.97490384436481;
out[1210] = 184.75059629806526;
out[1211] = 94.615102344455636;
out[1212] = -69.368640085185277;
out[1213] = -17.974903844364817;
out[1234] = -1.0;
out[1252] = -40.748687841669557;
out[1253] = 43.675799641021122;
out[1254] = -17.97490384436481;
out[1255] = 69.368640085185277;
out[1256] = 94.615102344455636;
out[1257] = -184.75059629806526;
out[1258] = -17.974903844364817;
out[1259] = 69.368640085185277;
out[1260] = 40.748687841669557;
out[1261] = -43.675799641021122;
out[1262] = 17.97490384436481;
out[1263] = -69.368640085185277;
out[1264] = -94.615102344455636;
out[1265] = 184.75059629806526;
out[1266] = 17.974903844364817;
out[1267] = -69.368640085185277;
out[1292] = -1.0;
out[1306] = 69.368640085185334;
out[1307] = 17.9749038443648;
out[1308] = 43.675799641021086;
out[1309] = 40.748687841669586;
out[1310] = 69.368640085185291;
out[1311] = 17.974903844364821;
out[1312] = -184.75059629806523;
out[1313] = -94.61510234445565;
out[1314] = -69.368640085185334;
out[1315] = -17.9749038443648;
out[1316] = -43.675799641021086;
out[1317] = -40.748687841669586;
out[1318] = -69.368640085185291;
out[1319] = -17.974903844364821;
out[1320] = 184.75059629806523;
out[1321] = 94.61510234445565;
out[1343] = -1.0;
out[1360] = -17.9749038443648;
out[1361] = 69.368640085185334;
out[1362] = -40.748687841669586;
out[1363] = 43.675799641021086;
out[1364] = -17.974903844364821;
out[1365] = 69.368640085185291;
out[1366] = 94.61510234445565;
out[1367] = -184.75059629806523;
out[1368] = 17.9749038443648;
out[1369] = -69.368640085185334;
out[1370] = 40.748687841669586;
out[1371] = -43.675799641021086;
out[1372] = 17.974903844364821;
out[1373] = -69.368640085185291;
out[1374] = -94.61510234445565;
out[1375] = 184.75059629806523;
out[1401] = -1.0;
out[1414] = -1.0;
out[1434] = 1.0;
out[1442] = 1.0;
out[1470] = -1.0;
out[1488] = 1.0;
out[1497] = 1.0;
out[1526] = -1.0;
out[1542] = 1.0;
out[1552] = 1.0;
out[1582] = -1.0;
out[1596] = 1.0;
out[1646] = 1.0;
out[1647] = 1.0;
out[1648] = 1.0;
out[1649] = 1.0;
out[1685] = -1.0;
out[1709] = 1.0;
out[1715] = 1.0;
out[1741] = -1.0;
out[1763] = 1.0;
out[1770] = 1.0;
out[1797] = -1.0;
out[1817] = 1.0;
out[1825] = 1.0;
out[1853] = -1.0;
out[1871] = 1.0;
out[1921] = 1.0;
out[1922] = 1.0;
out[1923] = 1.0;
out[1924] = 1.0;
out[1980] = -1.0;
out[2002] = 1.0;
out[2035] = -1.0;
out[2090] = -1.0;
out[2145] = -1.0;
out[2200] = -1.0;
out[2255] = -1.0;
out[2310] = -1.0;
out[2365] = -1.0;
out[2394] = -1.0;
out[2450] = -1.0;
out[2506] = -1.0;
out[2562] = -1.0;
out[2611] = -1.0;
out[2667] = -1.0;
out[2723] = -1.0;
out[2779] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[6] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999;
out[7] = -(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[8] = -(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[9] = -(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[10] = -(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[11] = -(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[12] = -(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[13] = -(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[14] = -(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[15] = -(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[16] = -(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[17] = -(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[18] = -(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[20] = (0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[21] = (0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[22] = (0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[23] = (-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[24] = (-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[25] = (-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[26] = (0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[27] = (0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[28] = (-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[29] = (0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[30] = (-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[31] = (-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[33] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[35] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[36] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[37] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[38] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[39] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[40] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[41] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[42] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[43] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[44] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[45] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[46] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[47] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[49] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[50] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[51] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[52] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[53] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[54] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[55] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[56] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[57] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[58] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[59] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[60] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[61] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[63] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[64] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[65] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[66] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[67] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[68] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[69] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[70] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[71] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[72] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[73] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[74] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[400] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[401] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[402] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[403] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[404] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[405] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[406] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[407] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[409] = y[16];
out[410] = y[17];
out[411] = y[18];
out[412] = 1.0*y[21];
out[413] = 1.0*y[22];
out[414] = 1.0*y[23];
out[419] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[420] = cos(x[0] + u[10]);
out[424] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[425] = cos(x[0] + u[11] - 2.0943951023931953);
out[429] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[430] = cos(x[0] + u[12] - 4.1887902047863905);
out[434] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[435] = 1.0*sin(x[0] + u[10]);
out[439] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[440] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[444] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[445] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[20];
out[3] = -0.5*p[18]/p[17];
out[4] = -0.5/p[17];
out[5] = 0.5/p[17];
out[19] = -1/p[13];
out[32] = -1/p[14];
out[34] = -1/p[15];
out[48] = -1/p[15];
out[62] = -1/p[15];
out[75] = -1/p[15];
out[76] = -p[32];
out[351] = -p[1];
out[353] = 1.0*p[0];
out[356] = -p[1];
out[358] = 1.0*p[0];
out[361] = -p[1];
out[363] = 1.0*p[0];
out[366] = -p[3];
out[368] = 1.0*p[2];
out[373] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[376] = -1.0*p[0];
out[377] = -1.0*p[1];
out[381] = -1.0*p[0];
out[382] = -1.0*p[1];
out[386] = -1.0*p[0];
out[387] = -1.0*p[1];
out[391] = -1.0*p[2];
out[392] = -1.0*p[3];
out[394] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[399] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[415] = -1/p[16];
out[417] = p[19];
out[421] = -p[10];
out[422] = 1.0*p[9];
out[426] = -p[10];
out[427] = 1.0*p[9];
out[431] = -p[10];
out[432] = 1.0*p[9];
out[436] = -1.0*p[9];
out[437] = -1.0*p[10];
out[441] = -1.0*p[9];
out[442] = -1.0*p[10];
out[446] = -1.0*p[9];
out[447] = -1.0*p[10];
out[450] = -p[25];
out[451] = 1.0*p[24];
out[453] = -p[25];
out[454] = 1.0*p[24];
out[456] = -p[25];
out[457] = 1.0*p[24];
out[459] = -p[27];
out[460] = 1.0*p[26];
out[462] = -1.0*p[24];
out[463] = -1.0*p[25];
out[465] = -1.0*p[24];
out[466] = -1.0*p[25];
out[468] = -1.0*p[24];
out[469] = -1.0*p[25];
out[471] = -1.0*p[26];
out[472] = -1.0*p[27];
out[473] = p[11]/(p[11] + 1000.0);
out[475] = p[31];
out[476] = -p[30];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 314.15926535897933;
out[2] = -314.15926535897933;
out[77] = -1.0;
out[78] = 184.75059629806532;
out[79] = 94.615102344455565;
out[80] = -69.368640085185334;
out[81] = -17.974903844364775;
out[82] = -43.675799641021136;
out[83] = -40.74868784166955;
out[84] = -69.368640085185348;
out[85] = -17.974903844364817;
out[86] = -184.75059629806532;
out[87] = -94.615102344455565;
out[88] = 69.368640085185334;
out[89] = 17.974903844364775;
out[90] = 43.675799641021136;
out[91] = 40.74868784166955;
out[92] = 69.368640085185348;
out[93] = 17.974903844364817;
out[94] = -1.0;
out[95] = -94.615102344455565;
out[96] = 184.75059629806532;
out[97] = 17.974903844364775;
out[98] = -69.368640085185334;
out[99] = 40.74868784166955;
out[100] = -43.675799641021136;
out[101] = 17.974903844364817;
out[102] = -69.368640085185348;
out[103] = 94.615102344455565;
out[104] = -184.75059629806532;
out[105] = -17.974903844364775;
out[106] = 69.368640085185334;
out[107] = -40.74868784166955;
out[108] = 43.675799641021136;
out[109] = -17.974903844364817;
out[110] = 69.368640085185348;
out[111] = -1.0;
out[112] = -69.368640085185319;
out[113] = -17.974903844364796;
out[114] = 184.75059629806523;
out[115] = 94.615102344455607;
out[116] = -69.368640085185291;
out[117] = -17.974903844364814;
out[118] = -43.675799641021079;
out[119] = -40.748687841669586;
out[120] = 69.368640085185319;
out[121] = 17.974903844364796;
out[122] = -184.75059629806523;
out[123] = -94.615102344455607;
out[124] = 69.368640085185291;
out[125] = 17.974903844364814;
out[126] = 43.675799641021079;
out[127] = 40.748687841669586;
out[128] = -1.0;
out[129] = 17.974903844364796;
out[130] = -69.368640085185319;
out[131] = -94.615102344455607;
out[132] = 184.75059629806523;
out[133] = 17.974903844364814;
out[134] = -69.368640085185291;
out[135] = 40.748687841669586;
out[136] = -43.675799641021079;
out[137] = -17.974903844364796;
out[138] = 69.368640085185319;
out[139] = 94.615102344455607;
out[140] = -184.75059629806523;
out[141] = -17.974903844364814;
out[142] = 69.368640085185291;
out[143] = -40.748687841669586;
out[144] = 43.675799641021079;
out[145] = -1.0;
out[146] = -43.675799641021122;
out[147] = -40.748687841669557;
out[148] = -69.368640085185277;
out[149] = -17.97490384436481;
out[150] = 184.75059629806526;
out[151] = 94.615102344455636;
out[152] = -69.368640085185277;
out[153] = -17.974903844364817;
out[154] = 43.675799641021122;
out[155] = 40.748687841669557;
out[156] = 69.368640085185277;
out[157] = 17.97490384436481;
out[158] = -184.75059629806526;
out[159] = -94.615102344455636;
out[160] = 69.368640085185277;
out[161] = 17.974903844364817;
out[162] = -1.0;
out[163] = 40.748687841669557;
out[164] = -43.675799641021122;
out[165] = 17.97490384436481;
out[166] = -69.368640085185277;
out[167] = -94.615102344455636;
out[168] = 184.75059629806526;
out[169] = 17.974903844364817;
out[170] = -69.368640085185277;
out[171] = -40.748687841669557;
out[172] = 43.675799641021122;
out[173] = -17.97490384436481;
out[174] = 69.368640085185277;
out[175] = 94.615102344455636;
out[176] = -184.75059629806526;
out[177] = -17.974903844364817;
out[178] = 69.368640085185277;
out[179] = -1.0;
out[180] = -69.368640085185334;
out[181] = -17.9749038443648;
out[182] = -43.675799641021086;
out[183] = -40.748687841669586;
out[184] = -69.368640085185291;
out[185] = -17.974903844364821;
out[186] = 184.75059629806523;
out[187] = 94.61510234445565;
out[188] = 69.368640085185334;
out[189] = 17.9749038443648;
out[190] = 43.675799641021086;
out[191] = 40.748687841669586;
out[192] = 69.368640085185291;
out[193] = 17.974903844364821;
out[194] = -184.75059629806523;
out[195] = -94.61510234445565;
out[196] = -1.0;
out[197] = 17.9749038443648;
out[198] = -69.368640085185334;
out[199] = 40.748687841669586;
out[200] = -43.675799641021086;
out[201] = 17.974903844364821;
out[202] = -69.368640085185291;
out[203] = -94.61510234445565;
out[204] = 184.75059629806523;
out[205] = -17.9749038443648;
out[206] = 69.368640085185334;
out[207] = -40.748687841669586;
out[208] = 43.675799641021086;
out[209] = -17.974903844364821;
out[210] = 69.368640085185291;
out[211] = 94.61510234445565;
out[212] = -184.75059629806523;
out[213] = -1.0;
out[214] = -184.75059629806532;
out[215] = -94.615102344455565;
out[216] = 69.368640085185334;
out[217] = 17.974903844364775;
out[218] = 43.675799641021136;
out[219] = 40.74868784166955;
out[220] = 69.368640085185348;
out[221] = 17.974903844364817;
out[222] = 184.75059629806532;
out[223] = 94.615102344455565;
out[224] = -69.368640085185334;
out[225] = -17.974903844364775;
out[226] = -43.675799641021136;
out[227] = -40.74868784166955;
out[228] = -69.368640085185348;
out[229] = -17.974903844364817;
out[230] = -1.0;
out[231] = 94.615102344455565;
out[232] = -184.75059629806532;
out[233] = -17.974903844364775;
out[234] = 69.368640085185334;
out[235] = -40.74868784166955;
out[236] = 43.675799641021136;
out[237] = -17.974903844364817;
out[238] = 69.368640085185348;
out[239] = -94.615102344455565;
out[240] = 184.75059629806532;
out[241] = 17.974903844364775;
out[242] = -69.368640085185334;
out[243] = 40.74868784166955;
out[244] = -43.675799641021136;
out[245] = 17.974903844364817;
out[246] = -69.368640085185348;
out[247] = -1.0;
out[248] = 69.368640085185319;
out[249] = 17.974903844364796;
out[250] = -184.75059629806523;
out[251] = -94.615102344455607;
out[252] = 69.368640085185291;
out[253] = 17.974903844364814;
out[254] = 43.675799641021079;
out[255] = 40.748687841669586;
out[256] = -69.368640085185319;
out[257] = -17.974903844364796;
out[258] = 184.75059629806523;
out[259] = 94.615102344455607;
out[260] = -69.368640085185291;
out[261] = -17.974903844364814;
out[262] = -43.675799641021079;
out[263] = -40.748687841669586;
out[264] = -1.0;
out[265] = -17.974903844364796;
out[266] = 69.368640085185319;
out[267] = 94.615102344455607;
out[268] = -184.75059629806523;
out[269] = -17.974903844364814;
out[270] = 69.368640085185291;
out[271] = -40.748687841669586;
out[272] = 43.675799641021079;
out[273] = 17.974903844364796;
out[274] = -69.368640085185319;
out[275] = -94.615102344455607;
out[276] = 184.75059629806523;
out[277] = 17.974903844364814;
out[278] = -69.368640085185291;
out[279] = 40.748687841669586;
out[280] = -43.675799641021079;
out[281] = -1.0;
out[282] = 43.675799641021122;
out[283] = 40.748687841669557;
out[284] = 69.368640085185277;
out[285] = 17.97490384436481;
out[286] = -184.75059629806526;
out[287] = -94.615102344455636;
out[288] = 69.368640085185277;
out[289] = 17.974903844364817;
out[290] = -43.675799641021122;
out[291] = -40.748687841669557;
out[292] = -69.368640085185277;
out[293] = -17.97490384436481;
out[294] = 184.75059629806526;
out[295] = 94.615102344455636;
out[296] = -69.368640085185277;
out[297] = -17.974903844364817;
out[298] = -1.0;
out[299] = -40.748687841669557;
out[300] = 43.675799641021122;
out[301] = -17.97490384436481;
out[302] = 69.368640085185277;
out[303] = 94.615102344455636;
out[304] = -184.75059629806526;
out[305] = -17.974903844364817;
out[306] = 69.368640085185277;
out[307] = 40.748687841669557;
out[308] = -43.675799641021122;
out[309] = 17.97490384436481;
out[310] = -69.368640085185277;
out[311] = -94.615102344455636;
out[312] = 184.75059629806526;
out[313] = 17.974903844364817;
out[314] = -69.368640085185277;
out[315] = -1.0;
out[316] = 69.368640085185334;
out[317] = 17.9749038443648;
out[318] = 43.675799641021086;
out[319] = 40.748687841669586;
out[320] = 69.368640085185291;
out[321] = 17.974903844364821;
out[322] = -184.75059629806523;
out[323] = -94.61510234445565;
out[324] = -69.368640085185334;
out[325] = -17.9749038443648;
out[326] = -43.675799641021086;
out[327] = -40.748687841669586;
out[328] = -69.368640085185291;
out[329] = -17.974903844364821;
out[330] = 184.75059629806523;
out[331] = 94.61510234445565;
out[332] = -1.0;
out[333] = -17.9749038443648;
out[334] = 69.368640085185334;
out[335] = -40.748687841669586;
out[336] = 43.675799641021086;
out[337] = -17.974903844364821;
out[338] = 69.368640085185291;
out[339] = 94.61510234445565;
out[340] = -184.75059629806523;
out[341] = 17.9749038443648;
out[342] = -69.368640085185334;
out[343] = 40.748687841669586;
out[344] = -43.675799641021086;
out[345] = 17.974903844364821;
out[346] = -69.368640085185291;
out[347] = -94.61510234445565;
out[348] = 184.75059629806523;
out[349] = -1.0;
out[350] = -1.0;
out[352] = 1.0;
out[354] = 1.0;
out[355] = -1.0;
out[357] = 1.0;
out[359] = 1.0;
out[360] = -1.0;
out[362] = 1.0;
out[364] = 1.0;
out[365] = -1.0;
out[367] = 1.0;
out[369] = 1.0;
out[370] = 1.0;
out[371] = 1.0;
out[372] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = 1.0;
out[380] = -1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = 1.0;
out[390] = -1.0;
out[393] = 1.0;
out[395] = 1.0;
out[396] = 1.0;
out[397] = 1.0;
out[398] = 1.0;
out[408] = -1.0;
out[416] = 1.0;
out[418] = -1.0;
out[423] = -1.0;
out[428] = -1.0;
out[433] = -1.0;
out[438] = -1.0;
out[443] = -1.0;
out[448] = -1.0;
out[449] = -1.0;
out[452] = -1.0;
out[455] = -1.0;
out[458] = -1.0;
out[461] = -1.0;
out[464] = -1.0;
out[467] = -1.0;
out[470] = -1.0;
out[474] = -1.0;
out[477] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[110] = -0.5*Dt*(((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999) + 1.0;
out[118] = 0.5*Dt*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[119] = 0.5*Dt*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[120] = 0.5*Dt*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[121] = 0.5*Dt*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[122] = 0.5*Dt*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[123] = 0.5*Dt*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[134] = 0.5*Dt*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[135] = 0.5*Dt*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[136] = 0.5*Dt*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[139] = 0.5*Dt*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[140] = 0.5*Dt*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[141] = 0.5*Dt*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[172] = -0.5*Dt*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[173] = -0.5*Dt*(0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[174] = -0.5*Dt*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[175] = -0.5*Dt*(-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[176] = -0.5*Dt*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[177] = -0.5*Dt*(-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[188] = -0.5*Dt*(0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[189] = -0.5*Dt*(0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[190] = -0.5*Dt*(-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[193] = -0.5*Dt*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[194] = -0.5*Dt*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[195] = -0.5*Dt*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[272] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[280] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[281] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[282] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[283] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[284] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[285] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[296] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[297] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[298] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[301] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[302] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[303] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[326] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[334] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[335] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[336] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[337] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[338] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[339] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[350] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[351] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[352] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[355] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[356] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[357] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[380] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[388] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[389] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[390] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[391] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[392] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[393] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[404] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[405] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[406] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[409] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[410] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[411] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[1970] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[1971] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[1972] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[1973] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1975] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[1976] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[1977] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[1978] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1982] = y[16];
out[1983] = y[17];
out[1984] = y[18];
out[1985] = 1.0*y[21];
out[1986] = 1.0*y[22];
out[1987] = 1.0*y[23];
out[2052] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[2057] = cos(x[0] + u[10]);
out[2106] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[2112] = cos(x[0] + u[11] - 2.0943951023931953);
out[2160] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[2167] = cos(x[0] + u[12] - 4.1887902047863905);
out[2214] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[2219] = 1.0*sin(x[0] + u[10]);
out[2268] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[2274] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[2322] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[2329] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[20] + 1.0;
out[1] = -157.07963267948966*Dt;
out[52] = 157.07963267948966*Dt;
out[55] = 0.25*p[18]*Dt/p[17] + 1.0;
out[57] = 0.25*Dt/p[17];
out[91] = -0.25*Dt/p[17];
out[165] = 0.5*Dt/p[13] + 1.0;
out[220] = 0.5*Dt/p[14] + 1.0;
out[275] = 0.5*Dt/p[15] + 1.0;
out[330] = 0.5*Dt/p[15] + 1.0;
out[385] = 0.5*Dt/p[15] + 1.0;
out[440] = 0.5*Dt/p[15] + 1.0;
out[495] = 0.5*Dt*p[32] + 1.0;
out[538] = 0.5*Dt;
out[1430] = -p[1];
out[1435] = 1.0*p[0];
out[1485] = -p[1];
out[1490] = 1.0*p[0];
out[1540] = -p[1];
out[1545] = 1.0*p[0];
out[1595] = -p[3];
out[1600] = 1.0*p[2];
out[1650] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1655] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1700] = -1.0*p[0];
out[1705] = -1.0*p[1];
out[1755] = -1.0*p[0];
out[1760] = -1.0*p[1];
out[1810] = -1.0*p[0];
out[1815] = -1.0*p[1];
out[1865] = -1.0*p[2];
out[1870] = -1.0*p[3];
out[1920] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1925] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1999] = -1/p[16];
out[2007] = p[19];
out[2078] = -p[10];
out[2083] = 1.0*p[9];
out[2133] = -p[10];
out[2138] = 1.0*p[9];
out[2188] = -p[10];
out[2193] = 1.0*p[9];
out[2240] = -1.0*p[9];
out[2245] = -1.0*p[10];
out[2295] = -1.0*p[9];
out[2300] = -1.0*p[10];
out[2350] = -1.0*p[9];
out[2355] = -1.0*p[10];
out[2420] = -p[25];
out[2424] = 1.0*p[24];
out[2475] = -p[25];
out[2479] = 1.0*p[24];
out[2530] = -p[25];
out[2534] = 1.0*p[24];
out[2585] = -p[27];
out[2589] = 1.0*p[26];
out[2636] = -1.0*p[24];
out[2640] = -1.0*p[25];
out[2691] = -1.0*p[24];
out[2695] = -1.0*p[25];
out[2746] = -1.0*p[24];
out[2750] = -1.0*p[25];
out[2801] = -1.0*p[26];
out[2805] = -1.0*p[27];
out[2809] = p[11]/(p[11] + 1000.0);
out[2871] = p[31];
out[2914] = -p[30];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[550] = 184.75059629806532;
out[551] = 94.615102344455565;
out[552] = -69.368640085185334;
out[553] = -17.974903844364775;
out[554] = -43.675799641021136;
out[555] = -40.74868784166955;
out[556] = -69.368640085185348;
out[557] = -17.974903844364817;
out[558] = -184.75059629806532;
out[559] = -94.615102344455565;
out[560] = 69.368640085185334;
out[561] = 17.974903844364775;
out[562] = 43.675799641021136;
out[563] = 40.74868784166955;
out[564] = 69.368640085185348;
out[565] = 17.974903844364817;
out[566] = -1.0;
out[604] = -94.615102344455565;
out[605] = 184.75059629806532;
out[606] = 17.974903844364775;
out[607] = -69.368640085185334;
out[608] = 40.74868784166955;
out[609] = -43.675799641021136;
out[610] = 17.974903844364817;
out[611] = -69.368640085185348;
out[612] = 94.615102344455565;
out[613] = -184.75059629806532;
out[614] = -17.974903844364775;
out[615] = 69.368640085185334;
out[616] = -40.74868784166955;
out[617] = 43.675799641021136;
out[618] = -17.974903844364817;
out[619] = 69.368640085185348;
out[625] = -1.0;
out[658] = -69.368640085185319;
out[659] = -17.974903844364796;
out[660] = 184.75059629806523;
out[661] = 94.615102344455607;
out[662] = -69.368640085185291;
out[663] = -17.974903844364814;
out[664] = -43.675799641021079;
out[665] = -40.748687841669586;
out[666] = 69.368640085185319;
out[667] = 17.974903844364796;
out[668] = -184.75059629806523;
out[669] = -94.615102344455607;
out[670] = 69.368640085185291;
out[671] = 17.974903844364814;
out[672] = 43.675799641021079;
out[673] = 40.748687841669586;
out[675] = -1.0;
out[712] = 17.974903844364796;
out[713] = -69.368640085185319;
out[714] = -94.615102344455607;
out[715] = 184.75059629806523;
out[716] = 17.974903844364814;
out[717] = -69.368640085185291;
out[718] = 40.748687841669586;
out[719] = -43.675799641021079;
out[720] = -17.974903844364796;
out[721] = 69.368640085185319;
out[722] = 94.615102344455607;
out[723] = -184.75059629806523;
out[724] = -17.974903844364814;
out[725] = 69.368640085185291;
out[726] = -40.748687841669586;
out[727] = 43.675799641021079;
out[734] = -1.0;
out[766] = -43.675799641021122;
out[767] = -40.748687841669557;
out[768] = -69.368640085185277;
out[769] = -17.97490384436481;
out[770] = 184.75059629806526;
out[771] = 94.615102344455636;
out[772] = -69.368640085185277;
out[773] = -17.974903844364817;
out[774] = 43.675799641021122;
out[775] = 40.748687841669557;
out[776] = 69.368640085185277;
out[777] = 17.97490384436481;
out[778] = -184.75059629806526;
out[779] = -94.615102344455636;
out[780] = 69.368640085185277;
out[781] = 17.974903844364817;
out[784] = -1.0;
out[820] = 40.748687841669557;
out[821] = -43.675799641021122;
out[822] = 17.97490384436481;
out[823] = -69.368640085185277;
out[824] = -94.615102344455636;
out[825] = 184.75059629806526;
out[826] = 17.974903844364817;
out[827] = -69.368640085185277;
out[828] = -40.748687841669557;
out[829] = 43.675799641021122;
out[830] = -17.97490384436481;
out[831] = 69.368640085185277;
out[832] = 94.615102344455636;
out[833] = -184.75059629806526;
out[834] = -17.974903844364817;
out[835] = 69.368640085185277;
out[843] = -1.0;
out[874] = -69.368640085185334;
out[875] = -17.9749038443648;
out[876] = -43.675799641021086;
out[877] = -40.748687841669586;
out[878] = -69.368640085185291;
out[879] = -17.974903844364821;
out[880] = 184.75059629806523;
out[881] = 94.61510234445565;
out[882] = 69.368640085185334;
out[883] = 17.9749038443648;
out[884] = 43.675799641021086;
out[885] = 40.748687841669586;
out[886] = 69.368640085185291;
out[887] = 17.974903844364821;
out[888] = -184.75059629806523;
out[889] = -94.61510234445565;
out[893] = -1.0;
out[928] = 17.9749038443648;
out[929] = -69.368640085185334;
out[930] = 40.748687841669586;
out[931] = -43.675799641021086;
out[932] = 17.974903844364821;
out[933] = -69.368640085185291;
out[934] = -94.61510234445565;
out[935] = 184.75059629806523;
out[936] = -17.9749038443648;
out[937] = 69.368640085185334;
out[938] = -40.748687841669586;
out[939] = 43.675799641021086;
out[940] = -17.974903844364821;
out[941] = 69.368640085185291;
out[942] = 94.61510234445565;
out[943] = -184.75059629806523;
out[952] = -1.0;
out[982] = -184.75059629806532;
out[983] = -94.615102344455565;
out[984] = 69.368640085185334;
out[985] = 17.974903844364775;
out[986] = 43.675799641021136;
out[987] = 40.74868784166955;
out[988] = 69.368640085185348;
out[989] = 17.974903844364817;
out[990] = 184.75059629806532;
out[991] = 94.615102344455565;
out[992] = -69.368640085185334;
out[993] = -17.974903844364775;
out[994] = -43.675799641021136;
out[995] = -40.74868784166955;
out[996] = -69.368640085185348;
out[997] = -17.974903844364817;
out[1016] = -1.0;
out[1036] = 94.615102344455565;
out[1037] = -184.75059629806532;
out[1038] = -17.974903844364775;
out[1039] = 69.368640085185334;
out[1040] = -40.74868784166955;
out[1041] = 43.675799641021136;
out[1042] = -17.974903844364817;
out[1043] = 69.368640085185348;
out[1044] = -94.615102344455565;
out[1045] = 184.75059629806532;
out[1046] = 17.974903844364775;
out[1047] = -69.368640085185334;
out[1048] = 40.74868784166955;
out[1049] = -43.675799641021136;
out[1050] = 17.974903844364817;
out[1051] = -69.368640085185348;
out[1074] = -1.0;
out[1090] = 69.368640085185319;
out[1091] = 17.974903844364796;
out[1092] = -184.75059629806523;
out[1093] = -94.615102344455607;
out[1094] = 69.368640085185291;
out[1095] = 17.974903844364814;
out[1096] = 43.675799641021079;
out[1097] = 40.748687841669586;
out[1098] = -69.368640085185319;
out[1099] = -17.974903844364796;
out[1100] = 184.75059629806523;
out[1101] = 94.615102344455607;
out[1102] = -69.368640085185291;
out[1103] = -17.974903844364814;
out[1104] = -43.675799641021079;
out[1105] = -40.748687841669586;
out[1125] = -1.0;
out[1144] = -17.974903844364796;
out[1145] = 69.368640085185319;
out[1146] = 94.615102344455607;
out[1147] = -184.75059629806523;
out[1148] = -17.974903844364814;
out[1149] = 69.368640085185291;
out[1150] = -40.748687841669586;
out[1151] = 43.675799641021079;
out[1152] = 17.974903844364796;
out[1153] = -69.368640085185319;
out[1154] = -94.615102344455607;
out[1155] = 184.75059629806523;
out[1156] = 17.974903844364814;
out[1157] = -69.368640085185291;
out[1158] = 40.748687841669586;
out[1159] = -43.675799641021079;
out[1183] = -1.0;
out[1198] = 43.675799641021122;
out[1199] = 40.748687841669557;
out[1200] = 69.368640085185277;
out[1201] = 17.97490384436481;
out[1202] = -184.75059629806526;
out[1203] = -94.615102344455636;
out[1204] = 69.368640085185277;
out[1205] = 17.974903844364817;
out[1206] = -43.675799641021122;
out[1207] = -40.748687841669557;
out[1208] = -69.368640085185277;
out[1209] = -17.97490384436481;
out[1210] = 184.75059629806526;
out[1211] = 94.615102344455636;
out[1212] = -69.368640085185277;
out[1213] = -17.974903844364817;
out[1234] = -1.0;
out[1252] = -40.748687841669557;
out[1253] = 43.675799641021122;
out[1254] = -17.97490384436481;
out[1255] = 69.368640085185277;
out[1256] = 94.615102344455636;
out[1257] = -184.75059629806526;
out[1258] = -17.974903844364817;
out[1259] = 69.368640085185277;
out[1260] = 40.748687841669557;
out[1261] = -43.675799641021122;
out[1262] = 17.97490384436481;
out[1263] = -69.368640085185277;
out[1264] = -94.615102344455636;
out[1265] = 184.75059629806526;
out[1266] = 17.974903844364817;
out[1267] = -69.368640085185277;
out[1292] = -1.0;
out[1306] = 69.368640085185334;
out[1307] = 17.9749038443648;
out[1308] = 43.675799641021086;
out[1309] = 40.748687841669586;
out[1310] = 69.368640085185291;
out[1311] = 17.974903844364821;
out[1312] = -184.75059629806523;
out[1313] = -94.61510234445565;
out[1314] = -69.368640085185334;
out[1315] = -17.9749038443648;
out[1316] = -43.675799641021086;
out[1317] = -40.748687841669586;
out[1318] = -69.368640085185291;
out[1319] = -17.974903844364821;
out[1320] = 184.75059629806523;
out[1321] = 94.61510234445565;
out[1343] = -1.0;
out[1360] = -17.9749038443648;
out[1361] = 69.368640085185334;
out[1362] = -40.748687841669586;
out[1363] = 43.675799641021086;
out[1364] = -17.974903844364821;
out[1365] = 69.368640085185291;
out[1366] = 94.61510234445565;
out[1367] = -184.75059629806523;
out[1368] = 17.9749038443648;
out[1369] = -69.368640085185334;
out[1370] = 40.748687841669586;
out[1371] = -43.675799641021086;
out[1372] = 17.974903844364821;
out[1373] = -69.368640085185291;
out[1374] = -94.61510234445565;
out[1375] = 184.75059629806523;
out[1401] = -1.0;
out[1414] = -1.0;
out[1434] = 1.0;
out[1442] = 1.0;
out[1470] = -1.0;
out[1488] = 1.0;
out[1497] = 1.0;
out[1526] = -1.0;
out[1542] = 1.0;
out[1552] = 1.0;
out[1582] = -1.0;
out[1596] = 1.0;
out[1646] = 1.0;
out[1647] = 1.0;
out[1648] = 1.0;
out[1649] = 1.0;
out[1685] = -1.0;
out[1709] = 1.0;
out[1715] = 1.0;
out[1741] = -1.0;
out[1763] = 1.0;
out[1770] = 1.0;
out[1797] = -1.0;
out[1817] = 1.0;
out[1825] = 1.0;
out[1853] = -1.0;
out[1871] = 1.0;
out[1921] = 1.0;
out[1922] = 1.0;
out[1923] = 1.0;
out[1924] = 1.0;
out[1980] = -1.0;
out[2002] = 1.0;
out[2035] = -1.0;
out[2090] = -1.0;
out[2145] = -1.0;
out[2200] = -1.0;
out[2255] = -1.0;
out[2310] = -1.0;
out[2365] = -1.0;
out[2394] = -1.0;
out[2450] = -1.0;
out[2506] = -1.0;
out[2562] = -1.0;
out[2611] = -1.0;
out[2667] = -1.0;
out[2723] = -1.0;
out[2779] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[6] = -0.5*Dt*(((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
)) - 1.0000009999999999) + 1.0;
out[7] = 0.5*Dt*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[8] = 0.5*Dt*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[9] = 0.5*Dt*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[10] = 0.5*Dt*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[11] = 0.5*Dt*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[12] = 0.5*Dt*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[13] = 0.5*Dt*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[14] = 0.5*Dt*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[15] = 0.5*Dt*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[16] = 0.5*Dt*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[17] = 0.5*Dt*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[18] = 0.5*Dt*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
))/p[11];
out[20] = -0.5*Dt*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/(p[11]*p[13]);
out[21] = -0.5*Dt*(0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18])/(p[11]*p[13]);
out[22] = -0.5*Dt*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/(p[11]*p[13]);
out[23] = -0.5*Dt*(-0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18])/(p[11]*p[13]);
out[24] = -0.5*Dt*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/(p[11]*p[13]);
out[25] = -0.5*Dt*(-0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23])/(p[11]*p[13]);
out[26] = -0.5*Dt*(0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4])/(p[11]*p[13]);
out[27] = -0.5*Dt*(0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4])/(p[11]*p[13]);
out[28] = -0.5*Dt*(-0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4])/(p[11]*p[13]);
out[29] = -0.5*Dt*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/(p[11]*p[13]);
out[30] = -0.5*Dt*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/(p[11]*p[13]);
out[31] = -0.5*Dt*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/(p[11]*p[13]);
out[33] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[35] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[36] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[37] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[38] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[39] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[40] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[41] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[42] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[43] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[44] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[45] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[46] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[47] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[49] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[50] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[51] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[52] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[53] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[54] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[55] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[56] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[57] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[58] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[59] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[60] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[61] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[22]
))/p[15];
out[63] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18])/p[11]
))/p[15];
out[64] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18])/p[11]
))/p[15];
out[65] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18])/p[11]
))/p[15];
out[66] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18])/p[11]
))/p[15];
out[67] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23])/p[11]
))/p[15];
out[68] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18])/p[11]
))/p[15];
out[69] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4])/p[11]
))/p[15];
out[70] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4])/p[11]
))/p[15];
out[71] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5])/p[11]
))/p[15];
out[72] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4])/p[11]
))/p[15];
out[73] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(-0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4])/p[11]
))/p[15];
out[74] = -0.5*Dt*((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   -p[21]*(0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4])/p[11]
))/p[15];
out[400] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[28];
out[401] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[29];
out[402] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[30] + u[0];
out[403] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[404] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[31];
out[405] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[32];
out[406] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[33] + 1.0*u[1];
out[407] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[409] = y[16];
out[410] = y[17];
out[411] = y[18];
out[412] = 1.0*y[21];
out[413] = 1.0*y[22];
out[414] = 1.0*y[23];
out[419] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[420] = cos(x[0] + u[10]);
out[424] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[425] = cos(x[0] + u[11] - 2.0943951023931953);
out[429] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[430] = cos(x[0] + u[12] - 4.1887902047863905);
out[434] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[435] = 1.0*sin(x[0] + u[10]);
out[439] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[440] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[444] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);
out[445] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[20] + 1.0;
out[1] = -157.07963267948966*Dt;
out[2] = 157.07963267948966*Dt;
out[3] = 0.25*p[18]*Dt/p[17] + 1.0;
out[4] = 0.25*Dt/p[17];
out[5] = -0.25*Dt/p[17];
out[19] = 0.5*Dt/p[13] + 1.0;
out[32] = 0.5*Dt/p[14] + 1.0;
out[34] = 0.5*Dt/p[15] + 1.0;
out[48] = 0.5*Dt/p[15] + 1.0;
out[62] = 0.5*Dt/p[15] + 1.0;
out[75] = 0.5*Dt/p[15] + 1.0;
out[76] = 0.5*Dt*p[32] + 1.0;
out[77] = 0.5*Dt;
out[351] = -p[1];
out[353] = 1.0*p[0];
out[356] = -p[1];
out[358] = 1.0*p[0];
out[361] = -p[1];
out[363] = 1.0*p[0];
out[366] = -p[3];
out[368] = 1.0*p[2];
out[373] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[374] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[376] = -1.0*p[0];
out[377] = -1.0*p[1];
out[381] = -1.0*p[0];
out[382] = -1.0*p[1];
out[386] = -1.0*p[0];
out[387] = -1.0*p[1];
out[391] = -1.0*p[2];
out[392] = -1.0*p[3];
out[394] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[399] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[415] = -1/p[16];
out[417] = p[19];
out[421] = -p[10];
out[422] = 1.0*p[9];
out[426] = -p[10];
out[427] = 1.0*p[9];
out[431] = -p[10];
out[432] = 1.0*p[9];
out[436] = -1.0*p[9];
out[437] = -1.0*p[10];
out[441] = -1.0*p[9];
out[442] = -1.0*p[10];
out[446] = -1.0*p[9];
out[447] = -1.0*p[10];
out[450] = -p[25];
out[451] = 1.0*p[24];
out[453] = -p[25];
out[454] = 1.0*p[24];
out[456] = -p[25];
out[457] = 1.0*p[24];
out[459] = -p[27];
out[460] = 1.0*p[26];
out[462] = -1.0*p[24];
out[463] = -1.0*p[25];
out[465] = -1.0*p[24];
out[466] = -1.0*p[25];
out[468] = -1.0*p[24];
out[469] = -1.0*p[25];
out[471] = -1.0*p[26];
out[472] = -1.0*p[27];
out[473] = p[11]/(p[11] + 1000.0);
out[475] = p[31];
out[476] = -p[30];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[78] = 184.75059629806532;
out[79] = 94.615102344455565;
out[80] = -69.368640085185334;
out[81] = -17.974903844364775;
out[82] = -43.675799641021136;
out[83] = -40.74868784166955;
out[84] = -69.368640085185348;
out[85] = -17.974903844364817;
out[86] = -184.75059629806532;
out[87] = -94.615102344455565;
out[88] = 69.368640085185334;
out[89] = 17.974903844364775;
out[90] = 43.675799641021136;
out[91] = 40.74868784166955;
out[92] = 69.368640085185348;
out[93] = 17.974903844364817;
out[94] = -1.0;
out[95] = -94.615102344455565;
out[96] = 184.75059629806532;
out[97] = 17.974903844364775;
out[98] = -69.368640085185334;
out[99] = 40.74868784166955;
out[100] = -43.675799641021136;
out[101] = 17.974903844364817;
out[102] = -69.368640085185348;
out[103] = 94.615102344455565;
out[104] = -184.75059629806532;
out[105] = -17.974903844364775;
out[106] = 69.368640085185334;
out[107] = -40.74868784166955;
out[108] = 43.675799641021136;
out[109] = -17.974903844364817;
out[110] = 69.368640085185348;
out[111] = -1.0;
out[112] = -69.368640085185319;
out[113] = -17.974903844364796;
out[114] = 184.75059629806523;
out[115] = 94.615102344455607;
out[116] = -69.368640085185291;
out[117] = -17.974903844364814;
out[118] = -43.675799641021079;
out[119] = -40.748687841669586;
out[120] = 69.368640085185319;
out[121] = 17.974903844364796;
out[122] = -184.75059629806523;
out[123] = -94.615102344455607;
out[124] = 69.368640085185291;
out[125] = 17.974903844364814;
out[126] = 43.675799641021079;
out[127] = 40.748687841669586;
out[128] = -1.0;
out[129] = 17.974903844364796;
out[130] = -69.368640085185319;
out[131] = -94.615102344455607;
out[132] = 184.75059629806523;
out[133] = 17.974903844364814;
out[134] = -69.368640085185291;
out[135] = 40.748687841669586;
out[136] = -43.675799641021079;
out[137] = -17.974903844364796;
out[138] = 69.368640085185319;
out[139] = 94.615102344455607;
out[140] = -184.75059629806523;
out[141] = -17.974903844364814;
out[142] = 69.368640085185291;
out[143] = -40.748687841669586;
out[144] = 43.675799641021079;
out[145] = -1.0;
out[146] = -43.675799641021122;
out[147] = -40.748687841669557;
out[148] = -69.368640085185277;
out[149] = -17.97490384436481;
out[150] = 184.75059629806526;
out[151] = 94.615102344455636;
out[152] = -69.368640085185277;
out[153] = -17.974903844364817;
out[154] = 43.675799641021122;
out[155] = 40.748687841669557;
out[156] = 69.368640085185277;
out[157] = 17.97490384436481;
out[158] = -184.75059629806526;
out[159] = -94.615102344455636;
out[160] = 69.368640085185277;
out[161] = 17.974903844364817;
out[162] = -1.0;
out[163] = 40.748687841669557;
out[164] = -43.675799641021122;
out[165] = 17.97490384436481;
out[166] = -69.368640085185277;
out[167] = -94.615102344455636;
out[168] = 184.75059629806526;
out[169] = 17.974903844364817;
out[170] = -69.368640085185277;
out[171] = -40.748687841669557;
out[172] = 43.675799641021122;
out[173] = -17.97490384436481;
out[174] = 69.368640085185277;
out[175] = 94.615102344455636;
out[176] = -184.75059629806526;
out[177] = -17.974903844364817;
out[178] = 69.368640085185277;
out[179] = -1.0;
out[180] = -69.368640085185334;
out[181] = -17.9749038443648;
out[182] = -43.675799641021086;
out[183] = -40.748687841669586;
out[184] = -69.368640085185291;
out[185] = -17.974903844364821;
out[186] = 184.75059629806523;
out[187] = 94.61510234445565;
out[188] = 69.368640085185334;
out[189] = 17.9749038443648;
out[190] = 43.675799641021086;
out[191] = 40.748687841669586;
out[192] = 69.368640085185291;
out[193] = 17.974903844364821;
out[194] = -184.75059629806523;
out[195] = -94.61510234445565;
out[196] = -1.0;
out[197] = 17.9749038443648;
out[198] = -69.368640085185334;
out[199] = 40.748687841669586;
out[200] = -43.675799641021086;
out[201] = 17.974903844364821;
out[202] = -69.368640085185291;
out[203] = -94.61510234445565;
out[204] = 184.75059629806523;
out[205] = -17.9749038443648;
out[206] = 69.368640085185334;
out[207] = -40.748687841669586;
out[208] = 43.675799641021086;
out[209] = -17.974903844364821;
out[210] = 69.368640085185291;
out[211] = 94.61510234445565;
out[212] = -184.75059629806523;
out[213] = -1.0;
out[214] = -184.75059629806532;
out[215] = -94.615102344455565;
out[216] = 69.368640085185334;
out[217] = 17.974903844364775;
out[218] = 43.675799641021136;
out[219] = 40.74868784166955;
out[220] = 69.368640085185348;
out[221] = 17.974903844364817;
out[222] = 184.75059629806532;
out[223] = 94.615102344455565;
out[224] = -69.368640085185334;
out[225] = -17.974903844364775;
out[226] = -43.675799641021136;
out[227] = -40.74868784166955;
out[228] = -69.368640085185348;
out[229] = -17.974903844364817;
out[230] = -1.0;
out[231] = 94.615102344455565;
out[232] = -184.75059629806532;
out[233] = -17.974903844364775;
out[234] = 69.368640085185334;
out[235] = -40.74868784166955;
out[236] = 43.675799641021136;
out[237] = -17.974903844364817;
out[238] = 69.368640085185348;
out[239] = -94.615102344455565;
out[240] = 184.75059629806532;
out[241] = 17.974903844364775;
out[242] = -69.368640085185334;
out[243] = 40.74868784166955;
out[244] = -43.675799641021136;
out[245] = 17.974903844364817;
out[246] = -69.368640085185348;
out[247] = -1.0;
out[248] = 69.368640085185319;
out[249] = 17.974903844364796;
out[250] = -184.75059629806523;
out[251] = -94.615102344455607;
out[252] = 69.368640085185291;
out[253] = 17.974903844364814;
out[254] = 43.675799641021079;
out[255] = 40.748687841669586;
out[256] = -69.368640085185319;
out[257] = -17.974903844364796;
out[258] = 184.75059629806523;
out[259] = 94.615102344455607;
out[260] = -69.368640085185291;
out[261] = -17.974903844364814;
out[262] = -43.675799641021079;
out[263] = -40.748687841669586;
out[264] = -1.0;
out[265] = -17.974903844364796;
out[266] = 69.368640085185319;
out[267] = 94.615102344455607;
out[268] = -184.75059629806523;
out[269] = -17.974903844364814;
out[270] = 69.368640085185291;
out[271] = -40.748687841669586;
out[272] = 43.675799641021079;
out[273] = 17.974903844364796;
out[274] = -69.368640085185319;
out[275] = -94.615102344455607;
out[276] = 184.75059629806523;
out[277] = 17.974903844364814;
out[278] = -69.368640085185291;
out[279] = 40.748687841669586;
out[280] = -43.675799641021079;
out[281] = -1.0;
out[282] = 43.675799641021122;
out[283] = 40.748687841669557;
out[284] = 69.368640085185277;
out[285] = 17.97490384436481;
out[286] = -184.75059629806526;
out[287] = -94.615102344455636;
out[288] = 69.368640085185277;
out[289] = 17.974903844364817;
out[290] = -43.675799641021122;
out[291] = -40.748687841669557;
out[292] = -69.368640085185277;
out[293] = -17.97490384436481;
out[294] = 184.75059629806526;
out[295] = 94.615102344455636;
out[296] = -69.368640085185277;
out[297] = -17.974903844364817;
out[298] = -1.0;
out[299] = -40.748687841669557;
out[300] = 43.675799641021122;
out[301] = -17.97490384436481;
out[302] = 69.368640085185277;
out[303] = 94.615102344455636;
out[304] = -184.75059629806526;
out[305] = -17.974903844364817;
out[306] = 69.368640085185277;
out[307] = 40.748687841669557;
out[308] = -43.675799641021122;
out[309] = 17.97490384436481;
out[310] = -69.368640085185277;
out[311] = -94.615102344455636;
out[312] = 184.75059629806526;
out[313] = 17.974903844364817;
out[314] = -69.368640085185277;
out[315] = -1.0;
out[316] = 69.368640085185334;
out[317] = 17.9749038443648;
out[318] = 43.675799641021086;
out[319] = 40.748687841669586;
out[320] = 69.368640085185291;
out[321] = 17.974903844364821;
out[322] = -184.75059629806523;
out[323] = -94.61510234445565;
out[324] = -69.368640085185334;
out[325] = -17.9749038443648;
out[326] = -43.675799641021086;
out[327] = -40.748687841669586;
out[328] = -69.368640085185291;
out[329] = -17.974903844364821;
out[330] = 184.75059629806523;
out[331] = 94.61510234445565;
out[332] = -1.0;
out[333] = -17.9749038443648;
out[334] = 69.368640085185334;
out[335] = -40.748687841669586;
out[336] = 43.675799641021086;
out[337] = -17.974903844364821;
out[338] = 69.368640085185291;
out[339] = 94.61510234445565;
out[340] = -184.75059629806523;
out[341] = 17.9749038443648;
out[342] = -69.368640085185334;
out[343] = 40.748687841669586;
out[344] = -43.675799641021086;
out[345] = 17.974903844364821;
out[346] = -69.368640085185291;
out[347] = -94.61510234445565;
out[348] = 184.75059629806523;
out[349] = -1.0;
out[350] = -1.0;
out[352] = 1.0;
out[354] = 1.0;
out[355] = -1.0;
out[357] = 1.0;
out[359] = 1.0;
out[360] = -1.0;
out[362] = 1.0;
out[364] = 1.0;
out[365] = -1.0;
out[367] = 1.0;
out[369] = 1.0;
out[370] = 1.0;
out[371] = 1.0;
out[372] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = 1.0;
out[380] = -1.0;
out[383] = 1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = 1.0;
out[390] = -1.0;
out[393] = 1.0;
out[395] = 1.0;
out[396] = 1.0;
out[397] = 1.0;
out[398] = 1.0;
out[408] = -1.0;
out[416] = 1.0;
out[418] = -1.0;
out[423] = -1.0;
out[428] = -1.0;
out[433] = -1.0;
out[438] = -1.0;
out[443] = -1.0;
out[448] = -1.0;
out[449] = -1.0;
out[452] = -1.0;
out[455] = -1.0;
out[458] = -1.0;
out[461] = -1.0;
out[464] = -1.0;
out[467] = -1.0;
out[470] = -1.0;
out[474] = -1.0;
out[477] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[66] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
));
out[141] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];
out[166] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];
out[191] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];

}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[114] = 1.0/p[14];
out[131] = 1.0/p[15];
out[157] = 1.0/p[15];
out[183] = 1.0/p[15];
out[209] = 1.0/p[15];

}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[249] = 1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[650] = y[18];
out[651] = 1.0*y[23];
out[702] = cos(x[0] + u[10]);
out[710] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[728] = cos(x[0] + u[11] - 2.0943951023931953);
out[736] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[754] = cos(x[0] + u[12] - 4.1887902047863905);
out[762] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[777] = 1.0*sin(x[0] + u[10]);
out[785] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[803] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[811] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[829] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);
out[837] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[690] = 1.0/p[16];
out[692] = p[23];
out[869] = cos(u[23]);
out[873] = -u[19]*sin(u[23]);
out[895] = cos(u[23] - 2.0943951023931953);
out[898] = -u[20]*sin(u[23] - 2.0943951023931953);
out[921] = cos(u[23] - 4.1887902047863905);
out[923] = -u[21]*sin(u[23] - 4.1887902047863905);
out[969] = 1.0*sin(u[23]);
out[973] = 1.0*u[19]*cos(u[23]);
out[995] = 1.0*sin(u[23] - 2.0943951023931953);
out[998] = 1.0*u[20]*cos(u[23] - 2.0943951023931953);
out[1021] = 1.0*sin(u[23] - 4.1887902047863905);
out[1023] = 1.0*u[21]*cos(u[23] - 4.1887902047863905);

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[475] = 1.0;
out[601] = 1.0;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[300] = 1.0;
out[379] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[368] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[373] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[413] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[418] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[458] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[463] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[503] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[508] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[528] = y[16];
out[529] = 1.0*y[21];
out[544] = y[0];
out[549] = 1.0*y[1];
out[572] = -1.0*y[21];
out[573] = 1.0*y[16];
out[588] = 1.0*y[1];
out[593] = -1.0*y[0];
out[618] = y[17];
out[619] = 1.0*y[22];
out[633] = y[2];
out[638] = 1.0*y[3];
out[662] = -1.0*y[22];
out[663] = 1.0*y[17];
out[677] = 1.0*y[3];
out[682] = -1.0*y[2];
out[708] = y[18];
out[709] = 1.0*y[23];
out[722] = y[4];
out[727] = 1.0*y[5];
out[752] = -1.0*y[23];
out[753] = 1.0*y[18];
out[766] = 1.0*y[5];
out[771] = -1.0*y[4];
out[792] = 0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18];
out[793] = 0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18];
out[794] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[795] = -0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18];
out[796] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[797] = -0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23];
out[808] = 0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4];
out[809] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[810] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[813] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[814] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[815] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[836] = 0.33333333333333331*y[16] + 0.28867513459481275*y[22] - 0.16666666666666677*y[17] - 0.28867513459481287*y[23] - 0.16666666666666657*y[18];
out[837] = 0.33333333333333331*y[21] - 0.16666666666666677*y[22] - 0.28867513459481275*y[17] - 0.16666666666666657*y[23] + 0.28867513459481287*y[18];
out[838] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.33333333333333326*y[17] + 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[839] = -0.16666666666666677*y[21] + 0.28867513459481275*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] - 0.28867513459481281*y[18];
out[840] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] - 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[841] = -0.16666666666666657*y[21] - 0.28867513459481287*y[16] - 0.16666666666666652*y[22] + 0.28867513459481281*y[17] + 0.33333333333333326*y[23];
out[852] = 0.33333333333333331*y[0] + 0.28867513459481275*y[3] - 0.16666666666666677*y[2] - 0.28867513459481287*y[5] - 0.16666666666666657*y[4];
out[853] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.33333333333333326*y[2] + 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[854] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] - 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[857] = 0.33333333333333331*y[1] - 0.16666666666666677*y[3] - 0.28867513459481275*y[2] - 0.16666666666666657*y[5] + 0.28867513459481287*y[4];
out[858] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] - 0.28867513459481281*y[4];
out[859] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] - 0.16666666666666652*y[3] + 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[880] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[881] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[882] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[883] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[884] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[885] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[896] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[897] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[898] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[901] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[902] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[903] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[924] = -0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18];
out[925] = 0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18];
out[926] = 0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18];
out[927] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[928] = 0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23];
out[929] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[940] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[941] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[942] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[945] = -0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4];
out[946] = -0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4];
out[947] = 0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4];
out[1398] = y[34]*pow(1.0*pow(y[38], 2) + pow(y[34], 2), -0.5);
out[1402] = 1.0*y[38]*pow(1.0*pow(y[38], 2) + pow(y[34], 2), -0.5);
out[1443] = y[35]*pow(1.0*pow(y[39], 2) + pow(y[35], 2), -0.5);
out[1447] = 1.0*y[39]*pow(1.0*pow(y[39], 2) + pow(y[35], 2), -0.5);
out[1488] = y[36]*pow(1.0*pow(y[40], 2) + pow(y[36], 2), -0.5);
out[1492] = 1.0*y[40]*pow(1.0*pow(y[40], 2) + pow(y[36], 2), -0.5);
out[1533] = y[37]*pow(1.0*pow(y[41], 2) + pow(y[37], 2), -0.5);
out[1537] = 1.0*y[41]*pow(1.0*pow(y[41], 2) + pow(y[37], 2), -0.5);
out[1548] = y[34];
out[1549] = 1.0*y[38];
out[1550] = y[35];
out[1551] = 1.0*y[39];
out[1552] = y[36];
out[1553] = 1.0*y[40];
out[1574] = y[8];
out[1575] = y[10];
out[1576] = y[12];
out[1578] = 1.0*y[9];
out[1579] = 1.0*y[11];
out[1580] = 1.0*y[13];
out[1592] = -1.0*y[38];
out[1593] = 1.0*y[34];
out[1594] = -1.0*y[39];
out[1595] = 1.0*y[35];
out[1596] = -1.0*y[40];
out[1597] = 1.0*y[36];
out[1618] = 1.0*y[9];
out[1619] = 1.0*y[11];
out[1620] = 1.0*y[13];
out[1622] = -1.0*y[8];
out[1623] = -1.0*y[10];
out[1624] = -1.0*y[12];

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806532;
out[1] = 94.615102344455565;
out[2] = -69.368640085185334;
out[3] = -17.974903844364775;
out[4] = -43.675799641021136;
out[5] = -40.74868784166955;
out[6] = -69.368640085185348;
out[7] = -17.974903844364817;
out[8] = -184.75059629806532;
out[9] = -94.615102344455565;
out[10] = 69.368640085185334;
out[11] = 17.974903844364775;
out[12] = 43.675799641021136;
out[13] = 40.74868784166955;
out[14] = 69.368640085185348;
out[15] = 17.974903844364817;
out[44] = -94.615102344455565;
out[45] = 184.75059629806532;
out[46] = 17.974903844364775;
out[47] = -69.368640085185334;
out[48] = 40.74868784166955;
out[49] = -43.675799641021136;
out[50] = 17.974903844364817;
out[51] = -69.368640085185348;
out[52] = 94.615102344455565;
out[53] = -184.75059629806532;
out[54] = -17.974903844364775;
out[55] = 69.368640085185334;
out[56] = -40.74868784166955;
out[57] = 43.675799641021136;
out[58] = -17.974903844364817;
out[59] = 69.368640085185348;
out[88] = -69.368640085185319;
out[89] = -17.974903844364796;
out[90] = 184.75059629806523;
out[91] = 94.615102344455607;
out[92] = -69.368640085185291;
out[93] = -17.974903844364814;
out[94] = -43.675799641021079;
out[95] = -40.748687841669586;
out[96] = 69.368640085185319;
out[97] = 17.974903844364796;
out[98] = -184.75059629806523;
out[99] = -94.615102344455607;
out[100] = 69.368640085185291;
out[101] = 17.974903844364814;
out[102] = 43.675799641021079;
out[103] = 40.748687841669586;
out[132] = 17.974903844364796;
out[133] = -69.368640085185319;
out[134] = -94.615102344455607;
out[135] = 184.75059629806523;
out[136] = 17.974903844364814;
out[137] = -69.368640085185291;
out[138] = 40.748687841669586;
out[139] = -43.675799641021079;
out[140] = -17.974903844364796;
out[141] = 69.368640085185319;
out[142] = 94.615102344455607;
out[143] = -184.75059629806523;
out[144] = -17.974903844364814;
out[145] = 69.368640085185291;
out[146] = -40.748687841669586;
out[147] = 43.675799641021079;
out[176] = -43.675799641021122;
out[177] = -40.748687841669557;
out[178] = -69.368640085185277;
out[179] = -17.97490384436481;
out[180] = 184.75059629806526;
out[181] = 94.615102344455636;
out[182] = -69.368640085185277;
out[183] = -17.974903844364817;
out[184] = 43.675799641021122;
out[185] = 40.748687841669557;
out[186] = 69.368640085185277;
out[187] = 17.97490384436481;
out[188] = -184.75059629806526;
out[189] = -94.615102344455636;
out[190] = 69.368640085185277;
out[191] = 17.974903844364817;
out[220] = 40.748687841669557;
out[221] = -43.675799641021122;
out[222] = 17.97490384436481;
out[223] = -69.368640085185277;
out[224] = -94.615102344455636;
out[225] = 184.75059629806526;
out[226] = 17.974903844364817;
out[227] = -69.368640085185277;
out[228] = -40.748687841669557;
out[229] = 43.675799641021122;
out[230] = -17.97490384436481;
out[231] = 69.368640085185277;
out[232] = 94.615102344455636;
out[233] = -184.75059629806526;
out[234] = -17.974903844364817;
out[235] = 69.368640085185277;
out[264] = -69.368640085185334;
out[265] = -17.9749038443648;
out[266] = -43.675799641021086;
out[267] = -40.748687841669586;
out[268] = -69.368640085185291;
out[269] = -17.974903844364821;
out[270] = 184.75059629806523;
out[271] = 94.61510234445565;
out[272] = 69.368640085185334;
out[273] = 17.9749038443648;
out[274] = 43.675799641021086;
out[275] = 40.748687841669586;
out[276] = 69.368640085185291;
out[277] = 17.974903844364821;
out[278] = -184.75059629806523;
out[279] = -94.61510234445565;
out[308] = 17.9749038443648;
out[309] = -69.368640085185334;
out[310] = 40.748687841669586;
out[311] = -43.675799641021086;
out[312] = 17.974903844364821;
out[313] = -69.368640085185291;
out[314] = -94.61510234445565;
out[315] = 184.75059629806523;
out[316] = -17.9749038443648;
out[317] = 69.368640085185334;
out[318] = -40.748687841669586;
out[319] = 43.675799641021086;
out[320] = -17.974903844364821;
out[321] = 69.368640085185291;
out[322] = 94.61510234445565;
out[323] = -184.75059629806523;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[552] = 1.0;
out[578] = 1.0;
out[604] = 1.0;
out[631] = 1.0;
out[657] = 1.0;
out[683] = 1.0;
out[714] = 1.0;
out[740] = 1.0;
out[974] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   1.0
));
out[3] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];
out[5] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];
out[7] = ((0.050000000000000003*p[12] < -p[22]*x[2] - p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11]) || 0.050000000000000003*p[12] < p[22]*x[2] + p[21]*(u[16] - (0.33333333333333331*y[1]*y[16] + y[1]*(-0.28867513459481287*y[22] - 0.16666666666666657*y[17]) + y[1]*(0.28867513459481275*y[23] - 0.16666666666666677*y[18]) - 0.33333333333333331*y[0]*y[21] + y[0]*(0.16666666666666657*y[22] - 0.28867513459481287*y[17]) + y[0]*(0.16666666666666677*y[23] + 0.28867513459481275*y[18]) + 0.33333333333333326*y[3]*y[17] - 0.28867513459481281*y[3]*y[23] - 0.16666666666666652*y[3]*y[18] - 0.33333333333333326*y[2]*y[22] + 0.16666666666666652*y[2]*y[23] - 0.28867513459481281*y[2]*y[18] + 0.28867513459481281*y[5]*y[22] - 0.16666666666666652*y[5]*y[17] + 0.33333333333333326*y[5]*y[18] + 0.16666666666666652*y[4]*y[22] + 0.28867513459481281*y[4]*y[17] - 0.33333333333333326*y[4]*y[23] - 1.0*y[21]*(-0.28867513459481287*y[3] - 0.16666666666666657*y[2]) - 1.0*y[21]*(0.28867513459481275*y[5] - 0.16666666666666677*y[4]) + 1.0*y[16]*(-0.16666666666666657*y[3] + 0.28867513459481287*y[2]) + 1.0*y[16]*(-0.16666666666666677*y[5] - 0.28867513459481275*y[4]))/p[11])) ? (
   0
)
: (
   p[21]
))/p[15];

}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 1.0/p[14];
out[2] = 1.0/p[15];
out[4] = 1.0/p[15];
out[6] = 1.0/p[15];
out[8] = 1.0/p[15];

}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[9] = 1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = y[18];
out[3] = 1.0*y[23];
out[6] = cos(x[0] + u[10]);
out[7] = -(x[5] + u[2])*sin(x[0] + u[10]);
out[8] = cos(x[0] + u[11] - 2.0943951023931953);
out[9] = -(x[6] + u[3])*sin(x[0] + u[11] - 2.0943951023931953);
out[10] = cos(x[0] + u[12] - 4.1887902047863905);
out[11] = -(x[7] + u[4])*sin(x[0] + u[12] - 4.1887902047863905);
out[12] = 1.0*sin(x[0] + u[10]);
out[13] = 1.0*(x[5] + u[2])*cos(x[0] + u[10]);
out[14] = 1.0*sin(x[0] + u[11] - 2.0943951023931953);
out[15] = 1.0*(x[6] + u[3])*cos(x[0] + u[11] - 2.0943951023931953);
out[16] = 1.0*sin(x[0] + u[12] - 4.1887902047863905);
out[17] = 1.0*(x[7] + u[4])*cos(x[0] + u[12] - 4.1887902047863905);

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 1.0/p[16];
out[5] = p[23];
out[18] = cos(u[23]);
out[19] = -u[19]*sin(u[23]);
out[20] = cos(u[23] - 2.0943951023931953);
out[21] = -u[20]*sin(u[23] - 2.0943951023931953);
out[22] = cos(u[23] - 4.1887902047863905);
out[23] = -u[21]*sin(u[23] - 4.1887902047863905);
out[24] = 1.0*sin(u[23]);
out[25] = 1.0*u[19]*cos(u[23]);
out[26] = 1.0*sin(u[23] - 2.0943951023931953);
out[27] = 1.0*u[20]*cos(u[23] - 2.0943951023931953);
out[28] = 1.0*sin(u[23] - 4.1887902047863905);
out[29] = 1.0*u[21]*cos(u[23] - 4.1887902047863905);

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[128] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[129] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[130] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[131] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[132] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[133] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[134] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[135] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[136] = y[16];
out[137] = 1.0*y[21];
out[138] = y[0];
out[139] = 1.0*y[1];
out[140] = -1.0*y[21];
out[141] = 1.0*y[16];
out[142] = 1.0*y[1];
out[143] = -1.0*y[0];
out[144] = y[17];
out[145] = 1.0*y[22];
out[146] = y[2];
out[147] = 1.0*y[3];
out[148] = -1.0*y[22];
out[149] = 1.0*y[17];
out[150] = 1.0*y[3];
out[151] = -1.0*y[2];
out[152] = y[18];
out[153] = 1.0*y[23];
out[154] = y[4];
out[155] = 1.0*y[5];
out[156] = -1.0*y[23];
out[157] = 1.0*y[18];
out[158] = 1.0*y[5];
out[159] = -1.0*y[4];
out[160] = 0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18];
out[161] = 0.33333333333333331*y[21] - 0.16666666666666657*y[22] + 0.28867513459481287*y[17] - 0.16666666666666677*y[23] - 0.28867513459481275*y[18];
out[162] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[163] = -0.16666666666666657*y[21] - 0.28867513459481287*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] + 0.28867513459481281*y[18];
out[164] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[165] = -0.16666666666666677*y[21] + 0.28867513459481275*y[16] - 0.16666666666666652*y[22] - 0.28867513459481281*y[17] + 0.33333333333333326*y[23];
out[166] = 0.33333333333333331*y[0] - 0.28867513459481287*y[3] - 0.16666666666666657*y[2] + 0.28867513459481275*y[5] - 0.16666666666666677*y[4];
out[167] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] + 0.33333333333333326*y[2] - 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[168] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[169] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[170] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[171] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[172] = 0.33333333333333331*y[16] + 0.28867513459481275*y[22] - 0.16666666666666677*y[17] - 0.28867513459481287*y[23] - 0.16666666666666657*y[18];
out[173] = 0.33333333333333331*y[21] - 0.16666666666666677*y[22] - 0.28867513459481275*y[17] - 0.16666666666666657*y[23] + 0.28867513459481287*y[18];
out[174] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.33333333333333326*y[17] + 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[175] = -0.16666666666666677*y[21] + 0.28867513459481275*y[16] + 0.33333333333333326*y[22] - 0.16666666666666652*y[23] - 0.28867513459481281*y[18];
out[176] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] - 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[177] = -0.16666666666666657*y[21] - 0.28867513459481287*y[16] - 0.16666666666666652*y[22] + 0.28867513459481281*y[17] + 0.33333333333333326*y[23];
out[178] = 0.33333333333333331*y[0] + 0.28867513459481275*y[3] - 0.16666666666666677*y[2] - 0.28867513459481287*y[5] - 0.16666666666666657*y[4];
out[179] = -0.28867513459481275*y[1] - 0.16666666666666677*y[0] + 0.33333333333333326*y[2] + 0.28867513459481281*y[5] - 0.16666666666666652*y[4];
out[180] = 0.28867513459481287*y[1] - 0.16666666666666657*y[0] - 0.28867513459481281*y[3] - 0.16666666666666652*y[2] + 0.33333333333333326*y[4];
out[181] = 0.33333333333333331*y[1] - 0.16666666666666677*y[3] - 0.28867513459481275*y[2] - 0.16666666666666657*y[5] + 0.28867513459481287*y[4];
out[182] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] - 0.28867513459481281*y[4];
out[183] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] - 0.16666666666666652*y[3] + 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[184] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[185] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[186] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[187] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[188] = 0.33333333333333331*y[16] + 0.33333333333333331*y[17] + 0.33333333333333331*y[18];
out[189] = 0.33333333333333331*y[21] + 0.33333333333333331*y[22] + 0.33333333333333331*y[23];
out[190] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[191] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[192] = 0.33333333333333331*y[0] + 0.33333333333333331*y[2] + 0.33333333333333331*y[4];
out[193] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[194] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[195] = 0.33333333333333331*y[1] + 0.33333333333333331*y[3] + 0.33333333333333331*y[5];
out[196] = -0.33333333333333331*y[21] + 0.16666666666666657*y[22] - 0.28867513459481287*y[17] + 0.16666666666666677*y[23] + 0.28867513459481275*y[18];
out[197] = 0.33333333333333331*y[16] - 0.28867513459481287*y[22] - 0.16666666666666657*y[17] + 0.28867513459481275*y[23] - 0.16666666666666677*y[18];
out[198] = 0.16666666666666657*y[21] + 0.28867513459481287*y[16] - 0.33333333333333326*y[22] + 0.16666666666666652*y[23] - 0.28867513459481281*y[18];
out[199] = 0.28867513459481287*y[21] - 0.16666666666666657*y[16] + 0.33333333333333326*y[17] - 0.28867513459481281*y[23] - 0.16666666666666652*y[18];
out[200] = 0.16666666666666677*y[21] - 0.28867513459481275*y[16] + 0.16666666666666652*y[22] + 0.28867513459481281*y[17] - 0.33333333333333326*y[23];
out[201] = -0.28867513459481275*y[21] - 0.16666666666666677*y[16] + 0.28867513459481281*y[22] - 0.16666666666666652*y[17] + 0.33333333333333326*y[18];
out[202] = 0.33333333333333331*y[1] - 0.16666666666666657*y[3] + 0.28867513459481287*y[2] - 0.16666666666666677*y[5] - 0.28867513459481275*y[4];
out[203] = -0.16666666666666657*y[1] - 0.28867513459481287*y[0] + 0.33333333333333326*y[3] - 0.16666666666666652*y[5] + 0.28867513459481281*y[4];
out[204] = -0.16666666666666677*y[1] + 0.28867513459481275*y[0] - 0.16666666666666652*y[3] - 0.28867513459481281*y[2] + 0.33333333333333326*y[5];
out[205] = -0.33333333333333331*y[0] + 0.28867513459481287*y[3] + 0.16666666666666657*y[2] - 0.28867513459481275*y[5] + 0.16666666666666677*y[4];
out[206] = -0.28867513459481287*y[1] + 0.16666666666666657*y[0] - 0.33333333333333326*y[2] + 0.28867513459481281*y[5] + 0.16666666666666652*y[4];
out[207] = 0.28867513459481275*y[1] + 0.16666666666666677*y[0] - 0.28867513459481281*y[3] + 0.16666666666666652*y[2] - 0.33333333333333326*y[4];
out[208] = y[34]*pow(1.0*pow(y[38], 2) + pow(y[34], 2), -0.5);
out[209] = 1.0*y[38]*pow(1.0*pow(y[38], 2) + pow(y[34], 2), -0.5);
out[210] = y[35]*pow(1.0*pow(y[39], 2) + pow(y[35], 2), -0.5);
out[211] = 1.0*y[39]*pow(1.0*pow(y[39], 2) + pow(y[35], 2), -0.5);
out[212] = y[36]*pow(1.0*pow(y[40], 2) + pow(y[36], 2), -0.5);
out[213] = 1.0*y[40]*pow(1.0*pow(y[40], 2) + pow(y[36], 2), -0.5);
out[214] = y[37]*pow(1.0*pow(y[41], 2) + pow(y[37], 2), -0.5);
out[215] = 1.0*y[41]*pow(1.0*pow(y[41], 2) + pow(y[37], 2), -0.5);
out[216] = y[34];
out[217] = 1.0*y[38];
out[218] = y[35];
out[219] = 1.0*y[39];
out[220] = y[36];
out[221] = 1.0*y[40];
out[222] = y[8];
out[223] = y[10];
out[224] = y[12];
out[225] = 1.0*y[9];
out[226] = 1.0*y[11];
out[227] = 1.0*y[13];
out[228] = -1.0*y[38];
out[229] = 1.0*y[34];
out[230] = -1.0*y[39];
out[231] = 1.0*y[35];
out[232] = -1.0*y[40];
out[233] = 1.0*y[36];
out[234] = 1.0*y[9];
out[235] = 1.0*y[11];
out[236] = 1.0*y[13];
out[237] = -1.0*y[8];
out[238] = -1.0*y[10];
out[239] = -1.0*y[12];

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806532;
out[1] = 94.615102344455565;
out[2] = -69.368640085185334;
out[3] = -17.974903844364775;
out[4] = -43.675799641021136;
out[5] = -40.74868784166955;
out[6] = -69.368640085185348;
out[7] = -17.974903844364817;
out[8] = -184.75059629806532;
out[9] = -94.615102344455565;
out[10] = 69.368640085185334;
out[11] = 17.974903844364775;
out[12] = 43.675799641021136;
out[13] = 40.74868784166955;
out[14] = 69.368640085185348;
out[15] = 17.974903844364817;
out[16] = -94.615102344455565;
out[17] = 184.75059629806532;
out[18] = 17.974903844364775;
out[19] = -69.368640085185334;
out[20] = 40.74868784166955;
out[21] = -43.675799641021136;
out[22] = 17.974903844364817;
out[23] = -69.368640085185348;
out[24] = 94.615102344455565;
out[25] = -184.75059629806532;
out[26] = -17.974903844364775;
out[27] = 69.368640085185334;
out[28] = -40.74868784166955;
out[29] = 43.675799641021136;
out[30] = -17.974903844364817;
out[31] = 69.368640085185348;
out[32] = -69.368640085185319;
out[33] = -17.974903844364796;
out[34] = 184.75059629806523;
out[35] = 94.615102344455607;
out[36] = -69.368640085185291;
out[37] = -17.974903844364814;
out[38] = -43.675799641021079;
out[39] = -40.748687841669586;
out[40] = 69.368640085185319;
out[41] = 17.974903844364796;
out[42] = -184.75059629806523;
out[43] = -94.615102344455607;
out[44] = 69.368640085185291;
out[45] = 17.974903844364814;
out[46] = 43.675799641021079;
out[47] = 40.748687841669586;
out[48] = 17.974903844364796;
out[49] = -69.368640085185319;
out[50] = -94.615102344455607;
out[51] = 184.75059629806523;
out[52] = 17.974903844364814;
out[53] = -69.368640085185291;
out[54] = 40.748687841669586;
out[55] = -43.675799641021079;
out[56] = -17.974903844364796;
out[57] = 69.368640085185319;
out[58] = 94.615102344455607;
out[59] = -184.75059629806523;
out[60] = -17.974903844364814;
out[61] = 69.368640085185291;
out[62] = -40.748687841669586;
out[63] = 43.675799641021079;
out[64] = -43.675799641021122;
out[65] = -40.748687841669557;
out[66] = -69.368640085185277;
out[67] = -17.97490384436481;
out[68] = 184.75059629806526;
out[69] = 94.615102344455636;
out[70] = -69.368640085185277;
out[71] = -17.974903844364817;
out[72] = 43.675799641021122;
out[73] = 40.748687841669557;
out[74] = 69.368640085185277;
out[75] = 17.97490384436481;
out[76] = -184.75059629806526;
out[77] = -94.615102344455636;
out[78] = 69.368640085185277;
out[79] = 17.974903844364817;
out[80] = 40.748687841669557;
out[81] = -43.675799641021122;
out[82] = 17.97490384436481;
out[83] = -69.368640085185277;
out[84] = -94.615102344455636;
out[85] = 184.75059629806526;
out[86] = 17.974903844364817;
out[87] = -69.368640085185277;
out[88] = -40.748687841669557;
out[89] = 43.675799641021122;
out[90] = -17.97490384436481;
out[91] = 69.368640085185277;
out[92] = 94.615102344455636;
out[93] = -184.75059629806526;
out[94] = -17.974903844364817;
out[95] = 69.368640085185277;
out[96] = -69.368640085185334;
out[97] = -17.9749038443648;
out[98] = -43.675799641021086;
out[99] = -40.748687841669586;
out[100] = -69.368640085185291;
out[101] = -17.974903844364821;
out[102] = 184.75059629806523;
out[103] = 94.61510234445565;
out[104] = 69.368640085185334;
out[105] = 17.9749038443648;
out[106] = 43.675799641021086;
out[107] = 40.748687841669586;
out[108] = 69.368640085185291;
out[109] = 17.974903844364821;
out[110] = -184.75059629806523;
out[111] = -94.61510234445565;
out[112] = 17.9749038443648;
out[113] = -69.368640085185334;
out[114] = 40.748687841669586;
out[115] = -43.675799641021086;
out[116] = 17.974903844364821;
out[117] = -69.368640085185291;
out[118] = -94.61510234445565;
out[119] = 184.75059629806523;
out[120] = -17.9749038443648;
out[121] = 69.368640085185334;
out[122] = -40.748687841669586;
out[123] = 43.675799641021086;
out[124] = -17.974903844364821;
out[125] = 69.368640085185291;
out[126] = 94.61510234445565;
out[127] = -184.75059629806523;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[2] = 1.0;
out[3] = 1.0;
out[4] = 1.0;
out[5] = 1.0;
out[6] = 1.0;
out[7] = 1.0;
out[8] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_temp_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_temp_cffi(void) { return NULL; }
#  else
     inittemp_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_temp_cffi(void)
{
  return _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inittemp_cffi(void)
{
  _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
